@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2009-2010, Pino Toscano <pino@kde.org>
- * Copyright (C) 2017-2020, 2025, Albert Astals Cid <aacid@kde.org>
+ * Copyright (C) 2017-2020, 2025, 2026, Albert Astals Cid <aacid@kde.org>
  * Copyright (C) 2017, Jason Alan Palmer <jalanpalmer@gmail.com>
  * Copyright (C) 2018, 2020, Suzuki Toshiya <mpsuzuki@hiroshima-u.ac.jp>
  * Copyright (C) 2018, 2020, Adam Reichold <adam.reichold@t-online.de>
@@ -37,7 +37,6 @@
 
 #include "TextOutputDev.h"
 
-#include <algorithm>
 #include <memory>
 #include <utility>
 
@@ -278,7 +277,8 @@ static void appendToGooString(void *stream, const char *text, int len)
 
  \param rect if not empty, it will be extracted the text in it; otherwise, the
              text of the whole page
- \param layout_mode the layout of the text
+ \param layout_mode the layout of the text. non_raw_non_physical_layout is not
+                    supported together with a non empty rect
 
  \returns the text of the page in the specified rect or in the whole page
 
@@ -293,6 +293,10 @@ ustring page::text(const rectf &r, text_layout_enum layout_mode) const
     if (r.is_empty()) {
         d->doc->doc->displayPage(&td, d->index + 1, 72, 72, 0, false, true, false);
     } else {
+        if (layout_mode == non_raw_non_physical_layout) {
+            detail::user_debug_function("non_raw_non_physical_layout is not supported together with a non empty rect", detail::debug_closure);
+            return {};
+        }
         d->doc->doc->displayPageSlice(&td, d->index + 1, 72, 72, 0, false, true, false, r.left(), r.top(), r.width(), r.height());
     }
     return ustring::from_utf8(out->c_str());
@@ -409,8 +413,8 @@ std::vector<text_box> page::text_list(int opt_flag) const
     const std::vector<TextWord *> &words = word_list->getWords();
     output_list.reserve(words.size());
     for (const TextWord *word : words) {
-        std::unique_ptr<GooString> gooWord { word->getText() };
-        ustring ustr = ustring::from_utf8(gooWord->c_str());
+        const std::unique_ptr<std::string> wordText = word->getText();
+        const ustring ustr = ustring::from_utf8(wordText->c_str());
 
         double xMin, yMin, xMax, yMax;
         word->getBBox(&xMin, &yMin, &xMax, &yMax);
