@@ -3,7 +3,11 @@
  * Copyright (C) 2013 Adrian Johnson <ajohnson@redneon.com>
  * Copyright (C) 2014, Hans-Peter Deifel <hpdeifel@gmx.de>
  * Copyright (C) 2016 Jakub Alba <jakubalba@gmail.com>
- * Copyright (C) 2017, 2018 Albert Astals Cid <aacid@kde.org>
+ * Copyright (C) 2017-2019, 2025 Albert Astals Cid <aacid@kde.org>
+ * Copyright (C) 2018 Suzuki Toshiya <mpsuzuki@hiroshima-u.ac.jp>
+ * Copyright (C) 2020 Adam Reichold <adam.reichold@t-online.de>
+ * Copyright (C) 2024 Oliver Sander <oliver.sander@tu-dresden.de>
+ * Copyright (C) 2024, 2025 g10 Code GmbH, Author: Sune Stolborg Vuorela <sune@vuorela.dk>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -22,8 +26,9 @@
 
 #include "poppler-private.h"
 
-#include "GooString.h"
-#include "Page.h"
+#include "goo/GooString.h"
+#include "PDFRectangle.h"
+#include "UTF.h"
 
 #include <ctime>
 #include <iostream>
@@ -39,7 +44,7 @@ static void stderr_debug_function(const std::string &msg, void * /*data*/)
 debug_func detail::user_debug_function = stderr_debug_function;
 void *detail::debug_closure = nullptr;
 
-void detail::error_function(void * /*data*/, ErrorCategory /*category*/, Goffset pos, const char *msg)
+void detail::error_function(ErrorCategory /*category*/, Goffset pos, const char *msg)
 {
     std::ostringstream oss;
     if (pos >= 0) {
@@ -59,14 +64,11 @@ rectf detail::pdfrectangle_to_rectf(const PDFRectangle &pdfrect)
 ustring detail::unicode_GooString_to_ustring(const GooString *str)
 {
     const char *data = str->c_str();
-    const int len = str->getLength();
+    const int len = str->size();
 
-    int i = 0;
-    bool is_unicode = false;
-    if ((data[0] & 0xff) == 0xfe && (len > 1 && (data[1] & 0xff) == 0xff)) {
-        is_unicode = true;
-        i = 2;
-    }
+    const bool is_unicodeLE = hasUnicodeByteOrderMarkLE(str->toStr());
+    const bool is_unicode = hasUnicodeByteOrderMark(str->toStr()) || is_unicodeLE;
+    int i = is_unicode ? 2 : 0;
     ustring::size_type ret_len = len - i;
     if (is_unicode) {
         ret_len >>= 1;
@@ -76,7 +78,7 @@ ustring detail::unicode_GooString_to_ustring(const GooString *str)
     ustring::value_type u;
     if (is_unicode) {
         while (i < len) {
-            u = ((data[i] & 0xff) << 8) | (data[i + 1] & 0xff);
+            u = is_unicodeLE ? ((data[i + 1] & 0xff) << 8) | (data[i] & 0xff) : ((data[i] & 0xff) << 8) | (data[i + 1] & 0xff);
             i += 2;
             ret[ret_index++] = u;
         }
@@ -93,7 +95,7 @@ ustring detail::unicode_GooString_to_ustring(const GooString *str)
 
 ustring detail::unicode_to_ustring(const Unicode *u, int length)
 {
-    ustring str(length * 2, 0);
+    ustring str(length, 0);
     ustring::iterator it = str.begin();
     const Unicode *uu = u;
     for (int i = 0; i < length; ++i) {
@@ -102,7 +104,7 @@ ustring detail::unicode_to_ustring(const Unicode *u, int length)
     return str;
 }
 
-GooString* detail::ustring_to_unicode_GooString(const ustring &str)
+std::unique_ptr<GooString> detail::ustring_to_unicode_GooString(const ustring &str)
 {
     const size_t len = str.size() * 2 + 2;
     const ustring::value_type *me = str.data();
@@ -113,6 +115,5 @@ GooString* detail::ustring_to_unicode_GooString(const ustring &str)
         ba[i * 2 + 2] = ((*me >> 8) & 0xff);
         ba[i * 2 + 3] = (*me & 0xff);
     }
-    GooString *goo = new GooString(&ba[0], len);
-    return goo;
+    return std::make_unique<GooString>(&ba[0], len);
 }
