@@ -16,7 +16,7 @@
 // Copyright (C) 2006 Takashi Iwai <tiwai@suse.de>
 // Copyright (C) 2007 Koji Otani <sho@bbr.jp>
 // Copyright (C) 2007 Carlos Garcia Campos <carlosgc@gnome.org>
-// Copyright (C) 2008, 2009, 2012, 2014-2022, 2024 Albert Astals Cid <aacid@kde.org>
+// Copyright (C) 2008, 2009, 2012, 2014-2022, 2024, 2025 Albert Astals Cid <aacid@kde.org>
 // Copyright (C) 2008 Tomas Are Haavet <tomasare@gmail.com>
 // Copyright (C) 2012 Suzuki Toshiya <mpsuzuki@hiroshima-u.ac.jp>
 // Copyright (C) 2012, 2017 Adrian Johnson <ajohnson@redneon.com>
@@ -454,35 +454,40 @@ static const char *macGlyphNames[258] = { ".notdef",
 // FoFiTrueType
 //------------------------------------------------------------------------
 
-std::unique_ptr<FoFiTrueType> FoFiTrueType::make(const unsigned char *fileA, int lenA, int faceIndexA)
+std::unique_ptr<FoFiTrueType> FoFiTrueType::make(std::span<unsigned char> data, int faceIndexA)
 {
-    // Cannot use std::make_unique, because the constructor is private
-    auto ff = new FoFiTrueType(fileA, lenA, false, faceIndexA);
+    auto ff = std::make_unique<FoFiTrueType>(data, faceIndexA);
     if (!ff->parsedOk) {
-        delete ff;
         return nullptr;
     }
-    return std::unique_ptr<FoFiTrueType>(ff);
+    return ff;
 }
 
 std::unique_ptr<FoFiTrueType> FoFiTrueType::load(const char *fileName, int faceIndexA)
 {
-    char *fileA;
-    int lenA;
+    std::optional<std::vector<unsigned char>> fileA;
 
-    if (!(fileA = FoFiBase::readFile(fileName, &lenA))) {
+    if (!(fileA = FoFiBase::readFile(fileName))) {
         return nullptr;
     }
-    // Cannot use std::make_unique, because the constructor is private
-    auto ff = new FoFiTrueType((unsigned char *)fileA, lenA, true, faceIndexA);
+    auto ff = std::make_unique<FoFiTrueType>(std::move(fileA.value()), faceIndexA);
     if (!ff->parsedOk) {
-        delete ff;
         return nullptr;
     }
-    return std::unique_ptr<FoFiTrueType>(ff);
+    return ff;
 }
 
-FoFiTrueType::FoFiTrueType(const unsigned char *fileA, int lenA, bool freeFileDataA, int faceIndexA) : FoFiBase(fileA, lenA, freeFileDataA)
+FoFiTrueType::FoFiTrueType(std::vector<unsigned char> &&fileA, int faceIndexA, PrivateTag) : FoFiBase(std::move(fileA))
+{
+    parsedOk = false;
+    faceIndex = faceIndexA;
+    gsubFeatureTable = 0;
+    gsubLookupList = 0;
+
+    parse();
+}
+
+FoFiTrueType::FoFiTrueType(std::span<unsigned char> data, int faceIndexA, PrivateTag) : FoFiBase(data)
 {
     parsedOk = false;
     faceIndex = faceIndexA;
@@ -645,34 +650,29 @@ int FoFiTrueType::mapNameToGID(const char *name) const
     return gid->second;
 }
 
-bool FoFiTrueType::getCFFBlock(char **start, int *length) const
+std::optional<std::span<unsigned char>> FoFiTrueType::getCFFBlock() const
 {
     if (!openTypeCFF || tables.empty()) {
-        return false;
+        return std::nullopt;
     }
     int i = seekTable("CFF ");
     if (i < 0 || !checkRegion(tables[i].offset, tables[i].len)) {
-        return false;
+        return std::nullopt;
     }
-    *start = (char *)file + tables[i].offset;
-    *length = tables[i].len;
-    return true;
+    return std::span { file.data() + tables[i].offset, size_t(tables[i].len) };
 }
 
 std::vector<int> FoFiTrueType::getCIDToGIDMap() const
 {
-    char *start;
-    int length;
-    FoFiType1C *ff;
-
-    if (!getCFFBlock(&start, &length)) {
+    auto cffBlock = getCFFBlock();
+    if (!cffBlock) {
         return {};
     }
-    if (!(ff = FoFiType1C::make((unsigned char *)start, length))) {
+    auto ff = FoFiType1C::make(cffBlock.value());
+    if (!ff) {
         return {};
     }
     std::vector<int> map = ff->getCIDToGIDMap();
-    delete ff;
     return map;
 }
 
@@ -703,18 +703,16 @@ int FoFiTrueType::getEmbeddingRights() const
 
 void FoFiTrueType::getFontMatrix(double *mat) const
 {
-    char *start;
-    int length;
-    FoFiType1C *ff;
+    auto cffBlock = getCFFBlock();
 
-    if (!getCFFBlock(&start, &length)) {
+    if (!cffBlock) {
         return;
     }
-    if (!(ff = FoFiType1C::make((unsigned char *)start, length))) {
+    auto ff = FoFiType1C::make(cffBlock.value());
+    if (!ff) {
         return;
     }
     ff->getFontMatrix(mat);
-    delete ff;
 }
 
 void FoFiTrueType::convertToType42(const char *psName, char **encoding, const std::vector<int> &codeToGID, FoFiOutputFunc outputFunc, void *outputStream) const
@@ -745,7 +743,7 @@ void FoFiTrueType::convertToType42(const char *psName, char **encoding, const st
     // write the guts of the dictionary
     cvtEncoding(encoding, outputFunc, outputStream);
     cvtCharStrings(encoding, codeToGID, outputFunc, outputStream);
-    cvtSfnts(outputFunc, outputStream, nullptr, false, &maxUsedGlyph);
+    cvtSfnts(outputFunc, outputStream, std::nullopt, false, &maxUsedGlyph);
 
     // end the dictionary and define the font
     (*outputFunc)(outputStream, "FontName currentdict end definefont pop\n", 40);
@@ -753,18 +751,15 @@ void FoFiTrueType::convertToType42(const char *psName, char **encoding, const st
 
 void FoFiTrueType::convertToType1(const char *psName, const char **newEncoding, bool ascii, FoFiOutputFunc outputFunc, void *outputStream) const
 {
-    char *start;
-    int length;
-    FoFiType1C *ff;
-
-    if (!getCFFBlock(&start, &length)) {
+    auto cffBlock = getCFFBlock();
+    if (!cffBlock) {
         return;
     }
-    if (!(ff = FoFiType1C::make((unsigned char *)start, length))) {
+    auto ff = FoFiType1C::make(cffBlock.value());
+    if (!ff) {
         return;
     }
     ff->convertToType1(psName, newEncoding, ascii, outputFunc, outputStream);
-    delete ff;
 }
 
 void FoFiTrueType::convertToCIDType2(const char *psName, const std::vector<int> &cidMap, bool needVerticalMetrics, FoFiOutputFunc outputFunc, void *outputStream) const
@@ -868,31 +863,27 @@ void FoFiTrueType::convertToCIDType2(const char *psName, const std::vector<int>
     (*outputFunc)(outputStream, "  end readonly def\n", 19);
 
     // write the guts of the dictionary
-    cvtSfnts(outputFunc, outputStream, nullptr, needVerticalMetrics, &maxUsedGlyph);
+    cvtSfnts(outputFunc, outputStream, std::nullopt, needVerticalMetrics, &maxUsedGlyph);
 
     // end the dictionary and define the font
     (*outputFunc)(outputStream, "CIDFontName currentdict end /CIDFont defineresource pop\n", 56);
 }
 
-void FoFiTrueType::convertToCIDType0(const char *psName, const std::vector<int> &cidMap, FoFiOutputFunc outputFunc, void *outputStream) const
+void FoFiTrueType::convertToCIDType0(const std::string &psName, const std::vector<int> &cidMap, FoFiOutputFunc outputFunc, void *outputStream) const
 {
-    char *start;
-    int length;
-    FoFiType1C *ff;
-
-    if (!getCFFBlock(&start, &length)) {
+    auto cffBlock = getCFFBlock();
+    if (!cffBlock) {
         return;
     }
-    if (!(ff = FoFiType1C::make((unsigned char *)start, length))) {
+    auto ff = FoFiType1C::make(cffBlock.value());
+    if (!ff) {
         return;
     }
     ff->convertToCIDType0(psName, cidMap, outputFunc, outputStream);
-    delete ff;
 }
 
-void FoFiTrueType::convertToType0(const char *psName, const std::vector<int> &cidMap, bool needVerticalMetrics, int *maxValidGlyph, FoFiOutputFunc outputFunc, void *outputStream) const
+void FoFiTrueType::convertToType0(const std::string &psName, const std::vector<int> &cidMap, bool needVerticalMetrics, int *maxValidGlyph, FoFiOutputFunc outputFunc, void *outputStream) const
 {
-    GooString *sfntsName;
     int maxUsedGlyph, n, i, j;
 
     *maxValidGlyph = -1;
@@ -902,9 +893,8 @@ void FoFiTrueType::convertToType0(const char *psName, const std::vector<int> &ci
     }
 
     // write the Type 42 sfnts array
-    sfntsName = (new GooString(psName))->append("_sfnts");
+    const std::string sfntsName = psName + "_sfnts";
     cvtSfnts(outputFunc, outputStream, sfntsName, needVerticalMetrics, &maxUsedGlyph);
-    delete sfntsName;
 
     // write the descendant Type 42 fonts
     // (The following is a kludge: nGlyphs is the glyph count from the
@@ -939,7 +929,7 @@ void FoFiTrueType::convertToType0(const char *psName, const std::vector<int> &ci
     for (i = 0; i < n; i += 256) {
         (*outputFunc)(outputStream, "10 dict begin\n", 14);
         (*outputFunc)(outputStream, "/FontName /", 11);
-        (*outputFunc)(outputStream, psName, strlen(psName));
+        (*outputFunc)(outputStream, psName.c_str(), psName.length());
         std::string buf = GooString::format("_{0:02x} def\n", i >> 8);
         (*outputFunc)(outputStream, buf.c_str(), buf.size());
         (*outputFunc)(outputStream, "/FontType 42 def\n", 17);
@@ -948,7 +938,7 @@ void FoFiTrueType::convertToType0(const char *psName, const std::vector<int> &ci
         (*outputFunc)(outputStream, buf.c_str(), buf.size());
         (*outputFunc)(outputStream, "/PaintType 0 def\n", 17);
         (*outputFunc)(outputStream, "/sfnts ", 7);
-        (*outputFunc)(outputStream, psName, strlen(psName));
+        (*outputFunc)(outputStream, psName.c_str(), psName.length());
         (*outputFunc)(outputStream, "_sfnts def\n", 11);
         (*outputFunc)(outputStream, "/Encoding 256 array\n", 20);
         for (j = 0; j < 256 && i + j < n; ++j) {
@@ -969,7 +959,7 @@ void FoFiTrueType::convertToType0(const char *psName, const std::vector<int> &ci
     // write the Type 0 parent font
     (*outputFunc)(outputStream, "16 dict begin\n", 14);
     (*outputFunc)(outputStream, "/FontName /", 11);
-    (*outputFunc)(outputStream, psName, strlen(psName));
+    (*outputFunc)(outputStream, psName.c_str(), psName.length());
     (*outputFunc)(outputStream, " def\n", 5);
     (*outputFunc)(outputStream, "/FontType 0 def\n", 16);
     (*outputFunc)(outputStream, "/FontMatrix [1 0 0 1 0 0] def\n", 30);
@@ -983,7 +973,7 @@ void FoFiTrueType::convertToType0(const char *psName, const std::vector<int> &ci
     (*outputFunc)(outputStream, "/FDepVector [\n", 14);
     for (i = 0; i < n; i += 256) {
         (*outputFunc)(outputStream, "/", 1);
-        (*outputFunc)(outputStream, psName, strlen(psName));
+        (*outputFunc)(outputStream, psName.c_str(), psName.length());
         const std::string buf = GooString::format("_{0:02x} findfont\n", i >> 8);
         (*outputFunc)(outputStream, buf.c_str(), buf.size());
     }
@@ -991,20 +981,17 @@ void FoFiTrueType::convertToType0(const char *psName, const std::vector<int> &ci
     (*outputFunc)(outputStream, "FontName currentdict end definefont pop\n", 40);
 }
 
-void FoFiTrueType::convertToType0(const char *psName, const std::vector<int> &cidMap, FoFiOutputFunc outputFunc, void *outputStream) const
+void FoFiTrueType::convertToType0(const std::string &psName, const std::vector<int> &cidMap, FoFiOutputFunc outputFunc, void *outputStream) const
 {
-    char *start;
-    int length;
-    FoFiType1C *ff;
-
-    if (!getCFFBlock(&start, &length)) {
+    auto cffBlock = getCFFBlock();
+    if (!cffBlock) {
         return;
     }
-    if (!(ff = FoFiType1C::make((unsigned char *)start, length))) {
+    auto ff = FoFiType1C::make(cffBlock.value());
+    if (!ff) {
         return;
     }
     ff->convertToType0(psName, cidMap, outputFunc, outputStream);
-    delete ff;
 }
 
 void FoFiTrueType::cvtEncoding(char **encoding, FoFiOutputFunc outputFunc, void *outputStream) const
@@ -1080,7 +1067,7 @@ err:
     (*outputFunc)(outputStream, "end readonly def\n", 17);
 }
 
-void FoFiTrueType::cvtSfnts(FoFiOutputFunc outputFunc, void *outputStream, const GooString *name, bool needVerticalMetrics, int *maxUsedGlyph) const
+void FoFiTrueType::cvtSfnts(FoFiOutputFunc outputFunc, void *outputStream, const std::optional<std::string> &name, bool needVerticalMetrics, int *maxUsedGlyph) const
 {
     std::array<unsigned char, 54> headData;
     std::vector<unsigned char> locaData;
@@ -1124,7 +1111,7 @@ void FoFiTrueType::cvtSfnts(FoFiOutputFunc outputFunc, void *outputStream, const
     if (!checkRegion(pos, 54)) {
         return;
     }
-    memcpy(headData.data(), file + pos, 54);
+    memcpy(headData.data(), file.data() + pos, 54);
     headData[8] = headData[9] = headData[10] = headData[11] = (unsigned char)0;
 
     // check for a bogus loca format field in the 'head' table
@@ -1243,14 +1230,14 @@ void FoFiTrueType::cvtSfnts(FoFiOutputFunc outputFunc, void *outputStream, const
                     length += 4 - (length & 3);
                 }
                 if (checkRegion(glyfPos + locaTable[j].origOffset, locaTable[j].len)) {
-                    checksum += computeTableChecksum(std::span(file + glyfPos + locaTable[j].origOffset, locaTable[j].len));
+                    checksum += computeTableChecksum(std::span(file.data() + glyfPos + locaTable[j].origOffset, locaTable[j].len));
                 }
             }
         } else {
             if ((j = seekTable(t42Tables[i].tag)) >= 0) {
                 length = tables[j].len;
                 if (checkRegion(tables[j].offset, length)) {
-                    checksum = computeTableChecksum(std::span(file + tables[j].offset, length));
+                    checksum = computeTableChecksum(std::span(file.data() + tables[j].offset, length));
                 }
             } else if (needVerticalMetrics && i == t42VheaTable) {
                 vheaTab[10] = advance / 256; // max advance height
@@ -1340,7 +1327,7 @@ void FoFiTrueType::cvtSfnts(FoFiOutputFunc outputFunc, void *outputStream, const
     // start the sfnts array
     if (name) {
         (*outputFunc)(outputStream, "/", 1);
-        (*outputFunc)(outputStream, name->c_str(), name->getLength());
+        (*outputFunc)(outputStream, name->c_str(), name->size());
         (*outputFunc)(outputStream, " [\n", 3);
     } else {
         (*outputFunc)(outputStream, "/sfnts [\n", 9);
@@ -1360,7 +1347,7 @@ void FoFiTrueType::cvtSfnts(FoFiOutputFunc outputFunc, void *outputStream, const
             glyfPos = tables[seekTable("glyf")].offset;
             for (j = 0; j < nGlyphs; ++j) {
                 if (locaTable[j].len > 0 && checkRegion(glyfPos + locaTable[j].origOffset, locaTable[j].len)) {
-                    dumpString(std::span(file + glyfPos + locaTable[j].origOffset, locaTable[j].len), outputFunc, outputStream);
+                    dumpString(std::span(file.data() + glyfPos + locaTable[j].origOffset, locaTable[j].len), outputFunc, outputStream);
                 }
             }
         } else {
@@ -1369,7 +1356,7 @@ void FoFiTrueType::cvtSfnts(FoFiOutputFunc outputFunc, void *outputStream, const
             // headers
             if ((length = newTables[i].len) > 0) {
                 if ((j = seekTable(t42Tables[i].tag)) >= 0 && checkRegion(tables[j].offset, tables[j].len)) {
-                    dumpString(std::span(file + tables[j].offset, tables[j].len), outputFunc, outputStream);
+                    dumpString(std::span(file.data() + tables[j].offset, tables[j].len), outputFunc, outputStream);
                 } else if (needVerticalMetrics && i == t42VheaTable) {
                     if (unlikely(length > (int)sizeof(vheaTab))) {
                         error(errSyntaxWarning, -1, "length bigger than vheaTab size");
@@ -1497,7 +1484,7 @@ void FoFiTrueType::parse()
         tables[j].offset = (int)getU32BE(pos + 8, &parsedOk);
         tables[j].len = (int)getU32BE(pos + 12, &parsedOk);
         if (unlikely((tables[j].offset < 0) || (tables[j].len < 0) || (tables[j].offset < INT_MAX - tables[j].len) || (tables[j].len > INT_MAX - tables[j].offset)
-                     || (tables[j].offset + tables[j].len >= tables[j].offset && tables[j].offset + tables[j].len <= len))) {
+                     || (tables[j].offset + tables[j].len >= tables[j].offset && tables[j].offset + tables[j].len <= int(file.size())))) {
             // ignore any bogus entries in the table directory
             ++j;
         }
@@ -1617,7 +1604,11 @@ void FoFiTrueType::readPostTable()
                 if (!ok || !checkRegion(stringPos + 1, m)) {
                     continue;
                 }
-                name.assign((char *)&file[stringPos + 1], m);
+                if (((size_t(stringPos) + 1) == file.size()) || m == 0) {
+                    name.clear();
+                } else {
+                    name.assign((char *)&file[stringPos + 1], m);
+                }
                 nameToGID[name] = i;
                 ++stringIdx;
                 stringPos += 1 + m;
@@ -1655,11 +1646,11 @@ int FoFiTrueType::seekTable(const char *tag) const
     return -1;
 }
 
-unsigned int FoFiTrueType::charToTag(const char *tagName)
+unsigned int FoFiTrueType::charToTag(const std::string &tagName) const
 {
-    int n = strlen(tagName);
+    size_t n = tagName.size();
     unsigned int tag = 0;
-    int i;
+    size_t i;
 
     if (n > 4) {
         n = 4;
@@ -1679,16 +1670,7 @@ unsigned int FoFiTrueType::charToTag(const char *tagName)
   setup GSUB table data
   Only supporting vertical text substitution.
 */
-int FoFiTrueType::setupGSUB(const char *scriptName)
-{
-    return setupGSUB(scriptName, nullptr);
-}
-
-/*
-  setup GSUB table data
-  Only supporting vertical text substitution.
-*/
-int FoFiTrueType::setupGSUB(const char *scriptName, const char *languageName)
+int FoFiTrueType::setupGSUB(const std::string &scriptName, const std::string &languageName)
 {
     unsigned int gsubTable;
     unsigned int i;
@@ -1701,15 +1683,10 @@ int FoFiTrueType::setupGSUB(const char *scriptName, const char *languageName)
     unsigned int featureIndex;
     unsigned int ftable = 0;
     unsigned int llist;
-    unsigned int scriptTag;
     int x;
     unsigned int pos;
 
-    if (scriptName == nullptr) {
-        gsubFeatureTable = 0;
-        return 0;
-    }
-    scriptTag = charToTag(scriptName);
+    const unsigned int scriptTag = charToTag(scriptName);
     /* read GSUB Header */
     if ((x = seekTable("GSUB")) < 0) {
         return 0; /* GSUB table not found */
@@ -1747,14 +1724,12 @@ int FoFiTrueType::setupGSUB(const char *scriptName, const char *languageName)
     /* use default language system */
     pos = gsubTable + scriptList + scriptTable;
     langSys = 0;
-    if (languageName) {
-        unsigned int langTag = charToTag(languageName);
-        unsigned int langCount = getU16BE(pos + 2, &parsedOk);
-        for (i = 0; i < langCount && langSys == 0; i++) {
-            tag = getU32BE(pos + 4 + i * (4 + 2), &parsedOk);
-            if (tag == langTag) {
-                langSys = getU16BE(pos + 4 + i * (4 + 2) + 4, &parsedOk);
-            }
+    const unsigned int langTag = charToTag(languageName);
+    const unsigned int langCount = getU16BE(pos + 2, &parsedOk);
+    for (i = 0; i < langCount && langSys == 0; i++) {
+        tag = getU32BE(pos + 4 + i * (4 + 2), &parsedOk);
+        if (tag == langTag) {
+            langSys = getU16BE(pos + 4 + i * (4 + 2) + 4, &parsedOk);
         }
     }
     if (langSys == 0) {
