@@ -13,13 +13,14 @@
 // All changes made under the Poppler project to this file are licensed
 // under GPL version 2 or later
 //
-// Copyright (C) 2005, 2008, 2010, 2018, 2021-2024 Albert Astals Cid <aacid@kde.org>
+// Copyright (C) 2005, 2008, 2010, 2018, 2021-2025 Albert Astals Cid <aacid@kde.org>
 // Copyright (C) 2005 Kristian Høgsberg <krh@redhat.com>
 // Copyright (C) 2010 Jakub Wilk <jwilk@jwilk.net>
 // Copyright (C) 2014 Carlos Garcia Campos <carlosgc@gnome.org>
 // Copyright (C) 2017 Adrian Johnson <ajohnson@redneon.com>
 // Copyright (C) 2017 Jean Ghali <jghali@libertysurf.fr>
 // Copyright (C) 2022 Oliver Sander <oliver.sander@tu-dresden.de>
+// Copyright (C) 2025 g10 Code GmbH, Author: Sune Stolborg Vuorela <sune@vuorela.dk>
 //
 // To see a description of the changes please see the Changelog file that
 // came with your tarball or type make ChangeLog if you are building from git
@@ -31,26 +32,21 @@
 #include <charconv>
 #include <optional>
 
-#include <cstdlib>
 #include <cstring>
-#include <climits>
-#include "goo/glibc.h"
 #include "goo/gmem.h"
-#include "goo/GooLikely.h"
 #include "FoFiEncodings.h"
 #include "FoFiType1.h"
-#include "poppler/Error.h"
 
 //------------------------------------------------------------------------
 // FoFiType1
 //------------------------------------------------------------------------
 
-FoFiType1 *FoFiType1::make(const unsigned char *fileA, int lenA)
+std::unique_ptr<FoFiType1> FoFiType1::make(std::vector<unsigned char> &&fileA)
 {
-    return new FoFiType1(fileA, lenA, false);
+    return std::make_unique<FoFiType1>(std::move(fileA));
 }
 
-FoFiType1::FoFiType1(const unsigned char *fileA, int lenA, bool freeFileDataA) : FoFiBase(fileA, lenA, freeFileDataA)
+FoFiType1::FoFiType1(std::vector<unsigned char> &&fileA, PrivateTag) : FoFiBase(std::move(fileA))
 {
     encoding = nullptr;
     parsed = false;
@@ -90,15 +86,15 @@ void FoFiType1::writeEncoded(const char **newEncoding, FoFiOutputFunc outputFunc
     int i;
 
     // copy everything up to the encoding
-    for (line = (char *)file; line && (strncmp(line, "/Encoding", 9) != 0); line = getNextLine(line)) {
+    for (line = (char *)file.data(); line && (strncmp(line, "/Encoding", 9) != 0); line = getNextLine(line)) {
         ;
     }
     if (!line) {
         // no encoding - just copy the whole font file
-        (*outputFunc)(outputStream, (char *)file, len);
+        (*outputFunc)(outputStream, (char *)file.data(), file.size());
         return;
     }
-    (*outputFunc)(outputStream, (char *)file, line - (char *)file);
+    (*outputFunc)(outputStream, (char *)file.data(), line - (char *)file.data());
 
     // write the new encoding
     (*outputFunc)(outputStream, "/Encoding 256 array\n", 20);
@@ -120,8 +116,8 @@ void FoFiType1::writeEncoded(const char **newEncoding, FoFiOutputFunc outputFunc
         // then look for 'def' preceded by PostScript whitespace
         p = line + 10;
         line = nullptr;
-        for (; p < (char *)file + len; ++p) {
-            if ((*p == ' ' || *p == '\t' || *p == '\x0a' || *p == '\x0d' || *p == '\x0c' || *p == '\0') && p + 4 <= (char *)file + len && !strncmp(p + 1, "def", 3)) {
+        for (; p < (char *)file.data() + file.size(); ++p) {
+            if ((*p == ' ' || *p == '\t' || *p == '\x0a' || *p == '\x0d' || *p == '\x0c' || *p == '\0') && p + 4 <= (char *)file.data() + file.size() && !strncmp(p + 1, "def", 3)) {
                 line = p + 4;
                 break;
             }
@@ -143,8 +139,8 @@ void FoFiType1::writeEncoded(const char **newEncoding, FoFiOutputFunc outputFunc
                 // then look for 'def' preceded by PostScript whitespace
                 p = line2 + 10;
                 line = nullptr;
-                for (; p < (char *)file + len; ++p) {
-                    if ((*p == ' ' || *p == '\t' || *p == '\x0a' || *p == '\x0d' || *p == '\x0c' || *p == '\0') && p + 4 <= (char *)file + len && !strncmp(p + 1, "def", 3)) {
+                for (; p < (char *)file.data() + file.size(); ++p) {
+                    if ((*p == ' ' || *p == '\t' || *p == '\x0a' || *p == '\x0d' || *p == '\x0c' || *p == '\0') && p + 4 <= (char *)file.data() + file.size() && !strncmp(p + 1, "def", 3)) {
                         line = p + 4;
                         break;
                     }
@@ -154,23 +150,23 @@ void FoFiType1::writeEncoded(const char **newEncoding, FoFiOutputFunc outputFunc
 
         // copy everything after the encoding
         if (line) {
-            (*outputFunc)(outputStream, line, ((char *)file + len) - line);
+            (*outputFunc)(outputStream, line, ((char *)file.data() + file.size()) - line);
         }
     }
 }
 
 char *FoFiType1::getNextLine(char *line) const
 {
-    while (line < (char *)file + len && *line != '\x0a' && *line != '\x0d') {
+    while (line < (char *)file.data() + file.size() && *line != '\x0a' && *line != '\x0d') {
         ++line;
     }
-    if (line < (char *)file + len && *line == '\x0d') {
+    if (line < (char *)file.data() + file.size() && *line == '\x0d') {
         ++line;
     }
-    if (line < (char *)file + len && *line == '\x0a') {
+    if (line < (char *)file.data() + file.size() && *line == '\x0a') {
         ++line;
     }
-    if (line >= (char *)file + len) {
+    if (line >= (char *)file.data() + file.size()) {
         return nullptr;
     }
     return line;
@@ -222,7 +218,7 @@ private:
 
 void FoFiType1::parse()
 {
-    FoFiType1Tokenizer tokenizer(std::string_view(reinterpret_cast<const char *>(file), len));
+    FoFiType1Tokenizer tokenizer(std::string_view(reinterpret_cast<const char *>(file.data()), file.size()));
     while (name.empty() || !encoding) {
         const std::optional<std::string_view> token = tokenizer.getToken();
 
@@ -312,7 +308,6 @@ void FoFiType1::parse()
 void FoFiType1::undoPFB()
 {
     bool ok;
-    unsigned char *file2;
     int pos1, pos2, type;
     unsigned int segLen;
 
@@ -320,7 +315,8 @@ void FoFiType1::undoPFB()
     if (getU8(0, &ok) != 0x80 || !ok) {
         return;
     }
-    file2 = (unsigned char *)gmalloc(len);
+    std::vector<unsigned char> file2;
+    file2.resize(file.size());
     pos1 = pos2 = 0;
     while (getU8(pos1, &ok) == 0x80 && ok) {
         type = getU8(pos1 + 1, &ok);
@@ -332,14 +328,11 @@ void FoFiType1::undoPFB()
         if (!ok || !checkRegion(pos1, segLen)) {
             break;
         }
-        memcpy(file2 + pos2, file + pos1, segLen);
+        memcpy(file2.data() + pos2, file.data() + pos1, segLen);
         pos1 += segLen;
         pos2 += segLen;
     }
-    if (freeFileData) {
-        gfree((char *)file);
-    }
-    file = file2;
-    freeFileData = true;
-    len = pos2;
+    file2.resize(pos2);
+    fileOwner = file2;
+    file = fileOwner;
 }
