@@ -3,6 +3,10 @@
  * Copyright (C) 2007 Inigo Martinez <inigomartinez@gmail.com>
  * Copyright (C) 2009 Carlos Garcia Campos <carlosgc@gnome.org>
  * Copyright (C) 2025 Markus Göllnitz <camelcasenick@bewares.it>
+ * Copyright (C) 2025 Lucas Baudin <lucas.baudin@ensae.fr>
+ * Copyright (C) 2025 Marco Trevisan <mail@3v1n0.net>
+ * Copyright (C) 2025 Aditya Tiwari <suntiwari3495@gmail.com>
+ * Copyright (C) 2026 Maximiliano Sandoval <msandova@protonmail.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -78,6 +82,10 @@ G_BEGIN_DECLS
 #define POPPLER_ANNOT_STAMP(obj) (G_TYPE_CHECK_INSTANCE_CAST((obj), POPPLER_TYPE_ANNOT_STAMP, PopplerAnnotStamp))
 #define POPPLER_IS_ANNOT_STAMP(obj) (G_TYPE_CHECK_INSTANCE_TYPE((obj), POPPLER_TYPE_ANNOT_STAMP))
 
+#define POPPLER_TYPE_ANNOT_INK (poppler_annot_ink_get_type())
+#define POPPLER_ANNOT_INK(obj) (G_TYPE_CHECK_INSTANCE_CAST((obj), POPPLER_TYPE_ANNOT_INK, PopplerAnnotInk))
+#define POPPLER_IS_ANNOT_INK(obj) (G_TYPE_CHECK_INSTANCE_TYPE((obj), POPPLER_TYPE_ANNOT_INK))
+
 typedef enum
 {
     POPPLER_ANNOT_UNKNOWN,
@@ -144,6 +152,48 @@ typedef enum
 #define POPPLER_ANNOT_TEXT_ICON_INSERT "Insert"
 #define POPPLER_ANNOT_TEXT_ICON_CROSS "Cross"
 #define POPPLER_ANNOT_TEXT_ICON_CIRCLE "Circle"
+/**
+ * POPPLER_ANNOT_TEXT_ICON_CHECK:
+ *
+ * Since: 26.01
+ */
+#define POPPLER_ANNOT_TEXT_ICON_CHECK "Check"
+/**
+ * POPPLER_ANNOT_TEXT_ICON_STAR:
+ *
+ * Since: 26.01
+ */
+#define POPPLER_ANNOT_TEXT_ICON_STAR "Star"
+/**
+ * POPPLER_ANNOT_TEXT_ICON_RIGHT_ARROW:
+ *
+ * Since: 26.01
+ */
+#define POPPLER_ANNOT_TEXT_ICON_RIGHT_ARROW "RightArrow"
+/**
+ * POPPLER_ANNOT_TEXT_ICON_RIGHT_POINTER:
+ *
+ * Since: 26.01
+ */
+#define POPPLER_ANNOT_TEXT_ICON_RIGHT_POINTER "RightPointer"
+/**
+ * POPPLER_ANNOT_TEXT_ICON_UP_ARROW:
+ *
+ * Since: 26.01
+ */
+#define POPPLER_ANNOT_TEXT_ICON_UP_ARROW "UpArrow"
+/**
+ * POPPLER_ANNOT_TEXT_ICON_UP_LEFT_ARROW:
+ *
+ * Since: 26.01
+ */
+#define POPPLER_ANNOT_TEXT_ICON_UP_LEFT_ARROW "UpLeftArrow"
+/**
+ * POPPLER_ANNOT_TEXT_ICON_CROSS_HAIRS:
+ *
+ * Since: 26.01
+ */
+#define POPPLER_ANNOT_TEXT_ICON_CROSS_HAIRS "CrossHairs"
 
 typedef enum
 {
@@ -196,6 +246,11 @@ typedef enum
 
 /* The next three enums are value-compatible with pango equivalents. */
 
+/**
+ * PopplerStretch:
+ *
+ * Since: 24.12
+ */
 typedef enum
 {
     POPPLER_STRETCH_ULTRA_CONDENSED,
@@ -209,6 +264,11 @@ typedef enum
     POPPLER_STRETCH_ULTRA_EXPANDED
 } PopplerStretch;
 
+/**
+ * PopplerWeight:
+ *
+ * Since: 24.12
+ */
 typedef enum
 {
     POPPLER_WEIGHT_THIN = 100,
@@ -222,6 +282,11 @@ typedef enum
     POPPLER_WEIGHT_HEAVY = 900
 } PopplerWeight;
 
+/**
+ * PopplerStyle:
+ *
+ * Since: 24.12
+ */
 typedef enum
 {
     POPPLER_STYLE_NORMAL,
@@ -286,7 +351,13 @@ gboolean poppler_annot_get_border_width(PopplerAnnot *poppler_annot, double *wid
 POPPLER_PUBLIC
 void poppler_annot_set_border_width(PopplerAnnot *poppler_annot, double width);
 
-/* PopplerAnnotMarkup */
+/**
+ * PopplerAnnotMarkup:
+ *
+ * An annotation for markup.
+ *
+ * Since 25.06 this type supports g_autoptr
+ */
 POPPLER_PUBLIC
 GType poppler_annot_markup_get_type(void) G_GNUC_CONST;
 POPPLER_PUBLIC
@@ -318,7 +389,13 @@ PopplerAnnotMarkupReplyType poppler_annot_markup_get_reply_to(PopplerAnnotMarkup
 POPPLER_PUBLIC
 PopplerAnnotExternalDataType poppler_annot_markup_get_external_data(PopplerAnnotMarkup *poppler_annot);
 
-/* PopplerAnnotText */
+/**
+ * PopplerAnnotText:
+ *
+ * An annotation for text.
+ *
+ * Since 25.06 this type supports g_autoptr
+ */
 POPPLER_PUBLIC
 GType poppler_annot_text_get_type(void) G_GNUC_CONST;
 POPPLER_PUBLIC
@@ -334,7 +411,13 @@ void poppler_annot_text_set_icon(PopplerAnnotText *poppler_annot, const gchar *i
 POPPLER_PUBLIC
 PopplerAnnotTextState poppler_annot_text_get_state(PopplerAnnotText *poppler_annot);
 
-/* PopplerAnnotTextMarkup */
+/**
+ * PopplerAnnotTextMarkup:
+ *
+ * An annotation for text markup.
+ *
+ * Since 25.06 this type supports g_autoptr
+ */
 POPPLER_PUBLIC
 GType poppler_annot_text_markup_get_type(void) G_GNUC_CONST;
 POPPLER_PUBLIC
@@ -350,7 +433,13 @@ void poppler_annot_text_markup_set_quadrilaterals(PopplerAnnotTextMarkup *popple
 POPPLER_PUBLIC
 GArray *poppler_annot_text_markup_get_quadrilaterals(PopplerAnnotTextMarkup *poppler_annot);
 
-/* PopplerAnnotFreeText */
+/**
+ * PopplerAnnotFreeText:
+ *
+ * An annotation for free text.
+ *
+ * Since 25.06 this type supports g_autoptr
+ */
 POPPLER_PUBLIC
 GType poppler_annot_free_text_get_type(void) G_GNUC_CONST;
 POPPLER_PUBLIC
@@ -378,7 +467,13 @@ void poppler_font_description_free(PopplerFontDescription *font_desc);
 POPPLER_PUBLIC
 PopplerFontDescription *poppler_font_description_copy(PopplerFontDescription *font_desc);
 
-/* PopplerAnnotFileAttachment */
+/**
+ * PopplerAnnotFileAttachment:
+ *
+ * An annotation for file attachment.
+ *
+ * Since 25.06 this type supports g_autoptr
+ */
 POPPLER_PUBLIC
 GType poppler_annot_file_attachment_get_type(void) G_GNUC_CONST;
 POPPLER_PUBLIC
@@ -386,7 +481,13 @@ PopplerAttachment *poppler_annot_file_attachment_get_attachment(PopplerAnnotFile
 POPPLER_PUBLIC
 gchar *poppler_annot_file_attachment_get_name(PopplerAnnotFileAttachment *poppler_annot);
 
-/* PopplerAnnotMovie */
+/**
+ * PopplerAnnotMovie:
+ *
+ * An annotation for movie.
+ *
+ * Since 25.06 this type supports g_autoptr
+ */
 POPPLER_PUBLIC
 GType poppler_annot_movie_get_type(void) G_GNUC_CONST;
 POPPLER_PUBLIC
@@ -394,13 +495,25 @@ gchar *poppler_annot_movie_get_title(PopplerAnnotMovie *poppler_annot);
 POPPLER_PUBLIC
 PopplerMovie *poppler_annot_movie_get_movie(PopplerAnnotMovie *poppler_annot);
 
-/* PopplerAnnotScreen */
+/**
+ * PopplerAnnotScreen:
+ *
+ * An annotation for screen.
+ *
+ * Since 25.06 this type supports g_autoptr
+ */
 POPPLER_PUBLIC
 GType poppler_annot_screen_get_type(void) G_GNUC_CONST;
 POPPLER_PUBLIC
 PopplerAction *poppler_annot_screen_get_action(PopplerAnnotScreen *poppler_annot);
 
-/* PopplerAnnotLine */
+/**
+ * PopplerAnnotLine:
+ *
+ * An annotation for line.
+ *
+ * Since 25.06 this type supports g_autoptr
+ */
 POPPLER_PUBLIC
 GType poppler_annot_line_get_type(void) G_GNUC_CONST;
 POPPLER_PUBLIC
@@ -408,7 +521,13 @@ PopplerAnnot *poppler_annot_line_new(PopplerDocument *doc, PopplerRectangle *rec
 POPPLER_PUBLIC
 void poppler_annot_line_set_vertices(PopplerAnnotLine *poppler_annot, PopplerPoint *start, PopplerPoint *end);
 
-/* PopplerAnnotCalloutLine */
+/**
+ * PopplerAnnotCalloutLine:
+ *
+ * An annotation for callout line.
+ *
+ * Since 25.06 this type supports g_autoptr
+ */
 POPPLER_PUBLIC
 GType poppler_annot_callout_line_get_type(void) G_GNUC_CONST;
 POPPLER_PUBLIC
@@ -418,7 +537,13 @@ PopplerAnnotCalloutLine *poppler_annot_callout_line_copy(PopplerAnnotCalloutLine
 POPPLER_PUBLIC
 void poppler_annot_callout_line_free(PopplerAnnotCalloutLine *callout);
 
-/* PopplerAnnotCircle */
+/**
+ * PopplerAnnotCircle:
+ *
+ * An annotation for circle.
+ *
+ * Since 25.06 this type supports g_autoptr
+ */
 POPPLER_PUBLIC
 GType poppler_annot_circle_get_type(void) G_GNUC_CONST;
 POPPLER_PUBLIC
@@ -428,7 +553,13 @@ void poppler_annot_circle_set_interior_color(PopplerAnnotCircle *poppler_annot,
 POPPLER_PUBLIC
 PopplerColor *poppler_annot_circle_get_interior_color(PopplerAnnotCircle *poppler_annot);
 
-/* PopplerAnnotGeometry */
+/**
+ * PopplerAnnotSquare:
+ *
+ * An annotation for square.
+ *
+ * Since 25.06 this type supports g_autoptr
+ */
 POPPLER_PUBLIC
 GType poppler_annot_square_get_type(void) G_GNUC_CONST;
 POPPLER_PUBLIC
@@ -438,7 +569,13 @@ void poppler_annot_square_set_interior_color(PopplerAnnotSquare *poppler_annot,
 POPPLER_PUBLIC
 PopplerColor *poppler_annot_square_get_interior_color(PopplerAnnotSquare *poppler_annot);
 
-/* PopplerAnnotStamp */
+/**
+ * PopplerAnnotStamp:
+ *
+ * An annotation for stamp.
+ *
+ * Since 25.06 this type supports g_autoptr
+ */
 POPPLER_PUBLIC
 GType poppler_annot_stamp_get_type(void) G_GNUC_CONST;
 POPPLER_PUBLIC
@@ -450,8 +587,47 @@ void poppler_annot_stamp_set_icon(PopplerAnnotStamp *poppler_annot, PopplerAnnot
 POPPLER_PUBLIC
 gboolean poppler_annot_stamp_set_custom_image(PopplerAnnotStamp *poppler_annot, cairo_surface_t *image, GError **error);
 
+/* Paths of PopplerAnnotInk */
+POPPLER_PUBLIC
+GType poppler_path_get_type(void) G_GNUC_CONST;
+POPPLER_PUBLIC
+PopplerPath *poppler_path_new_from_array(PopplerPoint *points, gsize n_points);
+POPPLER_PUBLIC
+void poppler_path_free(PopplerPath *path);
+POPPLER_PUBLIC
+PopplerPath *poppler_path_copy(PopplerPath *path);
+POPPLER_PUBLIC
+PopplerPoint *poppler_path_get_points(PopplerPath *path, gsize *n_points);
+/* PopplerAnnotInk */
+POPPLER_PUBLIC
+GType poppler_annot_ink_get_type(void) G_GNUC_CONST;
+POPPLER_PUBLIC
+PopplerAnnot *poppler_annot_ink_new(PopplerDocument *doc, PopplerRectangle *rect);
+POPPLER_PUBLIC
+void poppler_annot_ink_set_ink_list(PopplerAnnotInk *annot, PopplerPath **ink_list, gsize n_paths);
+POPPLER_PUBLIC
+PopplerPath **poppler_annot_ink_get_ink_list(PopplerAnnotInk *annot, gsize *n_paths);
+POPPLER_PUBLIC
+void poppler_annot_ink_set_draw_below(PopplerAnnotInk *annot, gboolean draw_below);
+POPPLER_PUBLIC
+gboolean poppler_annot_ink_get_draw_below(PopplerAnnotInk *annot);
+
 G_END_DECLS
 
+G_DEFINE_AUTOPTR_CLEANUP_FUNC(PopplerAnnot, g_object_unref)
+G_DEFINE_AUTOPTR_CLEANUP_FUNC(PopplerAnnotCircle, g_object_unref)
+G_DEFINE_AUTOPTR_CLEANUP_FUNC(PopplerAnnotFileAttachment, g_object_unref)
+G_DEFINE_AUTOPTR_CLEANUP_FUNC(PopplerAnnotFreeText, g_object_unref)
+G_DEFINE_AUTOPTR_CLEANUP_FUNC(PopplerAnnotLine, g_object_unref)
+G_DEFINE_AUTOPTR_CLEANUP_FUNC(PopplerAnnotMarkup, g_object_unref)
+G_DEFINE_AUTOPTR_CLEANUP_FUNC(PopplerAnnotMovie, g_object_unref)
+G_DEFINE_AUTOPTR_CLEANUP_FUNC(PopplerAnnotScreen, g_object_unref)
+G_DEFINE_AUTOPTR_CLEANUP_FUNC(PopplerAnnotSquare, g_object_unref)
+G_DEFINE_AUTOPTR_CLEANUP_FUNC(PopplerAnnotStamp, g_object_unref)
+G_DEFINE_AUTOPTR_CLEANUP_FUNC(PopplerAnnotText, g_object_unref)
+G_DEFINE_AUTOPTR_CLEANUP_FUNC(PopplerAnnotTextMarkup, g_object_unref)
+G_DEFINE_AUTOPTR_CLEANUP_FUNC(PopplerAnnotCalloutLine, poppler_annot_callout_line_free)
 G_DEFINE_AUTOPTR_CLEANUP_FUNC(PopplerFontDescription, poppler_font_description_free)
+G_DEFINE_AUTOPTR_CLEANUP_FUNC(PopplerPath, poppler_path_free)
 
 #endif /* __POPPLER_ANNOT_H__ */
