@@ -7,6 +7,8 @@
  * Copyright (C) 2021, 2023 Marek Kasik <mkasik@redhat.com>
  * Copyright (C) 2023-2025 g10 Code GmbH, Author: Sune Stolborg Vuorela <sune@vuorela.dk>
  * Copyright (C) 2025 Jan-Michael Brummer <jan-michael.brummer1@volkswagen.de>
+ * Copyright (C) 2025 lbaudin <lbaudin@gnome.org>
+ * Copyright (C) 2025 Albert Astals Cid <aacid@kde.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -29,7 +31,7 @@
 #include "poppler-private.h"
 
 #include <CertificateInfo.h>
-#ifdef ENABLE_NSS3
+#if ENABLE_NSS3
 #    include <NSSCryptoSignBackend.h>
 #endif
 #include <CryptoSignBackend.h>
@@ -65,7 +67,7 @@ static void poppler_form_field_finalize(GObject *object)
     G_OBJECT_CLASS(poppler_form_field_parent_class)->finalize(object);
 }
 
-static void poppler_form_field_init(PopplerFormField *field) { }
+static void poppler_form_field_init(PopplerFormField * /*field*/) { }
 
 static void poppler_form_field_class_init(PopplerFormFieldClass *klass)
 {
@@ -452,7 +454,7 @@ static PopplerSignatureInfo *_poppler_form_field_signature_validate(PopplerFormF
 
     sig_field = static_cast<FormFieldSignature *>(field->widget->getField());
 
-    sig_info = sig_field->validateSignatureAsync(flags & POPPLER_SIGNATURE_VALIDATION_FLAG_VALIDATE_CERTIFICATE, force_revalidation, -1, flags & POPPLER_SIGNATURE_VALIDATION_FLAG_WITHOUT_OCSP_REVOCATION_CHECK,
+    sig_info = sig_field->validateSignatureAsync(flags & POPPLER_SIGNATURE_VALIDATION_FLAG_VALIDATE_CERTIFICATE, force_revalidation, -1, !(flags & POPPLER_SIGNATURE_VALIDATION_FLAG_WITHOUT_OCSP_REVOCATION_CHECK),
                                                  flags & POPPLER_SIGNATURE_VALIDATION_FLAG_USE_AIA_CERTIFICATE_FETCH, {});
     CertificateValidationStatus certificateStatus = sig_field->validateSignatureResult();
 
@@ -529,7 +531,7 @@ static PopplerSignatureInfo *_poppler_form_field_signature_validate(PopplerFormF
     return poppler_sig_info;
 }
 
-static void signature_validate_thread(GTask *task, gpointer source_object, gpointer task_data, GCancellable *cancellable)
+static void signature_validate_thread(GTask *task, gpointer source_object, gpointer task_data, GCancellable * /*cancellable*/)
 {
     PopplerSignatureValidationFlags flags = (PopplerSignatureValidationFlags)GPOINTER_TO_INT(task_data);
     PopplerSignatureInfo *signature_info;
@@ -2275,7 +2277,7 @@ PopplerCertificateInfo *poppler_get_certificate_info_by_id(const char *id)
  **/
 void poppler_set_nss_dir(const char *path)
 {
-#ifdef ENABLE_NSS3
+#if ENABLE_NSS3
     NSSSignatureConfiguration::setNSSDir(GooString(path));
 #else
     (void)path;
@@ -2293,7 +2295,7 @@ void poppler_set_nss_dir(const char *path)
  **/
 char *poppler_get_nss_dir(void)
 {
-#ifdef ENABLE_NSS3
+#if ENABLE_NSS3
     return g_strdup(NSSSignatureConfiguration::getNSSDir().c_str());
 #else
     return nullptr;
@@ -2310,7 +2312,7 @@ char *poppler_get_nss_dir(void)
  **/
 void poppler_set_nss_password_callback(PopplerNssPasswordFunc func)
 {
-#ifdef ENABLE_NSS3
+#if ENABLE_NSS3
     NSSSignatureConfiguration::setNSSPasswordCallback(func);
 #else
     g_warning("poppler_set_nss_password_callback called but this poppler is built without NSS support");
