@@ -1,7 +1,8 @@
 /* poppler-structure.cc: glib interface to poppler
  *
  * Copyright (C) 2013 Igalia S.L.
- * Copyright (C) 2018 Albert Astals Cid <aacid@kde.org>
+ * Copyright (C) 2018, 2025 Albert Astals Cid <aacid@kde.org>
+ * Copyright (C) 2025 g10 Code GmbH, Author: Sune Stolborg Vuorela <sune@vuorela.dk>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -65,7 +66,7 @@ static PopplerStructureElement *_poppler_structure_element_new(PopplerDocument *
     return poppler_structure_element;
 }
 
-static void poppler_structure_element_init(PopplerStructureElement *poppler_structure_element) { }
+static void poppler_structure_element_init(PopplerStructureElement * /*poppler_structure_element*/) { }
 
 static void poppler_structure_element_finalize(GObject *object)
 {
@@ -792,7 +793,7 @@ enum
 static PopplerTextSpan *text_span_poppler_text_span(const TextSpan &span)
 {
     PopplerTextSpan *new_span = g_slice_new0(PopplerTextSpan);
-    if (GooString *text = span.getText()) {
+    if (const GooString *text = span.getText()) {
         new_span->text = _poppler_goo_string_to_utf8(text);
     }
 
@@ -806,11 +807,14 @@ static PopplerTextSpan *text_span_poppler_text_span(const TextSpan &span)
         const GooString *font_name = span.getFont()->getFamily();
         if (font_name) {
             new_span->font_name = _poppler_goo_string_to_utf8(font_name);
-        } else if (span.getFont()->getName()) {
-            const GooString aux(*span.getFont()->getName());
-            new_span->font_name = _poppler_goo_string_to_utf8(&aux);
         } else {
-            new_span->font_name = nullptr;
+            const std::optional<std::string> &fontName = span.getFont()->getName();
+            if (fontName) {
+                const GooString aux(*fontName);
+                new_span->font_name = _poppler_goo_string_to_utf8(&aux);
+            } else {
+                new_span->font_name = nullptr;
+            }
         }
 
         if (span.getFont()->isFixedWidth()) {
