@@ -19,7 +19,7 @@
 // Copyright (C) 2006 Kristian Høgsberg <krh@redhat.com>
 // Copyright (C) 2008 Adam Batkin <adam@batkin.net>
 // Copyright (C) 2008, 2010, 2012, 2013 Hib Eris <hib@hiberis.nl>
-// Copyright (C) 2009, 2012, 2014, 2017, 2018, 2021, 2022 Albert Astals Cid <aacid@kde.org>
+// Copyright (C) 2009, 2012, 2014, 2017, 2018, 2021, 2022, 2024, 2025 Albert Astals Cid <aacid@kde.org>
 // Copyright (C) 2009 Kovid Goyal <kovid@kovidgoyal.net>
 // Copyright (C) 2013, 2018 Adam Reichold <adamreichold@myopera.com>
 // Copyright (C) 2013, 2017 Adrian Johnson <ajohnson@redneon.com>
@@ -28,6 +28,7 @@
 // Copyright (C) 2017 Christoph Cullmann <cullmann@kde.org>
 // Copyright (C) 2018 Mojca Miklavec <mojca@macports.org>
 // Copyright (C) 2019, 2021 Christian Persch <chpe@src.gnome.org>
+// Copyright (C) 2025 g10 Code GmbH, Author: Sune Stolborg Vuorela <sune@vuorela.dk>
 //
 // To see a description of the changes please see the Changelog file that
 // came with your tarball or type make ChangeLog if you are building from git
@@ -40,7 +41,6 @@
 #    include <sys/types.h>
 #    include <sys/stat.h>
 #    include <fcntl.h>
-#    include <climits>
 #    include <cstring>
 #    include <pwd.h>
 #endif // _WIN32
@@ -48,7 +48,6 @@
 #include <limits>
 #include "GooString.h"
 #include "gfile.h"
-#include "gdir.h"
 
 // Some systems don't define this, so just make it something reasonably
 // large.
@@ -99,15 +98,13 @@ GooString *appendToPath(GooString *path, const char *fileName)
 {
 #ifdef _WIN32
     //---------- Win32 ----------
-    GooString *tmp;
     char buf[256];
     char *fp;
 
-    tmp = new GooString(path);
+    auto tmp = path->copy();
     tmp->append('/');
     tmp->append(fileName);
     GetFullPathNameA(tmp->c_str(), sizeof(buf), buf, &fp);
-    delete tmp;
     path->clear();
     path->append(buf);
     return path;
@@ -117,51 +114,55 @@ GooString *appendToPath(GooString *path, const char *fileName)
     int i;
 
     // appending "." does nothing
-    if (!strcmp(fileName, "."))
+    if (!strcmp(fileName, ".")) {
         return path;
+    }
 
     // appending ".." goes up one directory
     if (!strcmp(fileName, "..")) {
-        for (i = path->getLength() - 2; i >= 0; --i) {
-            if (path->getChar(i) == '/')
+        for (i = path->size() - 2; i >= 0; --i) {
+            if (path->getChar(i) == '/') {
                 break;
+            }
         }
         if (i <= 0) {
             if (path->getChar(0) == '/') {
-                path->del(1, path->getLength() - 1);
+                path->erase(1, path->size() - 1);
             } else {
                 path->clear();
                 path->append("..");
             }
         } else {
-            path->del(i, path->getLength() - i);
+            path->erase(i, path->size() - i);
         }
         return path;
     }
 
     // otherwise, append "/" and new path component
-    if (path->getLength() > 0 && path->getChar(path->getLength() - 1) != '/')
+    if (!path->empty() && path->getChar(path->size() - 1) != '/') {
         path->append('/');
+    }
     path->append(fileName);
     return path;
 #endif
 }
 
+#ifndef _WIN32
+
 static bool makeFileDescriptorCloexec(int fd)
 {
-#ifdef FD_CLOEXEC
+#    ifdef FD_CLOEXEC
     int flags = fcntl(fd, F_GETFD);
-    if (flags >= 0 && !(flags & FD_CLOEXEC))
+    if (flags >= 0 && !(flags & FD_CLOEXEC)) {
         flags = fcntl(fd, F_SETFD, flags | FD_CLOEXEC);
+    }
 
     return flags >= 0;
-#else
+#    else
     return true;
-#endif
+#    endif
 }
 
-#ifndef _WIN32
-
 int openFileDescriptor(const char *path, int flags)
 {
 #    ifdef O_CLOEXEC
@@ -234,13 +235,15 @@ FILE *openFile(const char *path, const char *mode)
     // First try to atomically open the file with CLOEXEC
     const std::string modeStr = mode + "e"s;
     FILE *file = fopen(path, modeStr.c_str());
-    if (file != nullptr)
+    if (file != nullptr) {
         return file;
+    }
 
     // Fall back to the provided mode and apply CLOEXEC afterwards
     file = fopen(path, mode);
-    if (file == nullptr)
+    if (file == nullptr) {
         return nullptr;
+    }
 
     if (!makeFileDescriptorCloexec(fileno(file))) {
         fclose(file);
@@ -283,9 +286,9 @@ char *getLine(char *buf, int size, FILE *f)
 
 int Gfseek(FILE *f, Goffset offset, int whence)
 {
-#if defined(HAVE_FSEEKO)
+#if HAVE_FSEEKO
     return fseeko(f, offset, whence);
-#elif defined(HAVE_FSEEK64)
+#elif HAVE_FSEEK64
     return fseek64(f, offset, whence);
 #elif defined(__MINGW32__)
     return fseeko64(f, offset, whence);
@@ -298,9 +301,9 @@ int Gfseek(FILE *f, Goffset offset, int whence)
 
 Goffset Gftell(FILE *f)
 {
-#if defined(HAVE_FSEEKO)
+#if HAVE_FSEEKO
     return ftello(f);
-#elif defined(HAVE_FSEEK64)
+#elif HAVE_FSEEK64
     return ftell64(f);
 #elif defined(__MINGW32__)
     return ftello64(f);
@@ -313,9 +316,9 @@ Goffset Gftell(FILE *f)
 
 Goffset GoffsetMax()
 {
-#if defined(HAVE_FSEEKO)
+#if HAVE_FSEEKO
     return (std::numeric_limits<off_t>::max)();
-#elif defined(HAVE_FSEEK64) || defined(__MINGW32__)
+#elif HAVE_FSEEK64 || defined(__MINGW32__)
     return (std::numeric_limits<off64_t>::max)();
 #elif defined(_WIN32)
     return (std::numeric_limits<__int64>::max)();
@@ -358,18 +361,18 @@ Goffset GooFile::size() const
     return size.QuadPart;
 }
 
-GooFile *GooFile::open(const std::string &fileName)
+std::unique_ptr<GooFile> GooFile::open(const std::string &fileName)
 {
     HANDLE handle = CreateFileA(fileName.c_str(), GENERIC_READ, FILE_SHARE_READ | FILE_SHARE_WRITE, nullptr, OPEN_EXISTING, FILE_ATTRIBUTE_NORMAL, nullptr);
 
-    return handle == INVALID_HANDLE_VALUE ? nullptr : new GooFile(handle);
+    return handle == INVALID_HANDLE_VALUE ? std::unique_ptr<GooFile>() : std::unique_ptr<GooFile>(new GooFile(handle));
 }
 
-GooFile *GooFile::open(const wchar_t *fileName)
+std::unique_ptr<GooFile> GooFile::open(const wchar_t *fileName)
 {
     HANDLE handle = CreateFileW(fileName, GENERIC_READ, FILE_SHARE_READ | FILE_SHARE_WRITE, nullptr, OPEN_EXISTING, FILE_ATTRIBUTE_NORMAL, nullptr);
 
-    return handle == INVALID_HANDLE_VALUE ? nullptr : new GooFile(handle);
+    return handle == INVALID_HANDLE_VALUE ? std::unique_ptr<GooFile>() : std::unique_ptr<GooFile>(new GooFile(handle));
 }
 
 bool GooFile::modificationTimeChangedSinceOpen() const
@@ -384,7 +387,7 @@ bool GooFile::modificationTimeChangedSinceOpen() const
 
 int GooFile::read(char *buf, int n, Goffset offset) const
 {
-#    ifdef HAVE_PREAD64
+#    if HAVE_PREAD64
     return pread64(fd, buf, n, offset);
 #    else
     return pread(fd, buf, n, offset);
@@ -393,23 +396,23 @@ int GooFile::read(char *buf, int n, Goffset offset) const
 
 Goffset GooFile::size() const
 {
-#    ifdef HAVE_LSEEK64
+#    if HAVE_LSEEK64
     return lseek64(fd, 0, SEEK_END);
 #    else
     return lseek(fd, 0, SEEK_END);
 #    endif
 }
 
-GooFile *GooFile::open(const std::string &fileName)
+std::unique_ptr<GooFile> GooFile::open(const std::string &fileName)
 {
     int fd = openFileDescriptor(fileName.c_str(), O_RDONLY);
 
     return GooFile::open(fd);
 }
 
-GooFile *GooFile::open(int fdA)
+std::unique_ptr<GooFile> GooFile::open(int fdA)
 {
-    return fdA < 0 ? nullptr : new GooFile(fdA);
+    return fdA < 0 ? std::unique_ptr<GooFile>() : std::unique_ptr<GooFile>(new GooFile(fdA));
 }
 
 GooFile::GooFile(int fdA) : fd(fdA)
@@ -428,109 +431,3 @@ bool GooFile::modificationTimeChangedSinceOpen() const
 }
 
 #endif // _WIN32
-
-//------------------------------------------------------------------------
-// GDir and GDirEntry
-//------------------------------------------------------------------------
-
-GDirEntry::GDirEntry(const char *dirPath, const char *nameA, bool doStat)
-{
-#ifdef _WIN32
-    DWORD fa;
-#else
-    struct stat st;
-#endif
-
-    name = new GooString(nameA);
-    dir = false;
-    fullPath = new GooString(dirPath);
-    appendToPath(fullPath, nameA);
-    if (doStat) {
-#ifdef _WIN32
-        fa = GetFileAttributesA(fullPath->c_str());
-        dir = (fa != 0xFFFFFFFF && (fa & FILE_ATTRIBUTE_DIRECTORY));
-#else
-        if (stat(fullPath->c_str(), &st) == 0)
-            dir = S_ISDIR(st.st_mode);
-#endif
-    }
-}
-
-GDirEntry::~GDirEntry()
-{
-    delete fullPath;
-    delete name;
-}
-
-GDir::GDir(const char *name, bool doStatA)
-{
-    path = new GooString(name);
-    doStat = doStatA;
-#ifdef _WIN32
-    GooString *tmp;
-
-    tmp = path->copy();
-    tmp->append("/*.*");
-    hnd = FindFirstFileA(tmp->c_str(), &ffd);
-    delete tmp;
-#else
-    dir = opendir(name);
-#endif
-}
-
-GDir::~GDir()
-{
-    delete path;
-#ifdef _WIN32
-    if (hnd != INVALID_HANDLE_VALUE) {
-        FindClose(hnd);
-        hnd = INVALID_HANDLE_VALUE;
-    }
-#else
-    if (dir)
-        closedir(dir);
-#endif
-}
-
-std::unique_ptr<GDirEntry> GDir::getNextEntry()
-{
-#ifdef _WIN32
-    if (hnd != INVALID_HANDLE_VALUE) {
-        auto e = std::make_unique<GDirEntry>(path->c_str(), ffd.cFileName, doStat);
-        if (!FindNextFileA(hnd, &ffd)) {
-            FindClose(hnd);
-            hnd = INVALID_HANDLE_VALUE;
-        }
-        return e;
-    }
-#else
-    struct dirent *ent;
-    if (dir) {
-        do {
-            ent = readdir(dir);
-        } while (ent && (!strcmp(ent->d_name, ".") || !strcmp(ent->d_name, "..")));
-        if (ent) {
-            return std::make_unique<GDirEntry>(path->c_str(), ent->d_name, doStat);
-        }
-    }
-#endif
-
-    return {};
-}
-
-void GDir::rewind()
-{
-#ifdef _WIN32
-    GooString *tmp;
-
-    if (hnd != INVALID_HANDLE_VALUE)
-        FindClose(hnd);
-    tmp = path->copy();
-    tmp->append("/*.*");
-    hnd = FindFirstFileA(tmp->c_str(), &ffd);
-    delete tmp;
-#else
-    if (dir)
-        rewinddir(dir);
-#endif
-}
