@@ -3,7 +3,7 @@
 // AnnotStampImageHelper.cc
 //
 // Copyright (C) 2021 Mahmoud Ahmed Khalil <mahmoudkhalil11@gmail.com>
-// Copyright (C) 2021 Albert Astals Cid <aacid@kde.org>
+// Copyright (C) 2021, 2025 Albert Astals Cid <aacid@kde.org>
 // Copyright (C) 2025 g10 Code GmbH, Author: Sune Stolborg Vuorela <sune@vuorela.dk>
 //
 // Licensed under GPLv2 or later
@@ -12,14 +12,10 @@
 
 #include "AnnotStampImageHelper.h"
 
-#include "goo/gmem.h"
-#include "goo/gstrtod.h"
 #include "PDFDoc.h"
 #include "Stream.h"
 #include "Dict.h"
 
-#include <iostream>
-
 AnnotStampImageHelper::AnnotStampImageHelper(PDFDoc *docA, int widthA, int heightA, ColorSpace colorSpace, int bitsPerComponent, char *data, int dataLength)
 {
     initialize(docA, widthA, heightA, colorSpace, bitsPerComponent, data, dataLength);
@@ -64,8 +60,8 @@ void AnnotStampImageHelper::initialize(PDFDoc *docA, int widthA, int heightA, Co
 
     std::vector<char> dataCopied { data, data + dataLength };
 
-    Stream *dataStream = new AutoFreeMemStream(std::move(dataCopied), Object(dict));
-    imgObj = Object(dataStream);
+    auto dataStream = std::make_unique<AutoFreeMemStream>(std::move(dataCopied), Object(dict));
+    imgObj = Object(std::move(dataStream));
     ref = doc->getXRef()->addIndirectObject(imgObj);
 }
 
