@@ -18,16 +18,18 @@
 // Copyright (C) 2005, 2006 Kristian Høgsberg <krh@redhat.com>
 // Copyright (C) 2005 Nickolay V. Shmyrev <nshmyrev@yandex.ru>
 // Copyright (C) 2006-2011, 2013 Carlos Garcia Campos <carlosgc@gnome.org>
-// Copyright (C) 2008, 2009, 2011-2017, 2022, 2023 Adrian Johnson <ajohnson@redneon.com>
+// Copyright (C) 2008, 2009, 2011-2017, 2022-2024 Adrian Johnson <ajohnson@redneon.com>
 // Copyright (C) 2008 Michael Vrable <mvrable@cs.ucsd.edu>
 // Copyright (C) 2010-2013 Thomas Freitag <Thomas.Freitag@alfa.de>
 // Copyright (C) 2015 Suzuki Toshiya <mpsuzuki@hiroshima-u.ac.jp>
 // Copyright (C) 2016 Jason Crain <jason@aquaticape.us>
-// Copyright (C) 2018, 2019, 2021 Albert Astals Cid <aacid@kde.org>
+// Copyright (C) 2018, 2019, 2021, 2025 Albert Astals Cid <aacid@kde.org>
 // Copyright (C) 2018 Klarälvdalens Datakonsult AB, a KDAB Group company, <info@kdab.com>. Work sponsored by the LiMux project of the city of Munich
 // Copyright (C) 2020 Michal <sudolskym@gmail.com>
 // Copyright (C) 2021 Christian Persch <chpe@src.gnome.org>
 // Copyright (C) 2022 Marek Kasik <mkasik@redhat.com>
+// Copyright (C) 2024 Nelson Benítez León <nbenitezl@gmail.com>
+// Copyright (C) 2025 g10 Code GmbH, Author: Sune Stolborg Vuorela <sune@vuorela.dk>
 //
 // To see a description of the changes please see the Changelog file that
 // came with your tarball or type make ChangeLog if you are building from git
@@ -37,10 +39,16 @@
 #ifndef CAIROOUTPUTDEV_H
 #define CAIROOUTPUTDEV_H
 
+#include <unordered_set>
+
 #include <cairo-ft.h>
 #include "OutputDev.h"
 #include "TextOutputDev.h"
 #include "GfxState.h"
+#include "StructElement.h"
+#include "StructTreeRoot.h"
+#include "Annot.h"
+#include "Link.h"
 
 class PDFDoc;
 class GfxState;
@@ -118,37 +126,18 @@ public:
     // Does this device use functionShadedFill(), axialShadedFill(), and
     // radialShadedFill()?  If this returns false, these shaded fills
     // will be reduced to a series of other drawing operations.
-#if CAIRO_VERSION >= CAIRO_VERSION_ENCODE(1, 12, 0)
-    bool useShadedFills(int type) override
-    {
-        return type <= 7;
-    }
-#else
-    bool useShadedFills(int type) override
-    {
-        return type > 1 && type < 4;
-    }
-#endif
+    bool useShadedFills(int type) override { return type <= 7; }
 
     // Does this device use FillColorStop()?
-    bool useFillColorStop() override
-    {
-        return true;
-    }
+    bool useFillColorStop() override { return true; }
 
     // Does this device use beginType3Char/endType3Char?  Otherwise,
     // text in Type 3 fonts will be drawn with drawChar/drawString.
-    bool interpretType3Chars() override
-    {
-        return false;
-    }
+    bool interpretType3Chars() override { return false; }
 
     // Does this device need to clip pages to the crop box even when the
     // box is the crop box?
-    bool needClipToCropBox() override
-    {
-        return true;
-    }
+    bool needClipToCropBox() override { return true; }
 
     //----- initialization and control
 
@@ -158,6 +147,12 @@ public:
     // End a page.
     void endPage() override;
 
+    // Must be called before last call to endPage()
+    void emitStructTree();
+
+    void beginForm(Object *obj, Ref id) override;
+    void endForm(Object *obj, Ref id) override;
+
     //----- save/restore graphics state
     void saveState(GfxState *state) override;
     void restoreState(GfxState *state) override;
@@ -187,18 +182,14 @@ public:
     void fill(GfxState *state) override;
     void eoFill(GfxState *state) override;
     void clipToStrokePath(GfxState *state) override;
-    bool tilingPatternFill(GfxState *state, Gfx *gfx, Catalog *cat, GfxTilingPattern *tPat, const double *mat, int x0, int y0, int x1, int y1, double xStep, double yStep) override;
-#if CAIRO_VERSION >= CAIRO_VERSION_ENCODE(1, 12, 0)
+    bool tilingPatternFill(GfxState *state, Gfx *gfx, Catalog *cat, GfxTilingPattern *tPat, const std::array<double, 6> &mat, int x0, int y0, int x1, int y1, double xStep, double yStep) override;
     bool functionShadedFill(GfxState *state, GfxFunctionShading *shading) override;
-#endif
     bool axialShadedFill(GfxState *state, GfxAxialShading *shading, double tMin, double tMax) override;
     bool axialShadedSupportExtend(GfxState *state, GfxAxialShading *shading) override;
     bool radialShadedFill(GfxState *state, GfxRadialShading *shading, double sMin, double sMax) override;
     bool radialShadedSupportExtend(GfxState *state, GfxRadialShading *shading) override;
-#if CAIRO_VERSION >= CAIRO_VERSION_ENCODE(1, 12, 0)
     bool gouraudTriangleShadedFill(GfxState *state, GfxGouraudTriangleShading *shading) override;
     bool patchMeshShadedFill(GfxState *state, GfxPatchMeshShading *shading) override;
-#endif
 
     //----- path clipping
     void clip(GfxState *state) override;
@@ -216,12 +207,14 @@ public:
     void beginTextObject(GfxState *state) override;
     void endTextObject(GfxState *state) override;
 
+    void beginMarkedContent(const char *name, Dict *properties) override;
+    void endMarkedContent(GfxState *state) override;
+
     //----- image drawing
     void drawImageMask(GfxState *state, Object *ref, Stream *str, int width, int height, bool invert, bool interpolate, bool inlineImg) override;
     void setSoftMaskFromImageMask(GfxState *state, Object *ref, Stream *str, int width, int height, bool invert, bool inlineImg, double *baseMatrix) override;
     void unsetSoftMaskFromImageMask(GfxState *state, double *baseMatrix) override;
-    void drawImageMaskPrescaled(GfxState *state, Object *ref, Stream *str, int width, int height, bool invert, bool interpolate, bool inlineImg);
-    void drawImageMaskRegular(GfxState *state, Object *ref, Stream *str, int width, int height, bool invert, bool interpolate, bool inlineImg);
+    void drawImageMaskRegular(GfxState *state, Stream *str, int width, int height, bool invert, bool interpolate);
 
     void drawImage(GfxState *state, Object *ref, Stream *str, int width, int height, GfxImageColorMap *colorMap, bool interpolate, const int *maskColors, bool inlineImg) override;
     void drawSoftMaskedImage(GfxState *state, Object *ref, Stream *str, int width, int height, GfxImageColorMap *colorMap, bool interpolate, Stream *maskStr, int maskWidth, int maskHeight, GfxImageColorMap *maskColorMap,
@@ -229,12 +222,15 @@ public:
 
     void drawMaskedImage(GfxState *state, Object *ref, Stream *str, int width, int height, GfxImageColorMap *colorMap, bool interpolate, Stream *maskStr, int maskWidth, int maskHeight, bool maskInvert, bool maskInterpolate) override;
 
+    // Does this device supports transparency (alpha channel) in JPX streams?
+    bool supportJPXtransparency() override { return true; }
+
     //----- transparency groups and soft masks
-    void beginTransparencyGroup(GfxState * /*state*/, const double * /*bbox*/, GfxColorSpace * /*blendingColorSpace*/, bool /*isolated*/, bool /*knockout*/, bool /*forSoftMask*/) override;
+    void beginTransparencyGroup(GfxState * /*state*/, const std::array<double, 4> & /*bbox*/, GfxColorSpace * /*blendingColorSpace*/, bool /*isolated*/, bool /*knockout*/, bool /*forSoftMask*/) override;
     void endTransparencyGroup(GfxState * /*state*/) override;
     void popTransparencyGroup();
-    void paintTransparencyGroup(GfxState * /*state*/, const double * /*bbox*/) override;
-    void setSoftMask(GfxState * /*state*/, const double * /*bbox*/, bool /*alpha*/, Function * /*transferFunc*/, GfxColor * /*backdropColor*/) override;
+    void paintTransparencyGroup(GfxState * /*state*/, const std::array<double, 4> & /*bbox*/) override;
+    void setSoftMask(GfxState * /*state*/, const std::array<double, 4> & /*bbox*/, bool /*alpha*/, Function * /*transferFunc*/, GfxColor * /*backdropColor*/) override;
     void clearSoftMask(GfxState * /*state*/) override;
 
     //----- Type 3 font operators
@@ -247,12 +243,9 @@ public:
     void startDoc(PDFDoc *docA, CairoFontEngine *fontEngine = nullptr);
 
     // Called to prepare this output dev for rendering CairoType3Font.
-    void startType3Render(GfxState *state, XRef *xref);
+    void startType3Render(XRef *xref);
 
-    bool isReverseVideo()
-    {
-        return false;
-    }
+    bool isReverseVideo() { return false; }
 
     void setCairo(cairo_t *cr);
     void setTextPage(TextPage *text);
@@ -262,6 +255,7 @@ public:
         needFontUpdate = true;
     }
     void copyAntialias(cairo_t *cr, cairo_t *source_cr);
+    void setLogicalStructure(bool logStruct) { this->logicalStruct = logStruct; }
 
     enum Type3RenderType
     {
@@ -269,43 +263,40 @@ public:
         Type3RenderMask,
         Type3RenderColor
     };
-    void setType3RenderType(Type3RenderType state)
-    {
-        t3_render_state = state;
-    }
+    void setType3RenderType(Type3RenderType state) { t3_render_state = state; }
     void getType3GlyphWidth(double *wx, double *wy)
     {
         *wx = t3_glyph_wx;
         *wy = t3_glyph_wy;
     }
-    bool hasType3GlyphBBox()
-    {
-        return t3_glyph_has_bbox;
-    }
-    double *getType3GlyphBBox()
-    {
-        return t3_glyph_bbox;
-    }
-    bool type3GlyphHasColor()
-    {
-        return t3_glyph_has_color;
-    }
+    bool hasType3GlyphBBox() { return t3_glyph_has_bbox; }
+    double *getType3GlyphBBox() { return t3_glyph_bbox; }
+    bool type3GlyphHasColor() { return t3_glyph_has_color; }
 
 protected:
-    void doPath(cairo_t *cairo, GfxState *state, const GfxPath *path);
+    void doPath(cairo_t *cairo, const GfxPath *path);
     cairo_surface_t *downscaleSurface(cairo_surface_t *orig_surface);
     void getScaledSize(const cairo_matrix_t *matrix, int orig_width, int orig_height, int *scaledWidth, int *scaledHeight);
     cairo_filter_t getFilterForSurface(cairo_surface_t *image, bool interpolate);
     bool getStreamData(Stream *str, char **buffer, int *length);
     void setMimeData(GfxState *state, Stream *str, Object *ref, GfxImageColorMap *colorMap, cairo_surface_t *image, int height);
-    void fillToStrokePathClip(GfxState *state);
+    void fillToStrokePathClip();
     void alignStrokeCoords(const GfxSubpath *subpath, int i, double *x, double *y);
-#if CAIRO_VERSION >= CAIRO_VERSION_ENCODE(1, 14, 0)
+    AnnotLink *findLinkObject(const StructElement *elem);
+    void quadToCairoRect(AnnotQuadrilaterals *quads, int idx, double destPageHeight, cairo_rectangle_t *rect);
+    bool appendLinkDestRef(GooString *s, const LinkDest *dest);
+    void appendLinkDestXY(GooString *s, const LinkDest *dest, double destPageHeight);
+    bool beginLinkTag(AnnotLink *annotLink);
+    bool beginLink(const StructElement *linkElem);
+    void getStructElemAttributeString(const StructElement *elem);
+    int getContentElementStructParents(const StructElement *element);
+    bool checkIfStructElementNeeded(const StructElement *element);
+    void emitStructElement(const StructElement *elem);
+    void startFirstPage(XRef *xrefA);
     bool setMimeDataForJBIG2Globals(Stream *str, cairo_surface_t *image);
-#endif
-#if CAIRO_VERSION >= CAIRO_VERSION_ENCODE(1, 15, 10)
     bool setMimeDataForCCITTParams(Stream *str, cairo_surface_t *image, int height);
-#endif
+    static void textStringToQuotedUtf8(const GooString *text, GooString *s);
+    bool isPDF();
 
     std::optional<GfxRGB> fill_color, stroke_color;
     cairo_pattern_t *fill_pattern, *stroke_pattern;
@@ -329,7 +320,7 @@ protected:
         cairo_line_join_t join;
         double miter;
         int ref_count;
-    } * strokePathClip;
+    } *strokePathClip;
 
     PDFDoc *doc; // the current document
 
@@ -360,7 +351,14 @@ protected:
     bool t3_glyph_has_color;
     bool has_color;
     double t3_glyph_bbox[4];
-    bool prescaleImages;
+    bool logicalStruct;
+    bool firstPage;
+    int pdfPageNum; // page number of the PDF file
+    int cairoPageNum; // page number in cairo output
+    std::vector<std::string> markedContentStack;
+    std::vector<std::shared_ptr<Annot>> annotations;
+    std::set<std::string> emittedDestinations;
+    std::map<int, int> pdfPageToCairoPageMap;
 
     TextPage *textPage; // text for the current page
     ActualText *actualText;
@@ -377,7 +375,7 @@ protected:
         GfxColorSpace *cs;
         cairo_matrix_t group_matrix;
         struct ColorSpaceStack *next;
-    } * groupColorSpaceStack;
+    } *groupColorSpaceStack;
 
     struct SaveStateElement
     {
@@ -391,6 +389,19 @@ protected:
         Ref fontRef;
     };
     std::vector<SaveStateElement> saveStateStack;
+
+    std::map<Ref, std::map<std::string, std::unique_ptr<LinkDest>>> destsMap;
+    std::map<Ref, int> pdfPageRefToCairoPageNumMap;
+    std::vector<int> structParentsStack;
+    int currentStructParents;
+
+    struct StructParentsMcidHash
+    {
+        size_t operator()(std::pair<int, int> x) const { return x.first << 16 | x.second; }
+    };
+    std::unordered_set<std::pair<int, int>, StructParentsMcidHash> mcidEmitted; // <structParent, MCID>
+
+    std::unordered_set<const StructElement *> structElementNeeded;
 };
 
 //------------------------------------------------------------------------
@@ -424,81 +435,57 @@ public:
     // Does this device use functionShadedFill(), axialShadedFill(), and
     // radialShadedFill()?  If this returns false, these shaded fills
     // will be reduced to a series of other drawing operations.
-#if CAIRO_VERSION >= CAIRO_VERSION_ENCODE(1, 11, 2)
-    bool useShadedFills(int type) override
-    {
-        return type <= 7;
-    }
-#else
-    bool useShadedFills(int type) override
-    {
-        return type < 4;
-    }
-#endif
+    bool useShadedFills(int type) override { return type <= 7; }
 
     // Does this device use FillColorStop()?
-    bool useFillColorStop() override
-    {
-        return false;
-    }
+    bool useFillColorStop() override { return false; }
 
     // Does this device use beginType3Char/endType3Char?  Otherwise,
     // text in Type 3 fonts will be drawn with drawChar/drawString.
-    bool interpretType3Chars() override
-    {
-        return false;
-    }
+    bool interpretType3Chars() override { return false; }
 
     // Does this device need non-text content?
-    bool needNonText() override
-    {
-        return true;
-    }
+    bool needNonText() override { return true; }
 
     //----- save/restore graphics state
-    void saveState(GfxState *state) override { }
-    void restoreState(GfxState *state) override { }
+    void saveState(GfxState * /*state*/) override { }
+    void restoreState(GfxState * /*state*/) override { }
 
     //----- update graphics state
-    void updateAll(GfxState *state) override { }
-    void setDefaultCTM(const double *ctm) override { }
-    void updateCTM(GfxState *state, double m11, double m12, double m21, double m22, double m31, double m32) override { }
-    void updateLineDash(GfxState *state) override { }
-    void updateFlatness(GfxState *state) override { }
-    void updateLineJoin(GfxState *state) override { }
-    void updateLineCap(GfxState *state) override { }
-    void updateMiterLimit(GfxState *state) override { }
-    void updateLineWidth(GfxState *state) override { }
-    void updateFillColor(GfxState *state) override { }
-    void updateStrokeColor(GfxState *state) override { }
-    void updateFillOpacity(GfxState *state) override { }
-    void updateStrokeOpacity(GfxState *state) override { }
-    void updateBlendMode(GfxState *state) override { }
+    void updateAll(GfxState * /*state*/) override { }
+    void setDefaultCTM(const double * /*ctm*/) override { }
+    void updateCTM(GfxState * /*state*/, double /*m11*/, double /*m12*/, double /*m21*/, double /*m22*/, double /*m31*/, double /*m32*/) override { }
+    void updateLineDash(GfxState * /*state*/) override { }
+    void updateFlatness(GfxState * /*state*/) override { }
+    void updateLineJoin(GfxState * /*state*/) override { }
+    void updateLineCap(GfxState * /*state*/) override { }
+    void updateMiterLimit(GfxState * /*state*/) override { }
+    void updateLineWidth(GfxState * /*state*/) override { }
+    void updateFillColor(GfxState * /*state*/) override { }
+    void updateStrokeColor(GfxState * /*state*/) override { }
+    void updateFillOpacity(GfxState * /*state*/) override { }
+    void updateStrokeOpacity(GfxState * /*state*/) override { }
+    void updateBlendMode(GfxState * /*state*/) override { }
 
     //----- update text state
-    void updateFont(GfxState *state) override { }
+    void updateFont(GfxState * /*state*/) override { }
 
     //----- path painting
-    void stroke(GfxState *state) override { }
-    void fill(GfxState *state) override { }
-    void eoFill(GfxState *state) override { }
-    void clipToStrokePath(GfxState *state) override { }
-    bool tilingPatternFill(GfxState *state, Gfx *gfx, Catalog *cat, GfxTilingPattern *tPat, const double *mat, int x0, int y0, int x1, int y1, double xStep, double yStep) override
-    {
-        return true;
-    }
-    bool axialShadedFill(GfxState *state, GfxAxialShading *shading, double tMin, double tMax) override
-    {
-        return true;
-    }
-    bool radialShadedFill(GfxState *state, GfxRadialShading *shading, double sMin, double sMax) override
+    void stroke(GfxState * /*state*/) override { }
+    void fill(GfxState * /*state*/) override { }
+    void eoFill(GfxState * /*state*/) override { }
+    void clipToStrokePath(GfxState * /*state*/) override { }
+    bool tilingPatternFill(GfxState * /*state*/, Gfx * /*gfx*/, Catalog * /*cat*/, GfxTilingPattern * /*tPat*/, const std::array<double, 6> & /*mat*/, int /*x0*/, int /*y0*/, int /*x1*/, int /*y1*/, double /*xStep*/,
+                           double /*yStep*/) override
     {
         return true;
     }
+    bool axialShadedFill(GfxState * /*state*/, GfxAxialShading * /*shading*/, double /*tMin*/, double /*tMax*/) override { return true; }
+    bool radialShadedFill(GfxState * /*state*/, GfxRadialShading * /*shading*/, double /*sMin*/, double /*sMax*/) override { return true; }
 
     //----- path clipping
-    void clip(GfxState *state) override { }
-    void eoClip(GfxState *state) override { }
+    void clip(GfxState * /*state*/) override { }
+    void eoClip(GfxState * /*state*/) override { }
 
     //----- image drawing
     void drawImageMask(GfxState *state, Object *ref, Stream *str, int width, int height, bool invert, bool interpolate, bool inlineImg) override;
@@ -507,13 +494,13 @@ public:
                              bool maskInterpolate) override;
     void drawMaskedImage(GfxState *state, Object *ref, Stream *str, int width, int height, GfxImageColorMap *colorMap, bool interpolate, Stream *maskStr, int maskWidth, int maskHeight, bool maskInvert, bool maskInterpolate) override;
     void setSoftMaskFromImageMask(GfxState *state, Object *ref, Stream *str, int width, int height, bool invert, bool inlineImg, double *baseMatrix) override;
-    void unsetSoftMaskFromImageMask(GfxState *state, double *baseMatrix) override { }
+    void unsetSoftMaskFromImageMask(GfxState * /*state*/, double * /*baseMatrix*/) override { }
 
     //----- transparency groups and soft masks
-    void beginTransparencyGroup(GfxState * /*state*/, const double * /*bbox*/, GfxColorSpace * /*blendingColorSpace*/, bool /*isolated*/, bool /*knockout*/, bool /*forSoftMask*/) override { }
+    void beginTransparencyGroup(GfxState * /*state*/, const std::array<double, 4> & /*bbox*/, GfxColorSpace * /*blendingColorSpace*/, bool /*isolated*/, bool /*knockout*/, bool /*forSoftMask*/) override { }
     void endTransparencyGroup(GfxState * /*state*/) override { }
-    void paintTransparencyGroup(GfxState * /*state*/, const double * /*bbox*/) override { }
-    void setSoftMask(GfxState * /*state*/, const double * /*bbox*/, bool /*alpha*/, Function * /*transferFunc*/, GfxColor * /*backdropColor*/) override { }
+    void paintTransparencyGroup(GfxState * /*state*/, const std::array<double, 4> & /*bbox*/) override { }
+    void setSoftMask(GfxState * /*state*/, const std::array<double, 4> & /*bbox*/, bool /*alpha*/, Function * /*transferFunc*/, GfxColor * /*backdropColor*/) override { }
     void clearSoftMask(GfxState * /*state*/) override { }
 
     //----- Image list
@@ -524,14 +511,8 @@ public:
         imgDrawCbkData = data;
     }
     // Iterate through list of images.
-    int getNumImages() const
-    {
-        return numImages;
-    }
-    CairoImage *getImage(int i) const
-    {
-        return images[i];
-    }
+    int getNumImages() const { return numImages; }
+    CairoImage *getImage(int i) const { return images[i]; }
 
 private:
     void saveImage(CairoImage *image);
