@@ -5,17 +5,19 @@
 // This file is licensed under the GPLv2 or later
 //
 // Copyright 2018 Chinmoy Ranjan Pradhan <chinmoyrp65@gmail.com>
-// Copyright 2018, 2019 Albert Astals Cid <aacid@kde.org>
+// Copyright 2018, 2019, 2025 Albert Astals Cid <aacid@kde.org>
 // Copyright 2018 Oliver Sander <oliver.sander@tu-dresden.de>
+// Copyright 2020 Thorsten Behrens <Thorsten.Behrens@CIB.de>
+// Copyright 2023, 2024 g10 Code GmbH, Author: Sune Stolborg Vuorela <sune@vuorela.dk>
 //
 //========================================================================
 
 #ifndef CERTIFICATEINFO_H
 #define CERTIFICATEINFO_H
 
-#include <memory>
 #include <ctime>
 #include "goo/GooString.h"
+#include "poppler_private_export.h"
 
 enum CertificateKeyUsageExtension
 {
@@ -38,7 +40,29 @@ enum PublicKeyType
     OTHERKEY
 };
 
-class X509CertificateInfo
+/** A signing key can be located in different places
+ sometimes. For the user, it might be easier to pick
+ the key located on a card if it has some visual
+ indicator that it is somehow removable.
+
+ \note a keylocation for a certificate without a private
+ key (cannot be used for signing) will likely be "Unknown"
+ */
+enum class KeyLocation
+{
+    Unknown, /** We don't know the location */
+    Other, /** We know the location, but it is somehow not covered by this enum */
+    Computer, /** The key is on this computer */
+    HardwareToken /** The key is on a dedicated hardware token, either a smartcard or a dedicated usb token (e.g. gnuk, nitrokey or yubikey) */
+};
+
+enum class CertificateType
+{
+    X509,
+    PGP
+};
+
+class POPPLER_PRIVATE_EXPORT X509CertificateInfo // TODO consider rename to just CertificateInfo
 {
 public:
     X509CertificateInfo();
@@ -49,26 +73,26 @@ public:
 
     struct PublicKeyInfo
     {
-        PublicKeyInfo();
+        PublicKeyInfo() = default;
 
-        PublicKeyInfo(PublicKeyInfo &&) noexcept;
-        PublicKeyInfo &operator=(PublicKeyInfo &&) noexcept;
+        PublicKeyInfo(PublicKeyInfo &&) noexcept = default;
+        PublicKeyInfo &operator=(PublicKeyInfo &&) noexcept = default;
 
         PublicKeyInfo(const PublicKeyInfo &) = delete;
         PublicKeyInfo &operator=(const PublicKeyInfo &) = delete;
 
         GooString publicKey;
-        PublicKeyType publicKeyType;
-        unsigned int publicKeyStrength; // in bits
+        PublicKeyType publicKeyType = OTHERKEY;
+        unsigned int publicKeyStrength = 0; // in bits
     };
 
     struct EntityInfo
     {
-        EntityInfo();
-        ~EntityInfo();
+        EntityInfo() = default;
+        ~EntityInfo() = default;
 
-        EntityInfo(EntityInfo &&) noexcept;
-        EntityInfo &operator=(EntityInfo &&) noexcept;
+        EntityInfo(EntityInfo &&) noexcept = default;
+        EntityInfo &operator=(EntityInfo &&) noexcept = default;
 
         EntityInfo(const EntityInfo &) = delete;
         EntityInfo &operator=(const EntityInfo &) = delete;
@@ -90,6 +114,7 @@ public:
     /* GETTERS */
     int getVersion() const;
     const GooString &getSerialNumber() const;
+    const GooString &getNickName() const;
     const EntityInfo &getIssuerInfo() const;
     const Validity &getValidity() const;
     const EntityInfo &getSubjectInfo() const;
@@ -97,10 +122,15 @@ public:
     unsigned int getKeyUsageExtensions() const;
     const GooString &getCertificateDER() const;
     bool getIsSelfSigned() const;
+    bool isQualified() const;
+    void setQualified(bool qualified);
+    KeyLocation getKeyLocation() const;
+    CertificateType getCertificateType() const;
 
     /* SETTERS */
     void setVersion(int);
     void setSerialNumber(const GooString &);
+    void setNickName(const GooString &);
     void setIssuerInfo(EntityInfo &&);
     void setValidity(Validity);
     void setSubjectInfo(EntityInfo &&);
@@ -108,6 +138,8 @@ public:
     void setKeyUsageExtensions(unsigned int);
     void setCertificateDER(const GooString &);
     void setIsSelfSigned(bool);
+    void setKeyLocation(KeyLocation location);
+    void setCertificateType(CertificateType type);
 
 private:
     EntityInfo issuer_info;
@@ -116,9 +148,13 @@ private:
     Validity cert_validity;
     GooString cert_serial;
     GooString cert_der;
+    GooString cert_nick;
     unsigned int ku_extensions;
     int cert_version;
+    bool is_qualified;
     bool is_self_signed;
+    KeyLocation keyLocation;
+    CertificateType certificate_type = CertificateType::X509;
 };
 
 #endif
