@@ -5,7 +5,7 @@
 // This file is licensed under the GPLv2 or later
 //
 // Copyright 2005 Jeff Muizelaar <jeff@infidigm.net>
-// Copyright 2005-2010, 2012, 2017, 2020-2023 Albert Astals Cid <aacid@kde.org>
+// Copyright 2005-2010, 2012, 2017, 2020-2023, 2025 Albert Astals Cid <aacid@kde.org>
 // Copyright 2009 Ryszard Trojnacki <rysiek@menel.com>
 // Copyright 2010 Carlos Garcia Campos <carlosgc@gnome.org>
 // Copyright 2011 Daiki Ueno <ueno@unixuser.org>
@@ -15,12 +15,13 @@
 // Copyright 2020 Lluís Batlle i Rossell <viric@viric.name>
 // Copyright 2025 Nelson Benítez León <nbenitezl@gmail.com>
 // Copyright 2025 g10 Code GmbH, Author: Sune Stolborg Vuorela <sune@vuorela.dk>
+// Copyright (C) 2025 Arnav V <arnav0872@gmail.com>
 //
 //========================================================================
 
 #include "DCTStream.h"
 
-static void str_init_source(j_decompress_ptr cinfo) { }
+static void str_init_source(j_decompress_ptr /*cinfo*/) { }
 
 static boolean str_fill_input_buffer(j_decompress_ptr cinfo)
 {
@@ -45,20 +46,24 @@ static boolean str_fill_input_buffer(j_decompress_ptr cinfo)
     }
 }
 
-static void str_skip_input_data(j_decompress_ptr cinfo, long num_bytes)
+static void str_skip_input_data(j_decompress_ptr cinfo, long num_bytes_l)
 {
-    struct str_src_mgr *src = (struct str_src_mgr *)cinfo->src;
-    if (num_bytes > 0) {
-        while (num_bytes > (long)src->pub.bytes_in_buffer) {
-            num_bytes -= (long)src->pub.bytes_in_buffer;
-            str_fill_input_buffer(cinfo);
-        }
-        src->pub.next_input_byte += (size_t)num_bytes;
-        src->pub.bytes_in_buffer -= (size_t)num_bytes;
+    if (num_bytes_l <= 0) {
+        return;
     }
+
+    size_t num_bytes = num_bytes_l;
+
+    struct str_src_mgr *src = (struct str_src_mgr *)cinfo->src;
+    while (num_bytes > src->pub.bytes_in_buffer) {
+        num_bytes -= src->pub.bytes_in_buffer;
+        str_fill_input_buffer(cinfo);
+    }
+    src->pub.next_input_byte += num_bytes;
+    src->pub.bytes_in_buffer -= num_bytes;
 }
 
-static void str_term_source(j_decompress_ptr cinfo) { }
+static void str_term_source(j_decompress_ptr /*cinfo*/) { }
 
 DCTStream::DCTStream(Stream *strA, int colorXformA, Dict *dict, int recursion) : FilterStream(strA)
 {
@@ -116,11 +121,11 @@ void DCTStream::init()
     row_buffer = nullptr;
 }
 
-bool DCTStream::reset()
+bool DCTStream::rewind()
 {
     int row_stride;
 
-    bool success = str->reset();
+    bool success = str->rewind();
 
     if (row_buffer) {
         jpeg_destroy_decompress(&cinfo);
@@ -162,7 +167,8 @@ bool DCTStream::reset()
                 if (cinfo.num_components == 3) {
                     if (cinfo.saw_JFIF_marker) {
                         colorXform = 1;
-                    } else if (cinfo.cur_comp_info[0]->component_id == 82 && cinfo.cur_comp_info[1]->component_id == 71 && cinfo.cur_comp_info[2]->component_id == 66) { // ASCII "RGB"
+                    } else if (cinfo.cur_comp_info[0] && cinfo.cur_comp_info[1] && cinfo.cur_comp_info[2] && cinfo.cur_comp_info[0]->component_id == 82 && cinfo.cur_comp_info[1]->component_id == 71
+                               && cinfo.cur_comp_info[2]->component_id == 66) { // ASCII "RGB"
                         colorXform = 0;
                     } else {
                         colorXform = 1;
@@ -264,7 +270,7 @@ std::optional<std::string> DCTStream::getPSFilter(int psLevel, const char *inden
     return s;
 }
 
-bool DCTStream::isBinary(bool last) const
+bool DCTStream::isBinary(bool /*last*/) const
 {
     return str->isBinary(true);
 }
