@@ -5,7 +5,7 @@
 // This file is licensed under the GPLv2 or later
 //
 // Copyright 2010 Hib Eris <hib@hiberis.nl>
-// Copyright 2010, 2022 Albert Astals Cid <aacid@kde.org>
+// Copyright 2010, 2022, 2025 Albert Astals Cid <aacid@kde.org>
 // Copyright 2010 Jonathan Liu <net147@gmail.com>
 // Copyright 2021 Peter Williams <peter@newton.cx>
 // Copyright 2021 Christian Persch <chpe@src.gnome.org>
@@ -47,7 +47,7 @@ size_t FILECacheLoader::init(CachedFile *cachedFile)
     return size;
 }
 
-int FILECacheLoader::load(const std::vector<ByteRange> &ranges, CachedFileWriter *writer)
+int FILECacheLoader::load(const std::vector<ByteRange> & /*ranges*/, CachedFileWriter * /*writer*/)
 {
     return 0;
 }
