@@ -13,6 +13,7 @@
 // Copyright (C) 2018 Adam Reichold <adam.reichold@t-online.de>
 // Copyright (C) 2019 Christian Persch <chpe@src.gnome.org>
 // Copyright (C) 2024, 2025 g10 Code GmbH, Author: Sune Stolborg Vuorela <sune@vuorela.dk>
+// Copyright (C) 2025 Arnav V <arnav0872@gmail.com>
 //
 // To see a description of the changes please see the Changelog file that
 // came with your tarball or type make ChangeLog if you are building from git
@@ -50,7 +51,7 @@ EmbFile::EmbFile(Object &&efStream)
         // subtype is normally the mimetype
         Object subtypeName = dataDict->lookup("Subtype");
         if (subtypeName.isName()) {
-            m_mimetype = std::make_unique<GooString>(subtypeName.getName());
+            m_mimetype = std::make_unique<GooString>(subtypeName.getNameString());
         }
 
         // paramDict corresponds to Table 3.42 in the PDF1.6 spec
@@ -58,12 +59,12 @@ EmbFile::EmbFile(Object &&efStream)
         if (paramDict.isDict()) {
             Object paramObj = paramDict.dictLookup("ModDate");
             if (paramObj.isString()) {
-                m_modDate = paramObj.getString()->copy();
+                m_modDate = paramObj.takeString();
             }
 
             paramObj = paramDict.dictLookup("CreationDate");
             if (paramObj.isString()) {
-                m_createDate = paramObj.getString()->copy();
+                m_createDate = paramObj.takeString();
             }
 
             paramObj = paramDict.dictLookup("Size");
@@ -73,7 +74,7 @@ EmbFile::EmbFile(Object &&efStream)
 
             paramObj = paramDict.dictLookup("CheckSum");
             if (paramObj.isString()) {
-                m_checksum = paramObj.getString()->copy();
+                m_checksum = paramObj.takeString();
             }
         }
     }
@@ -102,7 +103,7 @@ bool EmbFile::save2(FILE *f)
         return false;
     }
 
-    if (!m_objStr.streamReset()) {
+    if (!m_objStr.streamRewind()) {
         return false;
     }
     while ((c = m_objStr.streamGetChar()) != EOF) {
@@ -124,7 +125,7 @@ FileSpec::FileSpec(const Object *fileSpecA)
         return;
     }
 
-    fileName = obj1.getString()->copy();
+    fileName = obj1.takeString();
 
     if (fileSpec.isDict()) {
         obj1 = fileSpec.dictLookup("EF");
@@ -140,7 +141,7 @@ FileSpec::FileSpec(const Object *fileSpecA)
 
         obj1 = fileSpec.dictLookup("Desc");
         if (obj1.isString()) {
-            desc = obj1.getString()->copy();
+            desc = obj1.takeString();
         }
     }
 }
@@ -173,10 +174,9 @@ Object FileSpec::newFileSpecObject(XRef *xref, GooFile *file, const std::string
     streamDict.dictSet("Length", Object(file->size()));
     streamDict.dictSet("Params", std::move(paramsDict));
 
-    FileStream *fStream = new FileStream(file, 0, false, file->size(), std::move(streamDict));
+    auto fStream = std::make_unique<FileStream>(file, 0, false, file->size(), std::move(streamDict));
     fStream->setNeedsEncryptionOnSave(true);
-    Stream *stream = fStream;
-    const Ref streamRef = xref->addIndirectObject(Object(stream));
+    const Ref streamRef = xref->addIndirectObject(Object(std::move(fStream)));
 
     Dict *efDict = new Dict(xref);
     efDict->set("F", Object(streamRef));
@@ -197,7 +197,7 @@ GooString *FileSpec::getFileNameForPlatform()
 
     Object obj1 = getFileSpecNameForPlatform(&fileSpec);
     if (obj1.isString()) {
-        platformFileName = obj1.getString()->copy();
+        platformFileName = obj1.takeString();
     }
 
     return platformFileName.get();
@@ -265,7 +265,7 @@ Object getFileSpecNameForPlatform(const Object *fileSpec)
 
     // system-dependent path manipulation
 #ifdef _WIN32
-    int i, j;
+    size_t i, j;
     std::unique_ptr<GooString> name = fileName.getString()->copy();
     // "//...."             --> "\...."
     // "/x/...."            --> "x:\...."
@@ -273,31 +273,31 @@ Object getFileSpecNameForPlatform(const Object *fileSpec)
     // convert escaped slashes to slashes and unescaped slashes to backslashes
     i = 0;
     if (name->getChar(0) == '/') {
-        if (name->getLength() >= 2 && name->getChar(1) == '/') {
-            name->del(0);
+        if (name->size() >= 2 && name->getChar(1) == '/') {
+            name->erase(0, 1);
             i = 0;
-        } else if (name->getLength() >= 2 && ((name->getChar(1) >= 'a' && name->getChar(1) <= 'z') || (name->getChar(1) >= 'A' && name->getChar(1) <= 'Z')) && (name->getLength() == 2 || name->getChar(2) == '/')) {
+        } else if (name->size() >= 2 && ((name->getChar(1) >= 'a' && name->getChar(1) <= 'z') || (name->getChar(1) >= 'A' && name->getChar(1) <= 'Z')) && (name->size() == 2 || name->getChar(2) == '/')) {
             name->setChar(0, name->getChar(1));
             name->setChar(1, ':');
             i = 2;
         } else {
-            for (j = 2; j < name->getLength(); ++j) {
+            for (j = 2; j < name->size(); ++j) {
                 if (name->getChar(j - 1) != '\\' && name->getChar(j) == '/') {
                     break;
                 }
             }
-            if (j < name->getLength()) {
+            if (j < name->size()) {
                 name->setChar(0, '\\');
-                name->insert(0, '\\');
+                name->insert(0, 1, '\\');
                 i = 2;
             }
         }
     }
-    for (; i < name->getLength(); ++i) {
+    for (; i < name->size(); ++i) {
         if (name->getChar(i) == '/') {
             name->setChar(i, '\\');
-        } else if (name->getChar(i) == '\\' && i + 1 < name->getLength() && name->getChar(i + 1) == '/') {
-            name->del(i);
+        } else if (name->getChar(i) == '\\' && i + 1 < name->size() && name->getChar(i + 1) == '/') {
+            name->erase(i, 1);
         }
     }
     fileName = Object(std::move(name));
