@@ -3,8 +3,10 @@
 // FlateEncoder.h
 //
 // Copyright (C) 2016, William Bader <williambader@hotmail.com>
-// Copyright (C) 2018, 2019, 2021 Albert Astals Cid <aacid@kde.org>
+// Copyright (C) 2018, 2019, 2021, 2025 Albert Astals Cid <aacid@kde.org>
 // Copyright (C) 2025 Nelson Benítez León <nbenitezl@gmail.com>
+// Copyright (C) 2025 g10 Code GmbH, Author: Sune Stolborg Vuorela <sune@vuorela.dk>
+// Copyright (C) 2025 Arnav V <arnav0872@gmail.com>
 //
 // This file is under the GPLv2 or later license
 //
@@ -13,20 +15,8 @@
 #ifndef FLATEENCODE_H
 #define FLATEENCODE_H
 
-#include "poppler-config.h"
 #include <cstdio>
-#include <cstdlib>
-#include <cstddef>
-#ifdef HAVE_UNISTD_H
-#    include <unistd.h>
-#endif
-#include <cstring>
-#include <cctype>
-#include "goo/gmem.h"
-#include "goo/gfile.h"
-#include "Error.h"
 #include "Object.h"
-#include "Decrypt.h"
 
 #include "Stream.h"
 
@@ -44,11 +34,11 @@ public:
     explicit FlateEncoder(Stream *strA);
     ~FlateEncoder() override;
     StreamKind getKind() const override { return strWeird; }
-    bool reset() override;
+    [[nodiscard]] bool rewind() override;
     int getChar() override { return (outBufPtr >= outBufEnd && !fillBuf()) ? EOF : (*outBufPtr++ & 0xff); }
     int lookChar() override { return (outBufPtr >= outBufEnd && !fillBuf()) ? EOF : (*outBufPtr & 0xff); }
-    GooString *getPSFilter(int psLevel, const char *indent) override { return nullptr; }
-    bool isBinary(bool last = true) const override { return true; }
+    std::optional<std::string> getPSFilter(int /*psLevel*/, const char * /*indent*/) override { return {}; }
+    bool isBinary(bool /*last*/ = true) const override { return true; }
     bool isEncoder() const override { return true; }
 
 private:
