@@ -3,10 +3,11 @@
 // FlateStream.cc
 //
 // Copyright (C) 2005, Jeff Muizelaar <jeff@infidigm.net>
-// Copyright (C) 2010, 2021, Albert Astals Cid <aacid@kde.org>
+// Copyright (C) 2010, 2021, 2025, Albert Astals Cid <aacid@kde.org>
 // Copyright (C) 2016, William Bader <williambader@hotmail.com>
 // Copyright (C) 2017, Adrian Johnson <ajohnson@redneon.com>
 // Copyright (C) 2025 Nelson Benítez León <nbenitezl@gmail.com>
+// Copyright (C) 2025 Arnav V <arnav0872@gmail.com>
 //
 // This file is under the GPLv2 or later license
 //
@@ -16,7 +17,7 @@
 
 #include "poppler-config.h"
 
-#ifdef ENABLE_ZLIB_UNCOMPRESS
+#if ENABLE_ZLIB_UNCOMPRESS
 
 #    include "FlateStream.h"
 
@@ -43,9 +44,9 @@ FlateStream::~FlateStream()
     delete str;
 }
 
-bool FlateStream::reset()
+bool FlateStream::rewind()
 {
-    // FIXME: what are the semantics of reset?
+    // FIXME: what are the semantics of rewind?
     // i.e. how much initialization has to happen in the constructor?
 
     /* reinitialize zlib */
@@ -53,7 +54,7 @@ bool FlateStream::reset()
     memset(&d_stream, 0, sizeof(d_stream));
     inflateInit(&d_stream);
 
-    str->reset();
+    str->rewind();
     d_stream.avail_in = 0;
     status = Z_OK;
     out_pos = 0;
@@ -133,21 +134,22 @@ int FlateStream::fill_buffer()
     return 0;
 }
 
-GooString *FlateStream::getPSFilter(int psLevel, const char *indent)
+std::optional<std::string> FlateStream::getPSFilter(int psLevel, const char *indent)
 {
-    GooString *s;
-
     if (psLevel < 3 || pred) {
-        return NULL;
+        return std::nullopt;
     }
-    if (!(s = str->getPSFilter(psLevel, indent))) {
-        return NULL;
+
+    std::optional<std::string> s = str->getPSFilter(psLevel, indent);
+    if (!s.has_value()) {
+        return std::nullopt;
     }
-    s->append(indent)->append("<< >> /FlateDecode filter\n");
+    s->append(indent).append("<< >> /FlateDecode filter\n");
+
     return s;
 }
 
-bool FlateStream::isBinary(bool last) const
+bool FlateStream::isBinary(bool /*last*/) const
 {
     return str->isBinary(true);
 }
