@@ -16,6 +16,7 @@
 // Copyright (C) 2018, 2019 Adam Reichold <adam.reichold@t-online.de>
 // Copyright (C) 2019, 2021, 2022 Oliver Sander <oliver.sander@tu-dresden.de>
 // Copyright (C) 2023 Suzuki Toshiya <mpsuzuki@hiroshima-u.ac.jp>
+// Copyright (C) 2025 g10 Code GmbH, Author: Sune Stolborg Vuorela <sune@vuorela.dk>
 //
 // To see a description of the changes please see the Changelog file that
 // came with your tarball or type make ChangeLog if you are building from git
@@ -31,13 +32,7 @@
 //========================================================================
 
 #include "config.h"
-#include <cstdio>
-#include <cstdlib>
-#include <cstddef>
-#include <cstring>
-#include <cmath>
 #include "GlobalParams.h"
-#include "Error.h"
 #include "Object.h"
 #include "Dict.h"
 #include "GfxFont.h"
@@ -83,7 +78,7 @@ std::vector<FontInfo *> FontInfoScanner::scan(int nPages)
             delete resDict;
         }
         annots = page->getAnnots();
-        for (Annot *annot : annots->getAnnots()) {
+        for (const std::shared_ptr<Annot> &annot : annots->getAnnots()) {
             Object obj1 = annot->getAppearanceResDict();
             if (obj1.isDict()) {
                 scanFonts(xrefA.get(), obj1.getDict(), &result);
@@ -176,7 +171,7 @@ FontInfo::FontInfo(GfxFont *font, XRef *xref)
         if (fontLoc && fontLoc->locType == gfxFontLocExternal) {
             file = fontLoc->path;
         }
-        if (substituteNameAux.getLength() > 0) {
+        if (!substituteNameAux.empty()) {
             substituteName = substituteNameAux.toStr();
         }
     }
