@@ -5,12 +5,15 @@
 // This file is licensed under the GPLv2 or later
 //
 // Copyright 2023-2025 g10 Code GmbH, Author: Sune Stolborg Vuorela <sune@vuorela.dk>
+// Copyright 2025 Albert Astals Cid <aacid@kde.org>
 //========================================================================
 
 #include "CryptoSignBackend.h"
 #include "config.h"
 #include "GPGMECryptoSignBackend.h"
+#include "GPGMECryptoSignBackendConfiguration.h"
 #include "DistinguishedNameParser.h"
+#include "Error.h"
 #include <array>
 #include <gpgme.h>
 #include <gpgme++/key.h>
@@ -20,6 +23,7 @@
 #if DUMP_SIGNATURE_DATA
 #    include <fstream>
 #endif
+static std::vector<GpgME::Protocol> allowedTypes();
 
 bool GpgSignatureBackend::hasSufficientVersion()
 {
@@ -69,6 +73,15 @@ static bool isValidResult(const Result &result)
     return isSuccess(result.error());
 }
 
+static std::string errorString(const GpgME::Error &err)
+{
+#if GPGMEPP_VERSION < ((1 << 16) | (24 << 8) | (0))
+    return fromCharPtr(err.asString());
+#else
+    return err.asStdString();
+#endif
+}
+
 template<typename Result>
 static bool hasValidResult(const std::optional<Result> &result)
 {
@@ -226,7 +239,7 @@ std::unique_ptr<CryptoSign::VerificationInterface> GpgSignatureBackend::createVe
 std::vector<std::unique_ptr<X509CertificateInfo>> GpgSignatureBackend::getAvailableSigningCertificates()
 {
     std::vector<std::unique_ptr<X509CertificateInfo>> certificates;
-    for (auto type : GpgSignatureConfiguration::allowedTypes()) {
+    for (auto type : allowedTypes()) {
         const auto context = GpgME::Context::create(type);
         auto err = context->startKeyListing(static_cast<const char *>(nullptr), true /*secretOnly*/);
         while (isSuccess(err)) {
@@ -249,7 +262,7 @@ std::vector<std::unique_ptr<X509CertificateInfo>> GpgSignatureBackend::getAvaila
 
 GpgSignatureCreation::GpgSignatureCreation(const std::string &certId)
 {
-    for (auto type : GpgSignatureConfiguration::allowedTypes()) {
+    for (auto type : allowedTypes()) {
         GpgME::Error error;
         auto context = GpgME::Context::create(type);
         const auto signingKey = context->key(certId.c_str(), error, true);
@@ -267,25 +280,26 @@ void GpgSignatureCreation::addData(unsigned char *dataBlock, int dataLen)
 {
     gpgData.write(dataBlock, dataLen);
 }
-std::variant<std::vector<unsigned char>, CryptoSign::SigningError> GpgSignatureCreation::signDetached(const std::string &password)
+std::variant<std::vector<unsigned char>, CryptoSign::SigningErrorMessage> GpgSignatureCreation::signDetached(const std::string & /*password*/)
 {
     if (!key) {
-        return CryptoSign::SigningError::KeyMissing;
+        return CryptoSign::SigningErrorMessage { CryptoSign::SigningError::KeyMissing, ERROR_IN_CODE_LOCATION };
     }
     gpgData.rewind();
     GpgME::Data signatureData;
     const auto signingResult = gpgContext->sign(gpgData, signatureData, GpgME::SignatureMode::Detached);
     if (!isValidResult(signingResult)) {
         if (signingResult.error().isCanceled()) {
-            return CryptoSign::SigningError::UserCancelled;
+            return CryptoSign::SigningErrorMessage { CryptoSign::SigningError::UserCancelled, ERROR_IN_CODE_LOCATION };
         } else {
             switch (signingResult.error().code()) {
             case GPG_ERR_NO_PASSPHRASE: // this is likely the user pressing enter. Let's treat it as cancelled for now
-                return CryptoSign::SigningError::UserCancelled;
+                return CryptoSign::SigningErrorMessage { CryptoSign::SigningError::UserCancelled, ErrorString { errorString(signingResult.error()), ErrorStringType::UserString } };
             case GPG_ERR_BAD_PASSPHRASE:
-                return CryptoSign::SigningError::BadPassphrase;
+                return CryptoSign::SigningErrorMessage { CryptoSign::SigningError::BadPassphrase, ErrorString { errorString(signingResult.error()), ErrorStringType::UserString } };
             }
-            return CryptoSign::SigningError::GenericError;
+            error(errInternal, -1, "Signing error from gpgme: '%s'", errorString(signingResult.error()).c_str());
+            return CryptoSign::SigningErrorMessage { CryptoSign::SigningError::GenericError, ErrorString { errorString(signingResult.error()), ErrorStringType::UserString } };
         }
     }
 
@@ -301,7 +315,7 @@ std::variant<std::vector<unsigned char>, CryptoSign::SigningError> GpgSignatureC
         } };
 
         if (CryptoSign::maxSupportedSignatureSize - prefixandsize <= signatureString.size()) {
-            return CryptoSign::SigningError::InternalError;
+            return CryptoSign::SigningErrorMessage { CryptoSign::SigningError::InternalError, ERROR_IN_CODE_LOCATION };
         }
         std::array<unsigned char, 4> bytes;
         int n = CryptoSign::maxSupportedSignatureSize - prefixandsize - signatureString.size();
@@ -450,7 +464,7 @@ std::chrono::system_clock::time_point GpgSignatureVerification::getSigningTime()
     return std::chrono::system_clock::from_time_t(signature->creationTime());
 }
 
-void GpgSignatureVerification::validateCertificateAsync(std::chrono::system_clock::time_point validation_time, bool ocspRevocationCheck, bool useAIACertFetch, const std::function<void()> &doneFunction)
+void GpgSignatureVerification::validateCertificateAsync(std::chrono::system_clock::time_point /*validation_time*/, bool ocspRevocationCheck, bool useAIACertFetch, const std::function<void()> &doneFunction)
 {
     cachedValidationStatus.reset();
     if (!gpgResult) {
@@ -549,7 +563,7 @@ SignatureValidationStatus GpgSignatureVerification::validateSignature()
     }
 }
 
-#ifdef ENABLE_PGP_SIGNATURES
+#if ENABLE_PGP_SIGNATURES
 bool GpgSignatureConfiguration::allowPgp = true;
 #else
 bool GpgSignatureConfiguration::allowPgp = false;
@@ -564,11 +578,11 @@ void GpgSignatureConfiguration::setPgpSignaturesAllowed(bool allow)
     allowPgp = allow;
 }
 
-std::vector<GpgME::Protocol> GpgSignatureConfiguration::allowedTypes()
+static std::vector<GpgME::Protocol> allowedTypes()
 {
     std::vector<GpgME::Protocol> allowedTypes;
     allowedTypes.push_back(GpgME::CMS);
-    if (allowPgp) {
+    if (GpgSignatureConfiguration::arePgpSignaturesAllowed()) {
         allowedTypes.push_back(GpgME::OpenPGP);
     }
     return allowedTypes;
