@@ -15,7 +15,7 @@
 //
 // Copyright (C) 2005 Martin Kretzschmar <martink@gnome.org>
 // Copyright (C) 2005, 2006 Kristian Høgsberg <krh@redhat.com>
-// Copyright (C) 2005, 2007-2010, 2012, 2015, 2017-2024 Albert Astals Cid <aacid@kde.org>
+// Copyright (C) 2005, 2007-2010, 2012, 2015, 2017-2025 Albert Astals Cid <aacid@kde.org>
 // Copyright (C) 2005 Jonathan Blandford <jrb@redhat.com>
 // Copyright (C) 2006, 2007 Jeff Muizelaar <jeff@infidigm.net>
 // Copyright (C) 2006 Takashi Iwai <tiwai@suse.de>
@@ -61,7 +61,6 @@
 #include <algorithm>
 #include <cstring>
 #include <cstdio>
-#include <cctype>
 #include <filesystem>
 #ifdef _WIN32
 #    include <shlobj.h>
@@ -84,7 +83,7 @@
 #include "GlobalParams.h"
 #include "GfxFont.h"
 
-#ifdef WITH_FONTCONFIGURATION_FONTCONFIG
+#if WITH_FONTCONFIGURATION_FONTCONFIG
 #    include <fontconfig/fontconfig.h>
 #endif
 
@@ -112,7 +111,7 @@
 
 std::unique_ptr<GlobalParams> globalParams;
 
-#if defined(ENABLE_RELOCATABLE) && defined(_WIN32)
+#if ENABLE_RELOCATABLE && defined(_WIN32)
 
 /* search for data relative to where we are installed */
 
@@ -211,9 +210,8 @@ public:
     ~SysFontInfo();
     SysFontInfo(const SysFontInfo &) = delete;
     SysFontInfo &operator=(const SysFontInfo &) = delete;
-    bool match(const SysFontInfo *fi) const;
-    bool match(const GooString *nameA, bool boldA, bool italicA, bool obliqueA, bool fixedWidthA) const;
-    bool match(const GooString *nameA, bool boldA, bool italicA) const;
+    bool match(const std::string &nameA, bool boldA, bool italicA, bool obliqueA, bool fixedWidthA) const;
+    bool match(const std::string &nameA, bool boldA, bool italicA) const;
 };
 
 SysFontInfo::SysFontInfo(std::unique_ptr<GooString> &&nameA, bool boldA, bool italicA, bool obliqueA, bool fixedWidthA, std::unique_ptr<GooString> &&pathA, SysFontType typeA, int fontNumA, std::unique_ptr<GooString> &&substituteNameA)
@@ -229,19 +227,14 @@ SysFontInfo::SysFontInfo(std::unique_ptr<GooString> &&nameA, bool boldA, bool it
 
 SysFontInfo::~SysFontInfo() = default;
 
-bool SysFontInfo::match(const SysFontInfo *fi) const
+bool SysFontInfo::match(const std::string &nameA, bool boldA, bool italicA, bool obliqueA, bool fixedWidthA) const
 {
-    return !strcasecmp(name->c_str(), fi->name->c_str()) && bold == fi->bold && italic == fi->italic && oblique == fi->oblique && fixedWidth == fi->fixedWidth;
+    return !strcasecmp(name->c_str(), nameA.c_str()) && bold == boldA && italic == italicA && oblique == obliqueA && fixedWidth == fixedWidthA;
 }
 
-bool SysFontInfo::match(const GooString *nameA, bool boldA, bool italicA, bool obliqueA, bool fixedWidthA) const
+bool SysFontInfo::match(const std::string &nameA, bool boldA, bool italicA) const
 {
-    return !strcasecmp(name->c_str(), nameA->c_str()) && bold == boldA && italic == italicA && oblique == obliqueA && fixedWidth == fixedWidthA;
-}
-
-bool SysFontInfo::match(const GooString *nameA, bool boldA, bool italicA) const
-{
-    return !strcasecmp(name->c_str(), nameA->c_str()) && bold == boldA && italic == italicA;
+    return !strcasecmp(name->c_str(), nameA.c_str()) && bold == boldA && italic == italicA;
 }
 
 //------------------------------------------------------------------------
@@ -262,7 +255,7 @@ public:
 #ifdef _WIN32
     void scanWindowsFonts(const std::string &winFontDir);
 #endif
-#ifdef WITH_FONTCONFIGURATION_FONTCONFIG
+#if WITH_FONTCONFIGURATION_FONTCONFIG
     void addFcFont(SysFontInfo *si) { fonts.push_back(si); }
 #endif
 private:
@@ -286,39 +279,39 @@ const SysFontInfo *SysFontList::find(const std::string &name, bool fixedWidth, b
 {
     GooString *name2;
     bool bold, italic, oblique;
-    int n;
+    size_t n;
 
     name2 = new GooString(name);
 
     // remove space, comma, dash chars
     {
-        int i = 0;
-        while (i < name2->getLength()) {
+        size_t i = 0;
+        while (i < name2->size()) {
             const char c = name2->getChar(i);
             if (c == ' ' || c == ',' || c == '-') {
-                name2->del(i);
+                name2->erase(i, 1);
             } else {
                 ++i;
             }
         }
-        n = name2->getLength();
+        n = name2->size();
     }
 
     // remove trailing "MT" (Foo-MT, Foo-BoldMT, etc.)
     if (n > 2 && !strcmp(name2->c_str() + n - 2, "MT")) {
-        name2->del(n - 2, 2);
+        name2->erase(n - 2, 2);
         n -= 2;
     }
 
     // look for "Regular"
     if (n > 7 && !strcmp(name2->c_str() + n - 7, "Regular")) {
-        name2->del(n - 7, 7);
+        name2->erase(n - 7, 7);
         n -= 7;
     }
 
     // look for "Italic"
     if (n > 6 && !strcmp(name2->c_str() + n - 6, "Italic")) {
-        name2->del(n - 6, 6);
+        name2->erase(n - 6, 6);
         italic = true;
         n -= 6;
     } else {
@@ -327,7 +320,7 @@ const SysFontInfo *SysFontList::find(const std::string &name, bool fixedWidth, b
 
     // look for "Oblique"
     if (n > 6 && !strcmp(name2->c_str() + n - 7, "Oblique")) {
-        name2->del(n - 7, 7);
+        name2->erase(n - 7, 7);
         oblique = true;
         n -= 6;
     } else {
@@ -336,7 +329,7 @@ const SysFontInfo *SysFontList::find(const std::string &name, bool fixedWidth, b
 
     // look for "Bold"
     if (n > 4 && !strcmp(name2->c_str() + n - 4, "Bold")) {
-        name2->del(n - 4, 4);
+        name2->erase(n - 4, 4);
         bold = true;
         n -= 4;
     } else {
@@ -345,19 +338,19 @@ const SysFontInfo *SysFontList::find(const std::string &name, bool fixedWidth, b
 
     // remove trailing "MT" (FooMT-Bold, etc.)
     if (n > 2 && !strcmp(name2->c_str() + n - 2, "MT")) {
-        name2->del(n - 2, 2);
+        name2->erase(n - 2, 2);
         n -= 2;
     }
 
     // remove trailing "PS"
     if (n > 2 && !strcmp(name2->c_str() + n - 2, "PS")) {
-        name2->del(n - 2, 2);
+        name2->erase(n - 2, 2);
         n -= 2;
     }
 
     // remove trailing "IdentityH"
     if (n > 9 && !strcmp(name2->c_str() + n - 9, "IdentityH")) {
-        name2->del(n - 9, 9);
+        name2->erase(n - 9, 9);
         n -= 9;
     }
 
@@ -365,7 +358,7 @@ const SysFontInfo *SysFontList::find(const std::string &name, bool fixedWidth, b
     const SysFontInfo *fi = nullptr;
     for (const SysFontInfo *f : fonts) {
         fi = f;
-        if (fi->match(name2, bold, italic, oblique, fixedWidth)) {
+        if (fi->match(name2->toStr(), bold, italic, oblique, fixedWidth)) {
             if (std::ranges::find(filesToIgnore, fi->path->toStr()) == filesToIgnore.end()) {
                 break;
             }
@@ -376,7 +369,7 @@ const SysFontInfo *SysFontList::find(const std::string &name, bool fixedWidth, b
         // try ignoring the bold flag
         for (const SysFontInfo *f : fonts) {
             fi = f;
-            if (fi->match(name2, false, italic)) {
+            if (fi->match(name2->toStr(), false, italic)) {
                 if (std::ranges::find(filesToIgnore, fi->path->toStr()) == filesToIgnore.end()) {
                     break;
                 }
@@ -388,7 +381,7 @@ const SysFontInfo *SysFontList::find(const std::string &name, bool fixedWidth, b
         // try ignoring the bold and italic flags
         for (const SysFontInfo *f : fonts) {
             fi = f;
-            if (fi->match(name2, false, false)) {
+            if (fi->match(name2->toStr(), false, false)) {
                 if (std::ranges::find(filesToIgnore, fi->path->toStr()) == filesToIgnore.end()) {
                     break;
                 }
@@ -608,12 +601,12 @@ FILE *GlobalParams::getUnicodeMapFile(const std::string &encodingName)
     return file;
 }
 
-FILE *GlobalParams::findCMapFile(const GooString &collection, const GooString &cMapName)
+FILE *GlobalParams::findCMapFile(const std::string &collection, const std::string &cMapName)
 {
     FILE *file = nullptr;
 
     globalParamsLocker();
-    const auto collectionCMapDirs = cMapDirs.equal_range(collection.toStr());
+    const auto collectionCMapDirs = cMapDirs.equal_range(collection);
     for (auto cMapDir = collectionCMapDirs.first; cMapDir != collectionCMapDirs.second; ++cMapDir) {
         auto *const path = new GooString(cMapDir->second);
         appendToPath(path, cMapName.c_str());
@@ -627,14 +620,14 @@ FILE *GlobalParams::findCMapFile(const GooString &collection, const GooString &c
     return file;
 }
 
-FILE *GlobalParams::findToUnicodeFile(const GooString *name)
+FILE *GlobalParams::findToUnicodeFile(const std::string &name)
 {
     GooString *fileName;
     FILE *f;
 
     globalParamsLocker();
     for (const std::string &dir : toUnicodeDirs) {
-        fileName = appendToPath(new GooString(dir), name->c_str());
+        fileName = appendToPath(new GooString(dir), name.c_str());
         f = openFile(fileName->c_str(), "r");
         delete fileName;
         if (f) {
@@ -644,7 +637,7 @@ FILE *GlobalParams::findToUnicodeFile(const GooString *name)
     return nullptr;
 }
 
-#ifdef WITH_FONTCONFIGURATION_FONTCONFIG
+#if WITH_FONTCONFIGURATION_FONTCONFIG
 static bool findModifier(const std::string &name, const size_t modStart, const char *modifier, size_t &start)
 {
     if (modStart == std::string::npos) {
@@ -662,42 +655,52 @@ static bool findModifier(const std::string &name, const size_t modStart, const c
     }
 }
 
-static const char *getFontLang(const GfxFont *font)
+static const char *getFontLang(const GfxFont &font)
 {
-    const char *lang;
+    static constexpr std::string_view adobeGB1 = "Adobe-GB1";
+    static constexpr std::string_view adobeCNS1 = "Adobe-CNS1";
+    static constexpr std::string_view adobeJapan1 = "Adobe-Japan1";
+    static constexpr std::string_view adobeJapan2 = "Adobe-Japan2";
+    static constexpr std::string_view adobeKorea1 = "Adobe-Korea1";
+    static constexpr std::string_view adobeUCS = "Adobe-UCS";
+    static constexpr std::string_view adobeIdentity = "Adobe-Identity";
 
     // find the language we want the font to support
-    if (font->isCIDFont()) {
-        const GooString *collection = ((GfxCIDFont *)font)->getCollection();
+    if (font.isCIDFont()) {
+        const GooString *const collection = static_cast<const GfxCIDFont *>(&font)->getCollection();
         if (collection) {
-            if (strcmp(collection->c_str(), "Adobe-GB1") == 0) {
-                lang = "zh-cn"; // Simplified Chinese
-            } else if (strcmp(collection->c_str(), "Adobe-CNS1") == 0) {
-                lang = "zh-tw"; // Traditional Chinese
-            } else if (strcmp(collection->c_str(), "Adobe-Japan1") == 0) {
-                lang = "ja"; // Japanese
-            } else if (strcmp(collection->c_str(), "Adobe-Japan2") == 0) {
-                lang = "ja"; // Japanese
-            } else if (strcmp(collection->c_str(), "Adobe-Korea1") == 0) {
-                lang = "ko"; // Korean
-            } else if (strcmp(collection->c_str(), "Adobe-UCS") == 0) {
-                lang = "xx";
-            } else if (strcmp(collection->c_str(), "Adobe-Identity") == 0) {
-                lang = "xx";
-            } else {
-                error(errUnimplemented, -1, "Unknown CID font collection: {0:t}. If this is expected to be a valid PDF document, please report to poppler bugtracker.", collection);
-                lang = "xx";
+            const std::string &collectionStr = collection->toStr();
+
+            if (collectionStr == adobeGB1) {
+                return "zh-cn"; // Simplified Chinese
             }
-        } else {
-            lang = "xx";
+            if (collectionStr == adobeCNS1) {
+                return "zh-tw"; // Traditional Chinese
+            }
+            if (collectionStr == adobeJapan1) {
+                return "ja"; // Japanese
+            }
+            if (collectionStr == adobeJapan2) {
+                return "ja"; // Japanese
+            }
+            if (collectionStr == adobeKorea1) {
+                return "ko"; // Korean
+            }
+            if (collectionStr == adobeUCS) {
+                return "xx";
+            }
+            if (collectionStr == adobeIdentity) {
+                return "xx";
+            }
+
+            error(errUnimplemented, -1, "Unknown CID font collection: {0:t}. If this is expected to be a valid PDF document, please report to poppler bugtracker.", collection);
         }
-    } else {
-        lang = "xx";
     }
-    return lang;
+
+    return "xx";
 }
 
-static FcPattern *buildFcPattern(const GfxFont *font, const GooString *base14Name)
+static FcPattern *buildFcPattern(const GfxFont &font, const GooString *base14Name)
 {
     int weight = -1, slant = -1, width = -1, spacing = -1;
     FcPattern *p;
@@ -705,7 +708,7 @@ static FcPattern *buildFcPattern(const GfxFont *font, const GooString *base14Nam
     // this is all heuristics will be overwritten if font had proper info
     std::string fontName;
     if (base14Name == nullptr) {
-        fontName = font->getNameWithoutSubsetTag();
+        fontName = font.getNameWithoutSubsetTag();
     } else {
         fontName = base14Name->toStr();
     }
@@ -752,23 +755,23 @@ static FcPattern *buildFcPattern(const GfxFont *font, const GooString *base14Nam
     }
 
     // use font flags
-    if (font->isFixedWidth()) {
+    if (font.isFixedWidth()) {
         spacing = FC_MONO;
     }
-    if (font->isBold()) {
+    if (font.isBold()) {
         weight = FC_WEIGHT_BOLD;
     }
-    if (font->isItalic()) {
+    if (font.isItalic()) {
         slant = FC_SLANT_ITALIC;
     }
 
     // if the FontDescriptor specified a family name use it
-    if (font->getFamily()) {
-        family = font->getFamily()->toStr();
+    if (font.getFamily()) {
+        family = font.getFamily()->toStr();
     }
 
     // if the FontDescriptor specified a weight use it
-    switch (font->getWeight()) {
+    switch (font.getWeight()) {
     case GfxFont::W100:
         weight = FC_WEIGHT_EXTRALIGHT;
         break;
@@ -801,7 +804,7 @@ static FcPattern *buildFcPattern(const GfxFont *font, const GooString *base14Nam
     }
 
     // if the FontDescriptor specified a width use it
-    switch (font->getStretch()) {
+    switch (font.getStretch()) {
     case GfxFont::UltraCondensed:
         width = FC_WIDTH_ULTRACONDENSED;
         break;
@@ -865,7 +868,7 @@ std::optional<std::string> GlobalParams::findFontFile(const std::string &fontNam
     return {};
 }
 
-#if defined(WITH_FONTCONFIGURATION_FONTCONFIG) || defined(WITH_FONTCONFIGURATION_WIN32)
+#if WITH_FONTCONFIGURATION_FONTCONFIG || WITH_FONTCONFIGURATION_WIN32
 
 static bool supportedFontForEmbedding(Unicode uChar, const char *filepath, int faceIndex)
 {
@@ -905,11 +908,11 @@ static bool supportedFontForEmbedding(Unicode uChar, const char *filepath, int f
 /* if you can't or don't want to use Fontconfig, you need to implement
    this function for your platform. For Windows, it's in GlobalParamsWin.cc
 */
-#ifdef WITH_FONTCONFIGURATION_FONTCONFIG
+#if WITH_FONTCONFIGURATION_FONTCONFIG
 // not needed for fontconfig
 void GlobalParams::setupBaseFonts(const char *) { }
 
-std::optional<std::string> GlobalParams::findBase14FontFile(const GooString *base14Name, const GfxFont *font, GooString *substituteFontName)
+std::optional<std::string> GlobalParams::findBase14FontFile(const GooString *base14Name, const GfxFont &font, GooString *substituteFontName)
 {
     SysFontType type;
     int fontNum;
@@ -917,12 +920,12 @@ std::optional<std::string> GlobalParams::findBase14FontFile(const GooString *bas
     return findSystemFontFile(font, &type, &fontNum, substituteFontName, base14Name);
 }
 
-std::optional<std::string> GlobalParams::findSystemFontFile(const GfxFont *font, SysFontType *type, int *fontNum, GooString *substituteFontName, const GooString *base14Name)
+std::optional<std::string> GlobalParams::findSystemFontFile(const GfxFont &font, SysFontType *type, int *fontNum, GooString *substituteFontName, const GooString *base14Name)
 {
     const SysFontInfo *fi = nullptr;
     FcPattern *p = nullptr;
     std::optional<std::string> path;
-    const std::optional<std::string> &fontName = font->getName();
+    const std::optional<std::string> &fontName = font.getName();
     GooString substituteName;
     if (!fontName) {
         return {};
@@ -930,7 +933,7 @@ std::optional<std::string> GlobalParams::findSystemFontFile(const GfxFont *font,
 
     globalParamsLocker();
 
-    if ((fi = sysFonts->find(*fontName, font->isFixedWidth(), true))) {
+    if ((fi = sysFonts->find(*fontName, font.isFixedWidth(), true))) {
         path = fi->path->toStr();
         *type = fi->type;
         *fontNum = fi->fontNum;
@@ -991,12 +994,11 @@ std::optional<std::string> GlobalParams::findSystemFontFile(const GfxFont *font,
                         substituteName.Set((char *)s2);
                         res = FcPatternGetString(set->fonts[i], FC_STYLE, 0, &s2);
                         if (res == FcResultMatch && s2) {
-                            GooString *style = new GooString((char *)s2);
-                            if (style->cmp("Regular") != 0) {
+                            const std::string style = { (char *)s2 };
+                            if (style != "Regular") {
                                 substituteName.append(" ");
                                 substituteName.append(style);
                             }
-                            delete style;
                         }
                     }
                 }
@@ -1006,8 +1008,8 @@ std::optional<std::string> GlobalParams::findSystemFontFile(const GfxFont *font,
                 }
                 if (!strncasecmp(ext, ".ttf", 4) || !strncasecmp(ext, ".ttc", 4) || !strncasecmp(ext, ".otf", 4)) {
                     int weight, slant;
-                    bool bold = font->isBold();
-                    bool italic = font->isItalic();
+                    bool bold = font.isBold();
+                    bool italic = font.isItalic();
                     bool oblique = false;
                     FcPatternGetInteger(set->fonts[i], FC_WEIGHT, 0, &weight);
                     FcPatternGetInteger(set->fonts[i], FC_SLANT, 0, &slant);
@@ -1023,14 +1025,14 @@ std::optional<std::string> GlobalParams::findSystemFontFile(const GfxFont *font,
                     *fontNum = 0;
                     *type = (!strncasecmp(ext, ".ttc", 4)) ? sysFontTTC : sysFontTTF;
                     FcPatternGetInteger(set->fonts[i], FC_INDEX, 0, fontNum);
-                    SysFontInfo *sfi = new SysFontInfo(std::make_unique<GooString>(*fontName), bold, italic, oblique, font->isFixedWidth(), std::make_unique<GooString>((char *)s), *type, *fontNum, substituteName.copy());
+                    SysFontInfo *sfi = new SysFontInfo(std::make_unique<GooString>(*fontName), bold, italic, oblique, font.isFixedWidth(), std::make_unique<GooString>((char *)s), *type, *fontNum, substituteName.copy());
                     sysFonts->addFcFont(sfi);
                     fi = sfi;
                     path = std::string((char *)s);
                 } else if (!strncasecmp(ext, ".pfa", 4) || !strncasecmp(ext, ".pfb", 4)) {
                     int weight, slant;
-                    bool bold = font->isBold();
-                    bool italic = font->isItalic();
+                    bool bold = font.isBold();
+                    bool italic = font.isItalic();
                     bool oblique = false;
                     FcPatternGetInteger(set->fonts[i], FC_WEIGHT, 0, &weight);
                     FcPatternGetInteger(set->fonts[i], FC_SLANT, 0, &slant);
@@ -1046,7 +1048,7 @@ std::optional<std::string> GlobalParams::findSystemFontFile(const GfxFont *font,
                     *fontNum = 0;
                     *type = (!strncasecmp(ext, ".pfa", 4)) ? sysFontPFA : sysFontPFB;
                     FcPatternGetInteger(set->fonts[i], FC_INDEX, 0, fontNum);
-                    SysFontInfo *sfi = new SysFontInfo(std::make_unique<GooString>(*fontName), bold, italic, oblique, font->isFixedWidth(), std::make_unique<GooString>((char *)s), *type, *fontNum, substituteName.copy());
+                    SysFontInfo *sfi = new SysFontInfo(std::make_unique<GooString>(*fontName), bold, italic, oblique, font.isFixedWidth(), std::make_unique<GooString>((char *)s), *type, *fontNum, substituteName.copy());
                     sysFonts->addFcFont(sfi);
                     fi = sfi;
                     path = std::string((char *)s);
@@ -1065,7 +1067,7 @@ std::optional<std::string> GlobalParams::findSystemFontFile(const GfxFont *font,
         }
         FcFontSetDestroy(set);
     }
-    if (!path && (fi = sysFonts->find(*fontName, font->isFixedWidth(), false))) {
+    if (!path && (fi = sysFonts->find(*fontName, font.isFixedWidth(), false))) {
         path = fi->path->toStr();
         *type = fi->type;
         *fontNum = fi->fontNum;
@@ -1096,12 +1098,14 @@ FamilyStyleFontSearchResult GlobalParams::findSystemFontFileForFamilyAndStyle(co
                 for (int i = 0; i < fontSet->nfont; i++) {
                     FcChar8 *fcFilePath = nullptr;
                     int faceIndex = 0;
+                    FcChar8 *fcFamily = nullptr;
                     FcPatternGetString(fontSet->fonts[i], FC_FILE, 0, &fcFilePath);
                     FcPatternGetInteger(fontSet->fonts[i], FC_INDEX, 0, &faceIndex);
+                    FcPatternGetString(fontSet->fonts[i], FC_FAMILY, 0, &fcFamily);
 
                     const std::string sFilePath = reinterpret_cast<char *>(fcFilePath);
                     if (std::ranges::find(filesToIgnore, sFilePath) == filesToIgnore.end()) {
-                        return FamilyStyleFontSearchResult(sFilePath, faceIndex);
+                        return FamilyStyleFontSearchResult(sFilePath, faceIndex, fontFamily != std::string(reinterpret_cast<char *>(fcFamily)));
                     }
                 }
             }
@@ -1114,7 +1118,7 @@ FamilyStyleFontSearchResult GlobalParams::findSystemFontFileForFamilyAndStyle(co
 
 UCharFontSearchResult GlobalParams::findSystemFontFileForUChar(Unicode uChar, const GfxFont &fontToEmulate)
 {
-    FcPattern *pattern = buildFcPattern(&fontToEmulate, nullptr);
+    FcPattern *pattern = buildFcPattern(fontToEmulate, nullptr);
 
     FcConfigSubstitute(nullptr, pattern, FcMatchPattern);
     FcDefaultSubstitute(pattern);
@@ -1153,10 +1157,10 @@ UCharFontSearchResult GlobalParams::findSystemFontFileForUChar(Unicode uChar, co
 
     return {};
 }
-#elif defined(WITH_FONTCONFIGURATION_ANDROID)
+#elif WITH_FONTCONFIGURATION_ANDROID
 // Uses the font file mapping created by GlobalParams::setupBaseFonts
 // to return the path to a base-14 font file
-std::optional<std::string> GlobalParams::findBase14FontFile(const GooString *base14Name, const GfxFont *font, GooString *substituteFontName)
+std::optional<std::string> GlobalParams::findBase14FontFile(const GooString *base14Name, const GfxFont & /*font*/, GooString * /*substituteFontName*/)
 {
     return findFontFile(base14Name->toStr());
 }
@@ -1179,9 +1183,9 @@ struct AFontDestroyer
 
 #    endif
 
-std::optional<std::string> GlobalParams::findSystemFontFile(const GfxFont *font, SysFontType *type, int *fontNum, GooString *substituteFontName, const GooString *base14Name)
+std::optional<std::string> GlobalParams::findSystemFontFile(const GfxFont &font, SysFontType *type, int * /*fontNum*/, GooString * /*substituteFontName*/, const GooString * /*base14Name*/)
 {
-    const std::optional<std::string> &fontName = font->getName();
+    const std::optional<std::string> &fontName = font.getName();
 
     if (!fontName) {
         return {};
@@ -1196,16 +1200,16 @@ std::optional<std::string> GlobalParams::findSystemFontFile(const GfxFont *font,
     // https://developer.android.com/ndk/reference/group/font
     std::string genericFontFamily = "serif";
 
-    if (!font->isSerif()) {
+    if (!font.isSerif()) {
         genericFontFamily = "sans-serif";
-    } else if (font->isFixedWidth()) {
+    } else if (font.isFixedWidth()) {
         genericFontFamily = "monospace";
     }
 
     std::unique_ptr<AFontMatcher, AFontMatcherDestroyer> fontmatcher { AFontMatcher_create() };
 
     // Set font weight and italics for the font.
-    AFontMatcher_setStyle(fontmatcher.get(), font->getWeight() * 100, font->isItalic());
+    AFontMatcher_setStyle(fontmatcher.get(), font.getWeight() * 100, font.isItalic());
 
     // Get font match and the font file's path
     std::unique_ptr<AFont, AFontDestroyer> afont { AFontMatcher_match(fontmatcher.get(), genericFontFamily.c_str(), (uint16_t *)u"A", 1, nullptr) };
@@ -1288,22 +1292,22 @@ void GlobalParams::setupBaseFonts(const char *dir)
     }
 }
 
-FamilyStyleFontSearchResult GlobalParams::findSystemFontFileForFamilyAndStyle(const std::string &fontFamily, const std::string &fontStyle, const std::vector<std::string> &filesToIgnore)
+FamilyStyleFontSearchResult GlobalParams::findSystemFontFileForFamilyAndStyle(const std::string & /*fontFamily*/, const std::string & /*fontStyle*/, const std::vector<std::string> & /*filesToIgnore*/)
 {
     error(errUnimplemented, -1, "GlobalParams::findSystemFontFileForFamilyAndStyle not implemented for this platform");
     return {};
 }
 
-UCharFontSearchResult GlobalParams::findSystemFontFileForUChar(Unicode uChar, const GfxFont &fontToEmulate)
+UCharFontSearchResult GlobalParams::findSystemFontFileForUChar(Unicode /*uChar*/, const GfxFont & /*fontToEmulate*/)
 {
     error(errUnimplemented, -1, "GlobalParams::findSystemFontFileForUChar not implemented for this platform");
     return {};
 }
 
-#elif defined(WITH_FONTCONFIGURATION_WIN32)
+#elif WITH_FONTCONFIGURATION_WIN32
 #    include "GlobalParamsWin.cc"
 
-std::optional<std::string> GlobalParams::findBase14FontFile(const GooString *base14Name, const GfxFont *font, GooString * /*substituteFontName*/)
+std::optional<std::string> GlobalParams::findBase14FontFile(const GooString *base14Name, const GfxFont & /*font*/, GooString * /*substituteFontName*/)
 {
     return findFontFile(base14Name->toStr());
 }
@@ -1322,7 +1326,7 @@ UCharFontSearchResult GlobalParams::findSystemFontFileForUChar(Unicode uChar, co
     return {};
 }
 
-std::optional<std::string> GlobalParams::findBase14FontFile(const GooString *base14Name, const GfxFont *font, GooString * /*substituteFontName*/)
+std::optional<std::string> GlobalParams::findBase14FontFile(const GooString *base14Name, const GfxFont & /*font*/, GooString * /*substituteFontName*/)
 {
     return findFontFile(base14Name->toStr());
 }
@@ -1385,18 +1389,18 @@ void GlobalParams::setupBaseFonts(const char *dir)
     }
 }
 
-std::optional<std::string> GlobalParams::findSystemFontFile(const GfxFont *font, SysFontType *type, int *fontNum, GooString * /*substituteFontName*/, const GooString * /*base14Name*/)
+std::optional<std::string> GlobalParams::findSystemFontFile(const GfxFont &font, SysFontType *type, int *fontNum, GooString * /*substituteFontName*/, const GooString * /*base14Name*/)
 {
     const SysFontInfo *fi;
     std::optional<std::string> path;
 
-    const std::optional<std::string> &fontName = font->getName();
+    const std::optional<std::string> &fontName = font.getName();
     if (!fontName) {
         return {};
     }
 
     globalParamsLocker();
-    if ((fi = sysFonts->find(*fontName, font->isFixedWidth(), false))) {
+    if ((fi = sysFonts->find(*fontName, font.isFixedWidth(), false))) {
         path = fi->path->toStr();
         *type = fi->type;
         *fontNum = fi->fontNum;
@@ -1440,13 +1444,13 @@ bool GlobalParams::getErrQuiet()
     return errQuiet;
 }
 
-std::shared_ptr<CharCodeToUnicode> GlobalParams::getCIDToUnicode(const GooString *collection)
+std::shared_ptr<CharCodeToUnicode> GlobalParams::getCIDToUnicode(const std::string &collection)
 {
     std::shared_ptr<CharCodeToUnicode> ctu;
 
     globalParamsLocker();
     if (!(ctu = cidToUnicodeCache->getCharCodeToUnicode(collection))) {
-        const auto cidToUnicode = cidToUnicodes.find(collection->toStr());
+        const auto cidToUnicode = cidToUnicodes.find(collection);
         if (cidToUnicode != cidToUnicodes.end()) {
             if ((ctu = CharCodeToUnicode::parseCIDToUnicode(cidToUnicode->second.c_str(), collection))) {
                 cidToUnicodeCache->add(ctu);
@@ -1469,7 +1473,7 @@ const UnicodeMap *GlobalParams::getUnicodeMap(const std::string &encodingName)
     return map;
 }
 
-std::shared_ptr<CMap> GlobalParams::getCMap(const GooString &collection, const GooString &cMapName)
+std::shared_ptr<CMap> GlobalParams::getCMap(const std::string &collection, const std::string &cMapName)
 {
     cMapCacheLocker();
     return cMapCache->getCMap(collection, cMapName);
@@ -1477,7 +1481,7 @@ std::shared_ptr<CMap> GlobalParams::getCMap(const GooString &collection, const G
 
 const UnicodeMap *GlobalParams::getTextEncoding()
 {
-    return getUnicodeMap(textEncoding);
+    return getUnicodeMap(getTextEncodingName());
 }
 
 std::vector<std::string> GlobalParams::getEncodingNames()
@@ -1530,7 +1534,7 @@ void GlobalParams::setErrQuiet(bool errQuietA)
 #ifdef ANDROID
 void GlobalParams::setFontDir(const std::string &fontDir)
 {
-#    if defined(WITH_FONTCONFIGURATION_ANDROID)
+#    if WITH_FONTCONFIGURATION_ANDROID
     displayFontDir = fontDir;
 #    endif
 }
