@@ -5,7 +5,7 @@
 // This file is licensed under the GPLv2 or later
 //
 // Copyright (C) 2013 Adrian Johnson <ajohnson@redneon.com>
-// Copyright (C) 2017, 2020, 2021, 2024 Albert Astals Cid <aacid@kde.org>
+// Copyright (C) 2017, 2020, 2021, 2024, 2025 Albert Astals Cid <aacid@kde.org>
 // Copyright (C) 2018 Klarälvdalens Datakonsult AB, a KDAB Group company, <info@kdab.com>. Work sponsored by the LiMux project of the city of Munich
 // Copyright (C) 2020 Oliver Sander <oliver.sander@tu-dresden.de>
 // Copyright (C) 2020 Nelson Benítez León <nbenitezl@gmail.com>
@@ -18,8 +18,6 @@
 
 #include "config.h"
 #include <cstdio>
-#include "Object.h"
-#include "Dict.h"
 #include "Annot.h"
 #include "PDFDoc.h"
 #include "JSInfo.h"
@@ -189,15 +187,15 @@ void JSInfo::scan(int nPages)
         }
         // annotation actions (links, screen, widget)
         annots = page->getAnnots();
-        for (Annot *a : annots->getAnnots()) {
+        for (const std::shared_ptr<Annot> &a : annots->getAnnots()) {
             if (a->getType() == Annot::typeLink) {
-                AnnotLink *annot = static_cast<AnnotLink *>(a);
+                AnnotLink *annot = static_cast<AnnotLink *>(a.get());
                 scanLinkAction(annot->getAction(), "Link Annotation Activated");
                 if (onlyFirstJS && hasJS) {
                     return;
                 }
             } else if (a->getType() == Annot::typeScreen) {
-                AnnotScreen *annot = static_cast<AnnotScreen *>(a);
+                AnnotScreen *annot = static_cast<AnnotScreen *>(a.get());
                 scanLinkAction(annot->getAction(), "Screen Annotation Activated");
                 scanLinkAction(annot->getAdditionalAction(Annot::actionCursorEntering).get(), "Screen Annotation Cursor Enter");
                 scanLinkAction(annot->getAdditionalAction(Annot::actionCursorLeaving).get(), "Screen Annotation Cursor Leave");
@@ -214,7 +212,7 @@ void JSInfo::scan(int nPages)
                     return;
                 }
             } else if (a->getType() == Annot::typeWidget) {
-                AnnotWidget *annot = static_cast<AnnotWidget *>(a);
+                AnnotWidget *annot = static_cast<AnnotWidget *>(a.get());
                 scanLinkAction(annot->getAction(), "Widget Annotation Activated");
                 scanLinkAction(annot->getAdditionalAction(Annot::actionCursorEntering).get(), "Widget Annotation Cursor Enter");
                 scanLinkAction(annot->getAdditionalAction(Annot::actionCursorLeaving).get(), "Widget Annotation Cursor Leave");
