@@ -6,17 +6,17 @@
 //
 // Copyright 2010, 2012 Hib Eris <hib@hiberis.nl>
 // Copyright 2015 Jason Crain <jason@aquaticape.us>
-// Copyright 2017, 2019 Albert Astals Cid <aacid@kde.org>
+// Copyright 2017, 2019, 2025 Albert Astals Cid <aacid@kde.org>
 // Copyright 2019 Adam Reichold <adam.reichold@t-online.de>
 // Copyright 2019 Even Rouault <even.rouault@spatialys.com>
 // Copyright 2025 g10 Code GmbH, Author: Sune Stolborg Vuorela <sune@vuorela.dk>
 // Copyright (C) 2025 Jonathan Hähne <jonathan.haehne@hotmail.com>
+// Copyright (C) 2025 Arnav V <arnav0872@gmail.com>
 //
 //========================================================================
 
 #include "Linearization.h"
 #include "Parser.h"
-#include "Lexer.h"
 
 //------------------------------------------------------------------------
 // Linearization
@@ -26,7 +26,7 @@ Linearization::Linearization(BaseStream *str)
 {
     Parser *parser;
 
-    (void)str->reset();
+    (void)str->rewind();
     parser = new Parser(nullptr, str->makeSubStream(str->getStart(), false, 0, Object::null()), false);
     Object obj1 = parser->getObj();
     Object obj2 = parser->getObj();
