@@ -5,6 +5,7 @@
 // This file is licensed under the GPLv2 or later
 //
 // Copyright 2010 Hib Eris <hib@hiberis.nl>
+// Copyright 2019, 2021 Albert Astals Cid <aacid@kde.org>
 //
 //========================================================================
 
@@ -18,27 +19,25 @@ class BaseStream;
 // Linearization
 //------------------------------------------------------------------------
 
-class Linearization {
+class Linearization
+{
 public:
+    explicit Linearization(BaseStream *str);
+    ~Linearization();
 
-  Linearization(BaseStream *str);
-  ~Linearization();
-
-  unsigned int getLength();
-  unsigned int getHintsOffset();
-  unsigned int getHintsLength();
-  unsigned int getHintsOffset2();
-  unsigned int getHintsLength2();
-  int getObjectNumberFirst();
-  unsigned int getEndFirst();
-  int getNumPages();
-  unsigned int getMainXRefEntriesOffset();
-  int getPageFirst();
+    unsigned int getLength() const;
+    unsigned int getHintsOffset() const;
+    unsigned int getHintsLength() const;
+    unsigned int getHintsOffset2() const;
+    unsigned int getHintsLength2() const;
+    int getObjectNumberFirst() const;
+    unsigned int getEndFirst() const;
+    int getNumPages() const;
+    unsigned int getMainXRefEntriesOffset() const;
+    int getPageFirst() const;
 
 private:
-
-  Object linDict;
-
+    Object linDict;
 };
 
 #endif
