@@ -16,7 +16,7 @@
 // Copyright (C) 2006, 2008 Pino Toscano <pino@kde.org>
 // Copyright (C) 2007, 2010, 2011 Carlos Garcia Campos <carlosgc@gnome.org>
 // Copyright (C) 2008 Hugo Mercier <hmercier31@gmail.com>
-// Copyright (C) 2008-2010, 2012-2014, 2016-2024 Albert Astals Cid <aacid@kde.org>
+// Copyright (C) 2008-2010, 2012-2014, 2016-2025 Albert Astals Cid <aacid@kde.org>
 // Copyright (C) 2009 Kovid Goyal <kovid@kovidgoyal.net>
 // Copyright (C) 2009 Ilya Gorenbein <igorenbein@finjan.com>
 // Copyright (C) 2012 Tobias Koening <tobias.koenig@kdab.com>
@@ -37,7 +37,7 @@
 
 #include <cstddef>
 #include <cstring>
-#include "goo/gmem.h"
+#include <memory>
 #include "goo/GooString.h"
 #include "Error.h"
 #include "Object.h"
@@ -142,7 +142,7 @@ std::unique_ptr<LinkAction> LinkAction::parseAction(const Object *obj, const std
 
         // unknown action
     } else if (obj2.isName()) {
-        action = std::make_unique<LinkUnknown>(obj2.getName());
+        action = std::make_unique<LinkUnknown>(obj2.getNameString());
 
         // action is missing or wrong type
     } else {
@@ -216,7 +216,7 @@ const std::vector<std::unique_ptr<LinkAction>> &LinkAction::nextActions() const
 // LinkDest
 //------------------------------------------------------------------------
 
-LinkDest::LinkDest(const Array *a)
+LinkDest::LinkDest(const Array &a)
 {
     // initialize fields
     left = bottom = right = top = zoom = 0;
@@ -224,11 +224,11 @@ LinkDest::LinkDest(const Array *a)
     ok = false;
 
     // get page
-    if (a->getLength() < 2) {
+    if (a.getLength() < 2) {
         error(errSyntaxWarning, -1, "Annotation destination array is too short");
         return;
     }
-    const Object &obj0 = a->getNF(0);
+    const Object &obj0 = a.getNF(0);
     if (obj0.isInt()) {
         pageNum = obj0.getInt() + 1;
         pageIsRef = false;
@@ -241,15 +241,15 @@ LinkDest::LinkDest(const Array *a)
     }
 
     // get destination type
-    Object obj1 = a->get(1);
+    Object obj1 = a.get(1);
 
     // XYZ link
     if (obj1.isName("XYZ")) {
         kind = destXYZ;
-        if (a->getLength() < 3) {
+        if (a.getLength() < 3) {
             changeLeft = false;
         } else {
-            Object obj2 = a->get(2);
+            Object obj2 = a.get(2);
             if (obj2.isNull()) {
                 changeLeft = false;
             } else if (obj2.isNum()) {
@@ -260,10 +260,10 @@ LinkDest::LinkDest(const Array *a)
                 return;
             }
         }
-        if (a->getLength() < 4) {
+        if (a.getLength() < 4) {
             changeTop = false;
         } else {
-            Object obj2 = a->get(3);
+            Object obj2 = a.get(3);
             if (obj2.isNull()) {
                 changeTop = false;
             } else if (obj2.isNum()) {
@@ -274,10 +274,10 @@ LinkDest::LinkDest(const Array *a)
                 return;
             }
         }
-        if (a->getLength() < 5) {
+        if (a.getLength() < 5) {
             changeZoom = false;
         } else {
-            Object obj2 = a->get(4);
+            Object obj2 = a.get(4);
             if (obj2.isNull()) {
                 changeZoom = false;
             } else if (obj2.isNum()) {
@@ -296,10 +296,10 @@ LinkDest::LinkDest(const Array *a)
         // FitH link
     } else if (obj1.isName("FitH")) {
         kind = destFitH;
-        if (a->getLength() < 3) {
+        if (a.getLength() < 3) {
             changeTop = false;
         } else {
-            Object obj2 = a->get(2);
+            Object obj2 = a.get(2);
             if (obj2.isNull()) {
                 changeTop = false;
             } else if (obj2.isNum()) {
@@ -313,12 +313,12 @@ LinkDest::LinkDest(const Array *a)
 
         // FitV link
     } else if (obj1.isName("FitV")) {
-        if (a->getLength() < 3) {
+        if (a.getLength() < 3) {
             error(errSyntaxWarning, -1, "Annotation destination array is too short");
             return;
         }
         kind = destFitV;
-        Object obj2 = a->get(2);
+        Object obj2 = a.get(2);
         if (obj2.isNull()) {
             changeLeft = false;
         } else if (obj2.isNum()) {
@@ -331,33 +331,33 @@ LinkDest::LinkDest(const Array *a)
 
         // FitR link
     } else if (obj1.isName("FitR")) {
-        if (a->getLength() < 6) {
+        if (a.getLength() < 6) {
             error(errSyntaxWarning, -1, "Annotation destination array is too short");
             return;
         }
         kind = destFitR;
-        Object obj2 = a->get(2);
+        Object obj2 = a.get(2);
         if (obj2.isNum()) {
             left = obj2.getNum();
         } else {
             error(errSyntaxWarning, -1, "Bad annotation destination position");
             kind = destFit;
         }
-        obj2 = a->get(3);
+        obj2 = a.get(3);
         if (obj2.isNum()) {
             bottom = obj2.getNum();
         } else {
             error(errSyntaxWarning, -1, "Bad annotation destination position");
             kind = destFit;
         }
-        obj2 = a->get(4);
+        obj2 = a.get(4);
         if (obj2.isNum()) {
             right = obj2.getNum();
         } else {
             error(errSyntaxWarning, -1, "Bad annotation destination position");
             kind = destFit;
         }
-        obj2 = a->get(5);
+        obj2 = a.get(5);
         if (obj2.isNum()) {
             top = obj2.getNum();
         } else {
@@ -371,12 +371,12 @@ LinkDest::LinkDest(const Array *a)
 
         // FitBH link
     } else if (obj1.isName("FitBH")) {
-        if (a->getLength() < 3) {
+        if (a.getLength() < 3) {
             error(errSyntaxWarning, -1, "Annotation destination array is too short");
             return;
         }
         kind = destFitBH;
-        Object obj2 = a->get(2);
+        Object obj2 = a.get(2);
         if (obj2.isNull()) {
             changeTop = false;
         } else if (obj2.isNum()) {
@@ -389,12 +389,12 @@ LinkDest::LinkDest(const Array *a)
 
         // FitBV link
     } else if (obj1.isName("FitBV")) {
-        if (a->getLength() < 3) {
+        if (a.getLength() < 3) {
             error(errSyntaxWarning, -1, "Annotation destination array is too short");
             return;
         }
         kind = destFitBV;
-        Object obj2 = a->get(2);
+        Object obj2 = a.get(2);
         if (obj2.isNull()) {
             changeLeft = false;
         } else if (obj2.isNum()) {
@@ -422,13 +422,13 @@ LinkGoTo::LinkGoTo(const Object *destObj)
 {
     // named destination
     if (destObj->isName()) {
-        namedDest = std::make_unique<GooString>(destObj->getName());
+        namedDest = std::make_unique<GooString>(destObj->getNameString());
     } else if (destObj->isString()) {
         namedDest = destObj->getString()->copy();
 
         // destination dictionary
     } else if (destObj->isArray()) {
-        dest = std::make_unique<LinkDest>(destObj->getArray());
+        dest = std::make_unique<LinkDest>(*destObj->getArray());
         if (!dest->isOk()) {
             dest.reset();
         }
@@ -450,18 +450,18 @@ LinkGoToR::LinkGoToR(Object *fileSpecObj, Object *destObj)
     // get file name
     Object obj1 = getFileSpecNameForPlatform(fileSpecObj);
     if (obj1.isString()) {
-        fileName = obj1.getString()->copy();
+        fileName = obj1.takeString();
     }
 
     // named destination
     if (destObj->isName()) {
-        namedDest = std::make_unique<GooString>(destObj->getName());
+        namedDest = std::make_unique<GooString>(destObj->getNameString());
     } else if (destObj->isString()) {
         namedDest = destObj->getString()->copy();
 
         // destination dictionary
     } else if (destObj->isArray()) {
-        dest = std::make_unique<LinkDest>(destObj->getArray());
+        dest = std::make_unique<LinkDest>(*destObj->getArray());
         if (!dest->isOk()) {
             dest.reset();
         }
@@ -486,7 +486,7 @@ LinkLaunch::LinkLaunch(const Object *actionObj)
         if (!obj1.isNull()) {
             Object obj3 = getFileSpecNameForPlatform(&obj1);
             if (obj3.isString()) {
-                fileName = obj3.getString()->copy();
+                fileName = obj3.takeString();
             }
         } else {
 #ifdef _WIN32
@@ -500,11 +500,11 @@ LinkLaunch::LinkLaunch(const Object *actionObj)
                 Object obj2 = obj1.dictLookup("F");
                 Object obj3 = getFileSpecNameForPlatform(&obj2);
                 if (obj3.isString()) {
-                    fileName = obj3.getString()->copy();
+                    fileName = obj3.takeString();
                 }
                 obj2 = obj1.dictLookup("P");
                 if (obj2.isString()) {
-                    params = obj2.getString()->copy();
+                    params = obj2.takeString();
                 }
             } else {
                 error(errSyntaxWarning, -1, "Bad launch-type link action");
@@ -566,7 +566,7 @@ LinkNamed::LinkNamed(const Object *nameObj)
 {
     hasNameFlag = false;
     if (nameObj->isName()) {
-        name = (nameObj->getName()) ? nameObj->getName() : "";
+        name = nameObj->getNameString();
         hasNameFlag = true;
     }
 }
@@ -649,7 +649,7 @@ LinkSound::LinkSound(const Object *soundObj)
         }
         // 'Sound' object
         tmp = soundObj->dictLookup("Sound");
-        sound = Sound::parseSound(&tmp);
+        sound = Sound::parseSound(tmp);
     }
 }
 
@@ -689,7 +689,7 @@ LinkRendition::LinkRendition(const Object *obj)
                 // retrieve rendition object
                 Object renditionObj = obj->dictLookup("R");
                 if (renditionObj.isDict()) {
-                    media = new MediaRendition(&renditionObj);
+                    media = new MediaRendition(*renditionObj.getDict());
                 } else if (operationCode == 0 || operationCode == 4) {
                     error(errSyntaxWarning, -1, "Invalid Rendition Action: no R field with op = {0:d}", operationCode);
                     renditionObj.setToNull();
@@ -776,16 +776,15 @@ LinkOCGState::LinkOCGState(const Object *obj) : isValid(true)
                     stateList.push_back(stList);
                 }
 
-                const char *name = obj2.getName();
                 stList.list.clear();
-                if (!strcmp(name, "ON")) {
+                if (obj2.isName("ON")) {
                     stList.st = On;
-                } else if (!strcmp(name, "OFF")) {
+                } else if (obj2.isName("OFF")) {
                     stList.st = Off;
-                } else if (!strcmp(name, "Toggle")) {
+                } else if (obj2.isName("Toggle")) {
                     stList.st = Toggle;
                 } else {
-                    error(errSyntaxWarning, -1, "Invalid name '{0:s}' in OCG Action state array", name);
+                    error(errSyntaxWarning, -1, "Invalid name '{0:s}' in OCG Action state array", obj2.getName());
                     isValid = false;
                 }
             } else if (obj2.isRef()) {
@@ -849,7 +848,7 @@ LinkResetForm::LinkResetForm(const Object *obj)
         for (int i = 0; i < obj1.arrayGetLength(); ++i) {
             const Object &obj2 = obj1.arrayGetNF(i);
             if (obj2.isName()) {
-                fields[i] = std::string(obj2.getName());
+                fields[i] = obj2.getNameString();
             } else if (obj2.isString()) {
                 fields[i] = obj2.getString()->toStr();
             } else if (obj2.isRef()) {
@@ -891,7 +890,7 @@ LinkSubmitForm::LinkSubmitForm(const Object *obj)
         for (int i = 0; i < objFields.arrayGetLength(); ++i) {
             const Object &objNF = objFields.arrayGetNF(i);
             if (objNF.isName()) {
-                fields[i] = std::string(objNF.getName());
+                fields[i] = objNF.getNameString();
             } else if (objNF.isString()) {
                 fields[i] = objNF.getString()->toStr();
             } else if (objNF.isRef()) {
@@ -928,10 +927,7 @@ LinkSubmitForm::~LinkSubmitForm() = default;
 // LinkUnknown
 //------------------------------------------------------------------------
 
-LinkUnknown::LinkUnknown(const char *actionA)
-{
-    action = std::string(actionA ? actionA : "");
-}
+LinkUnknown::LinkUnknown(std::string &&actionA) : action { actionA } { }
 
 LinkUnknown::~LinkUnknown() = default;
 
@@ -945,20 +941,13 @@ Links::Links(Annots *annots)
         return;
     }
 
-    for (Annot *annot : annots->getAnnots()) {
+    for (const std::shared_ptr<Annot> &annot : annots->getAnnots()) {
 
         if (annot->getType() != Annot::typeLink) {
             continue;
         }
-
-        annot->incRefCnt();
-        links.push_back(static_cast<AnnotLink *>(annot));
+        links.push_back(std::static_pointer_cast<AnnotLink>(annot));
     }
 }
 
-Links::~Links()
-{
-    for (AnnotLink *link : links) {
-        link->decRefCnt();
-    }
-}
+Links::~Links() = default;
