@@ -19,7 +19,7 @@
 // Copyright (C) 2007, 2011, 2017, 2021, 2023 Adrian Johnson <ajohnson@redneon.com>
 // Copyright (C) 2009-2013, 2015 Thomas Freitag <Thomas.Freitag@alfa.de>
 // Copyright (C) 2009, 2011 Carlos Garcia Campos <carlosgc@gnome.org>
-// Copyright (C) 2009, 2012, 2013, 2018, 2019, 2021, 2024 Albert Astals Cid <aacid@kde.org>
+// Copyright (C) 2009, 2012, 2013, 2018, 2019, 2021, 2024, 2025 Albert Astals Cid <aacid@kde.org>
 // Copyright (C) 2010 Christian Feuersänger <cfeuersaenger@googlemail.com>
 // Copyright (C) 2012 Fabio D'Urso <fabiodurso@hotmail.it>
 // Copyright (C) 2012 William Bader <williambader@hotmail.com>
@@ -88,7 +88,7 @@ public:
 
     // Does this device support specific shading types?
     // see gouraudTriangleShadedFill() and patchMeshShadedFill()
-    virtual bool useShadedFills(int type) { return false; }
+    virtual bool useShadedFills(int /*type*/) { return false; }
 
     // Does this device use FillColorStop()?
     virtual bool useFillColorStop() { return false; }
@@ -124,14 +124,15 @@ public:
     // returns false, the page display is aborted.  Typically, an
     // OutputDev will use some alternate means to display the page
     // before returning false.
-    virtual bool checkPageSlice(Page *page, double hDPI, double vDPI, int rotate, bool useMediaBox, bool crop, int sliceX, int sliceY, int sliceW, int sliceH, bool printing, bool (*abortCheckCbk)(void *data) = nullptr,
-                                void *abortCheckCbkData = nullptr, bool (*annotDisplayDecideCbk)(Annot *annot, void *user_data) = nullptr, void *annotDisplayDecideCbkData = nullptr)
+    virtual bool checkPageSlice(Page * /*page*/, double /*hDPI*/, double /*vDPI*/, int /*rotate*/, bool /*useMediaBox*/, bool /*crop*/, int /*sliceX*/, int /*sliceY*/, int /*sliceW*/, int /*sliceH*/, bool /*printing*/,
+                                bool (* /*abortCheckCbk*/)(void *data) = nullptr, void * /*abortCheckCbkData */ = nullptr, bool (* /*annotDisplayDecideCbk*/)(Annot *annot, void *user_data) = nullptr,
+                                void * /*annotDisplayDecideCbkData*/ = nullptr)
     {
         return true;
     }
 
     // Start a page.
-    virtual void startPage(int pageNum, GfxState *state, XRef *xref) { }
+    virtual void startPage(int /*pageNum*/, GfxState * /*state*/, XRef * /*xref*/) { }
 
     // End a page.
     virtual void endPage() { }
@@ -141,7 +142,7 @@ public:
 
     virtual void initGfxState(GfxState *state)
     {
-#ifdef USE_CMS
+#if USE_CMS
         state->setDisplayProfile(displayprofile);
 
         auto invalidref = Ref::INVALID();
@@ -168,6 +169,8 @@ public:
             cs->buildTransforms(state); // needs to happen after state->setDisplayProfile has been called
             state->setDefaultCMYKColorSpace(std::move(cs));
         }
+#else
+        (void)state;
 #endif
     }
 
@@ -234,7 +237,8 @@ public:
     virtual void stroke(GfxState * /*state*/) { }
     virtual void fill(GfxState * /*state*/) { }
     virtual void eoFill(GfxState * /*state*/) { }
-    virtual bool tilingPatternFill(GfxState * /*state*/, Gfx * /*gfx*/, Catalog * /*cat*/, GfxTilingPattern * /*tPat*/, const double * /*mat*/, int /*x0*/, int /*y0*/, int /*x1*/, int /*y1*/, double /*xStep*/, double /*yStep*/)
+    virtual bool tilingPatternFill(GfxState * /*state*/, Gfx * /*gfx*/, Catalog * /*cat*/, GfxTilingPattern * /*tPat*/, const std::array<double, 6> & /*mat*/, int /*x0*/, int /*y0*/, int /*x1*/, int /*y1*/, double /*xStep*/,
+                                   double /*yStep*/)
     {
         return false;
     }
@@ -243,8 +247,8 @@ public:
     virtual bool axialShadedSupportExtend(GfxState * /*state*/, GfxAxialShading * /*shading*/) { return false; }
     virtual bool radialShadedFill(GfxState * /*state*/, GfxRadialShading * /*shading*/, double /*sMin*/, double /*sMax*/) { return false; }
     virtual bool radialShadedSupportExtend(GfxState * /*state*/, GfxRadialShading * /*shading*/) { return false; }
-    virtual bool gouraudTriangleShadedFill(GfxState *state, GfxGouraudTriangleShading *shading) { return false; }
-    virtual bool patchMeshShadedFill(GfxState *state, GfxPatchMeshShading *shading) { return false; }
+    virtual bool gouraudTriangleShadedFill(GfxState * /*state*/, GfxGouraudTriangleShading * /*shading*/) { return false; }
+    virtual bool patchMeshShadedFill(GfxState * /*state*/, GfxPatchMeshShading * /*shading*/) { return false; }
 
     //----- path clipping
 
@@ -313,11 +317,9 @@ public:
     virtual void markPoint(const char *name);
     virtual void markPoint(const char *name, Dict *properties);
 
-#ifdef OPI_SUPPORT
     //----- OPI functions
     virtual void opiBegin(GfxState *state, Dict *opiDict);
     virtual void opiEnd(GfxState *state, Dict *opiDict);
-#endif
 
     //----- Type 3 font operators
     virtual void type3D0(GfxState * /*state*/, double /*wx*/, double /*wy*/) { }
@@ -338,10 +340,10 @@ public:
 
     //----- transparency groups and soft masks
     virtual bool checkTransparencyGroup(GfxState * /*state*/, bool /*knockout*/) { return true; }
-    virtual void beginTransparencyGroup(GfxState * /*state*/, const double * /*bbox*/, GfxColorSpace * /*blendingColorSpace*/, bool /*isolated*/, bool /*knockout*/, bool /*forSoftMask*/) { }
+    virtual void beginTransparencyGroup(GfxState * /*state*/, const std::array<double, 4> & /*bbox*/, GfxColorSpace * /*blendingColorSpace*/, bool /*isolated*/, bool /*knockout*/, bool /*forSoftMask*/) { }
     virtual void endTransparencyGroup(GfxState * /*state*/) { }
-    virtual void paintTransparencyGroup(GfxState * /*state*/, const double * /*bbox*/) { }
-    virtual void setSoftMask(GfxState * /*state*/, const double * /*bbox*/, bool /*alpha*/, Function * /*transferFunc*/, GfxColor * /*backdropColor*/) { }
+    virtual void paintTransparencyGroup(GfxState * /*state*/, const std::array<double, 4> & /*bbox*/) { }
+    virtual void setSoftMask(GfxState * /*state*/, const std::array<double, 4> & /*bbox*/, bool /*alpha*/, Function * /*transferFunc*/, GfxColor * /*backdropColor*/) { }
     virtual void clearSoftMask(GfxState * /*state*/) { }
 
     //----- links
@@ -352,7 +354,7 @@ public:
     virtual void setVectorAntialias(bool /*vaa*/) { }
 #endif
 
-#ifdef USE_CMS
+#if USE_CMS
     void setDisplayProfile(const GfxLCMSProfilePtr &profile) { displayprofile = profile; }
     GfxLCMSProfilePtr getDisplayProfile() const { return displayprofile; }
     void setDefaultGrayProfile(const GfxLCMSProfilePtr &profile) { defaultGrayProfile = profile; }
@@ -370,7 +372,7 @@ private:
     double defICTM[6]; // inverse of default CTM
     std::unique_ptr<std::unordered_map<std::string, ProfileData>> profileHash;
 
-#ifdef USE_CMS
+#if USE_CMS
     GfxLCMSProfilePtr displayprofile;
     GfxLCMSProfilePtr defaultGrayProfile;
     GfxLCMSProfilePtr defaultRGBProfile;
