@@ -20,7 +20,7 @@
 // Copyright (C) 2011 Andreas Hartmetz <ahartmetz@gmail.com>
 // Copyright (C) 2011 Andrea Canciani <ranma42@gmail.com>
 // Copyright (C) 2011, 2017 Adrian Johnson <ajohnson@redneon.com>
-// Copyright (C) 2012, 2015, 2018-2021 Albert Astals Cid <aacid@kde.org>
+// Copyright (C) 2012, 2015, 2018-2021, 2025 Albert Astals Cid <aacid@kde.org>
 // Copyright (C) 2015, 2016 William Bader <williambader@hotmail.com>
 // Copyright (C) 2018 Stefan Brüns <stefan.bruens@rwth-aachen.de>
 //
@@ -65,15 +65,15 @@ public:
 
     ~SplashFunctionPattern() override;
 
-    bool testPosition(int x, int y) override { return true; }
+    bool testPosition(int /*x*/, int /*y*/) const override { return true; }
 
-    bool isStatic() override { return false; }
+    bool isStatic() const override { return false; }
 
-    bool getColor(int x, int y, SplashColorPtr c) override;
+    bool getColor(int x, int y, SplashColorPtr c) const override;
 
     virtual GfxFunctionShading *getShading() { return shading; }
 
-    bool isCMYK() override { return gfxMode == csDeviceCMYK; }
+    bool isCMYK() const override { return gfxMode == csDeviceCMYK; }
 
 protected:
     Matrix ictm;
@@ -91,17 +91,17 @@ public:
 
     ~SplashUnivariatePattern() override;
 
-    bool getColor(int x, int y, SplashColorPtr c) override;
+    bool getColor(int x, int y, SplashColorPtr c) const override;
 
-    bool testPosition(int x, int y) override;
+    bool testPosition(int x, int y) const override;
 
-    bool isStatic() override { return false; }
+    bool isStatic() const override { return false; }
 
-    virtual bool getParameter(double xs, double ys, double *t) = 0;
+    virtual bool getParameter(double xs, double ys, double *t) const = 0;
 
     virtual GfxUnivariateShading *getShading() { return shading; }
 
-    bool isCMYK() override { return gfxMode == csDeviceCMYK; }
+    bool isCMYK() const override { return gfxMode == csDeviceCMYK; }
 
 protected:
     Matrix ictm;
@@ -121,7 +121,7 @@ public:
 
     ~SplashAxialPattern() override;
 
-    bool getParameter(double xc, double yc, double *t) override;
+    bool getParameter(double xc, double yc, double *t) const override;
 
 private:
     double x0, y0, x1, y1;
@@ -138,13 +138,13 @@ public:
 
     ~SplashGouraudPattern() override;
 
-    bool getColor(int x, int y, SplashColorPtr c) override { return false; }
+    bool getColor(int /*x*/, int /*y*/, SplashColorPtr /*c*/) const override { return false; }
 
-    bool testPosition(int x, int y) override { return false; }
+    bool testPosition(int /*x*/, int /*y*/) const override { return false; }
 
-    bool isStatic() override { return false; }
+    bool isStatic() const override { return false; }
 
-    bool isCMYK() override { return gfxMode == csDeviceCMYK; }
+    bool isCMYK() const override { return gfxMode == csDeviceCMYK; }
 
     bool isParameterized() override { return shading->isParameterized(); }
     int getNTriangles() override { return shading->getNTriangles(); }
@@ -174,7 +174,7 @@ public:
 
     ~SplashRadialPattern() override;
 
-    bool getParameter(double xs, double ys, double *t) override;
+    bool getParameter(double xs, double ys, double *t) const override;
 
 private:
     double x0, y0, r0, dx, dy, dr;
@@ -265,7 +265,7 @@ public:
     void stroke(GfxState *state) override;
     void fill(GfxState *state) override;
     void eoFill(GfxState *state) override;
-    bool tilingPatternFill(GfxState *state, Gfx *gfx, Catalog *catalog, GfxTilingPattern *tPat, const double *mat, int x0, int y0, int x1, int y1, double xStep, double yStep) override;
+    bool tilingPatternFill(GfxState *state, Gfx *gfx, Catalog *catalog, GfxTilingPattern *tPat, const std::array<double, 6> &mat, int x0, int y0, int x1, int y1, double xStep, double yStep) override;
     bool functionShadedFill(GfxState *state, GfxFunctionShading *shading) override;
     bool axialShadedFill(GfxState *state, GfxAxialShading *shading, double tMin, double tMax) override;
     bool radialShadedFill(GfxState *state, GfxRadialShading *shading, double tMin, double tMax) override;
@@ -298,10 +298,10 @@ public:
 
     //----- transparency groups and soft masks
     bool checkTransparencyGroup(GfxState *state, bool knockout) override;
-    void beginTransparencyGroup(GfxState *state, const double *bbox, GfxColorSpace *blendingColorSpace, bool isolated, bool knockout, bool forSoftMask) override;
+    void beginTransparencyGroup(GfxState *state, const std::array<double, 4> &bbox, GfxColorSpace *blendingColorSpace, bool isolated, bool knockout, bool forSoftMask) override;
     void endTransparencyGroup(GfxState *state) override;
-    void paintTransparencyGroup(GfxState *state, const double *bbox) override;
-    void setSoftMask(GfxState *state, const double *bbox, bool alpha, Function *transferFunc, GfxColor *backdropColor) override;
+    void paintTransparencyGroup(GfxState *state, const std::array<double, 4> &bbox) override;
+    void setSoftMask(GfxState *state, const std::array<double, 4> &bbox, bool alpha, Function *transferFunc, GfxColor *backdropColor) override;
     void clearSoftMask(GfxState *state) override;
 
     //----- special access
@@ -341,26 +341,17 @@ public:
     void setVectorAntialias(bool vaa) override;
 #endif
 
-    bool getFontAntialias()
-    {
-        return fontAntialias;
-    }
-    void setFontAntialias(bool anti)
-    {
-        fontAntialias = anti;
-    }
+    bool getFontAntialias() { return fontAntialias; }
+    void setFontAntialias(bool anti) { fontAntialias = anti; }
 
     void setFreeTypeHinting(bool enable, bool enableSlightHinting);
-    void setEnableFreeType(bool enable)
-    {
-        enableFreeType = enable;
-    }
+    void setEnableFreeType(bool enable) { enableFreeType = enable; }
 
 protected:
     void doUpdateFont(GfxState *state);
 
 private:
-    bool univariateShadedFill(GfxState *state, SplashUnivariatePattern *pattern, double tMin, double tMax);
+    bool univariateShadedFill(GfxState *state, SplashUnivariatePattern *pattern);
 
     void setupScreenParams(double hDPI, double vDPI);
     SplashPattern *getColor(GfxGray gray);
@@ -369,9 +360,9 @@ private:
     SplashPattern *getColor(GfxColor *deviceN);
     static void getMatteColor(SplashColorMode colorMode, GfxImageColorMap *colorMap, const GfxColor *matteColor, SplashColor splashMatteColor);
     void setOverprintMask(GfxColorSpace *colorSpace, bool overprintFlag, int overprintMode, const GfxColor *singleColor, bool grayIndexed = false);
-    SplashPath convertPath(GfxState *state, const GfxPath *path, bool dropEmptySubpaths);
+    static SplashPath convertPath(const GfxPath *path, bool dropEmptySubpaths);
     void drawType3Glyph(GfxState *state, T3FontCache *t3Font, T3FontCacheTag *tag, unsigned char *data);
-#ifdef USE_CMS
+#if USE_CMS
     bool useIccImageSrc(void *data);
     static void iccTransform(void *data, SplashBitmap *bitmap);
     static bool iccImageSrc(void *data, SplashColorPtr colorLine, unsigned char *alphaLine);
