@@ -7,20 +7,18 @@
 // Copyright 2013, 2014 Igalia S.L.
 // Copyright 2014 Fabio D'Urso <fabiodurso@hotmail.it>
 // Copyright 2017 Jan-Erik S <janerik234678@gmail.com>
-// Copyright 2017-2019, 2023 Albert Astals Cid <aacid@kde.org>
+// Copyright 2017-2019, 2023, 2025, 2026 Albert Astals Cid <aacid@kde.org>
 // Copyright 2017, 2018 Adrian Johnson <ajohnson@redneon.com>
 // Copyright 2018, Adam Reichold <adam.reichold@t-online.de>
 // Copyright 2025, Kevin Backhouse <kevinbackhouse@github.com>
 //
 //========================================================================
 
-#include "goo/GooString.h"
 #include "StructTreeRoot.h"
 #include "StructElement.h"
 #include "PDFDoc.h"
 #include "Object.h"
 #include "Dict.h"
-#include <set>
 #include <cassert>
 
 StructTreeRoot::StructTreeRoot(PDFDoc *docA, const Dict &structTreeRootDict) : doc(docA)
@@ -51,7 +49,8 @@ void StructTreeRoot::parse(const Dict &root)
     // be filled-in later when parsing them.
     const Object parentTreeObj = root.lookup("ParentTree");
     if (parentTreeObj.isDict()) {
-        parseNumberTreeNode(*parentTreeObj.getDict());
+        RefRecursionChecker usedParents;
+        parseNumberTreeNode(*parentTreeObj.getDict(), usedParents);
     }
 
     RefRecursionChecker seenElements;
@@ -107,14 +106,19 @@ void StructTreeRoot::parse(const Dict &root)
     std::multimap<Ref, Parent *>().swap(refToParentMap);
 }
 
-void StructTreeRoot::parseNumberTreeNode(const Dict &node)
+void StructTreeRoot::parseNumberTreeNode(const Dict &node, RefRecursionChecker &usedParents)
 {
     Object kids = node.lookup("Kids");
     if (kids.isArray()) {
         for (int i = 0; i < kids.arrayGetLength(); i++) {
-            Object obj = kids.arrayGet(i);
+            Ref ref;
+            const Object obj = kids.getArray()->get(i, &ref);
+            if (!usedParents.insert(ref)) {
+                return;
+            }
+            const RefRecursionCheckerRemover remover(usedParents, ref);
             if (obj.isDict()) {
-                parseNumberTreeNode(*obj.getDict());
+                parseNumberTreeNode(*obj.getDict(), usedParents);
             } else {
                 error(errSyntaxError, -1, "Kids item at position {0:d} is wrong type ({1:s})", i, obj.getTypeName());
             }
