@@ -17,18 +17,19 @@
 // Copyright (C) 2006 Ed Catmur <ed@catmur.co.uk>
 // Copyright (C) 2007, 2008, 2011, 2013 Carlos Garcia Campos <carlosgc@gnome.org>
 // Copyright (C) 2007, 2017 Adrian Johnson <ajohnson@redneon.com>
-// Copyright (C) 2008, 2010, 2015, 2016, 2018, 2019, 2021 Albert Astals Cid <aacid@kde.org>
+// Copyright (C) 2008, 2010, 2015, 2016, 2018, 2019, 2021, 2025, 2026 Albert Astals Cid <aacid@kde.org>
 // Copyright (C) 2010 Brian Ewins <brian.ewins@gmail.com>
 // Copyright (C) 2012, 2013, 2015, 2016 Jason Crain <jason@aquaticape.us>
 // Copyright (C) 2013 Thomas Freitag <Thomas.Freitag@alfa.de>
 // Copyright (C) 2018 Klarälvdalens Datakonsult AB, a KDAB Group company, <info@kdab.com>. Work sponsored by the LiMux project of the city of Munich
 // Copyright (C) 2018 Sanchit Anand <sanxchit@gmail.com>
-// Copyright (C) 2018, 2020, 2021 Nelson Benítez León <nbenitezl@gmail.com>
+// Copyright (C) 2018, 2020, 2021, 2025 Nelson Benítez León <nbenitezl@gmail.com>
 // Copyright (C) 2019, 2022 Oliver Sander <oliver.sander@tu-dresden.de>
 // Copyright (C) 2019 Dan Shea <dan.shea@logical-innovations.com>
 // Copyright (C) 2020 Suzuki Toshiya <mpsuzuki@hiroshima-u.ac.jp>
 // Copyright (C) 2024, 2025 Stefan Brüns <stefan.bruens@rwth-aachen.de>
-// Copyright (C) 2024 g10 Code GmbH, Author: Sune Stolborg Vuorela <sune@vuorela.dk>
+// Copyright (C) 2024-2026 g10 Code GmbH, Author: Sune Stolborg Vuorela <sune@vuorela.dk>
+// Copyright (C) 2025 Hagen Möbius <hagen.moebius@googlemail.com>
 //
 // To see a description of the changes please see the Changelog file that
 // came with your tarball or type make ChangeLog if you are building from git
@@ -38,12 +39,11 @@
 #ifndef TEXTOUTPUTDEV_H
 #define TEXTOUTPUTDEV_H
 
-#include "poppler-config.h"
 #include "poppler_private_export.h"
-#include <cstdio>
 #include "GfxFont.h"
 #include "GfxState.h"
 #include "OutputDev.h"
+#include "PDFRectangle.h"
 
 class GooString;
 class Gfx;
@@ -108,7 +108,6 @@ public:
     // Get the writing mode (0 or 1), or 0 if the font is not set
     int getWMode() const;
 
-#ifdef TEXTOUT_WORD_LIST
     // Get the font name (which may be NULL).
     const GooString *getFontName() const { return fontName; }
 
@@ -118,14 +117,11 @@ public:
     bool isSymbolic() const { return flags & fontSymbolic; }
     bool isItalic() const { return flags & fontItalic; }
     bool isBold() const { return flags & fontBold; }
-#endif
 
 private:
     std::shared_ptr<GfxFont> gfxFont;
-#ifdef TEXTOUT_WORD_LIST
     GooString *fontName;
     int flags;
-#endif
 
     friend class TextWord;
     friend class TextPage;
@@ -149,13 +145,13 @@ public:
     TextWord &operator=(const TextWord &) = delete;
 
     // Add a character to the word.
-    void addChar(const GfxState *state, TextFontInfo *fontA, double x, double y, double dx, double dy, int charPosA, int charLen, CharCode c, Unicode u, const Matrix &textMatA);
+    void addChar(TextFontInfo *fontA, double x, double y, double dx, double dy, int charPosA, int charLen, CharCode c, Unicode u, const Matrix &textMatA);
 
     // Attempt to add a character to the word as a combining character.
     // Either character u or the last character in the word must be an
     // acute, dieresis, or other combining character.  Returns true if
     // the character was added.
-    bool addCombining(const GfxState *state, TextFontInfo *fontA, double fontSizeA, double x, double y, double dx, double dy, int charPosA, int charLen, CharCode c, Unicode u, const Matrix &textMatA);
+    bool addCombining(TextFontInfo *fontA, double fontSizeA, double x, double y, double dx, double dy, int charPosA, int charLen, CharCode c, Unicode u, const Matrix &textMatA);
 
     // Merge <word> onto the end of <this>.
     void merge(TextWord *word);
@@ -170,7 +166,7 @@ public:
 
     static bool cmpYX(const TextWord *const word1, const TextWord *const word2);
 
-    void visitSelection(TextSelectionVisitor *visitor, const PDFRectangle *selection, SelectionStyle style);
+    void visitSelection(TextSelectionVisitor *visitor, const PDFRectangle *selection);
 
     // Get the TextFontInfo object associated with a character.
     const TextFontInfo *getFontInfo(int idx) const { return chars[idx].font; }
@@ -178,10 +174,9 @@ public:
     // Get the next TextWord on the linked list.
     const TextWord *getNext() const { return next; }
 
-#ifdef TEXTOUT_WORD_LIST
     int getLength() const { return chars.size(); }
     const Unicode *getChar(int idx) const { return &chars[idx].text; }
-    GooString *getText() const;
+    std::unique_ptr<std::string> getText() const;
     const GooString *getFontName(int idx) const { return chars[idx].font->fontName; }
     void getColor(double *r, double *g, double *b) const
     {
@@ -196,13 +191,14 @@ public:
         *xMaxA = xMax;
         *yMaxA = yMax;
     }
+    PDFRectangle getBBox() const { return { xMin, yMin, xMax, yMax }; }
+
     void getCharBBox(int charIdx, double *xMinA, double *yMinA, double *xMaxA, double *yMaxA) const;
     double getFontSize() const { return fontSize; }
     int getRotation() const { return rot; }
     int getCharPos() const { return chars.empty() ? 0 : chars.front().charPos; }
     int getCharLen() const { return chars.empty() ? 0 : chars.back().charPos - chars.front().charPos; }
     bool getSpaceAfter() const { return spaceAfter; }
-#endif
     bool isUnderlined() const { return underlined; }
     const AnnotLink *getLink() const { return link; }
     double getEdge(int i) const { return chars[i].edge; }
@@ -242,10 +238,8 @@ private:
     bool invisible; // whether we are invisible (glyphless)
     TextWord *next; // next word in line
 
-#ifdef TEXTOUT_WORD_LIST
     double colorR, // word color
             colorG, colorB;
-#endif
 
     AnnotLink *link;
 
@@ -332,6 +326,7 @@ public:
     void coalesce(const UnicodeMap *uMap);
 
     void visitSelection(TextSelectionVisitor *visitor, const PDFRectangle *selection, SelectionStyle style);
+    PDFRectangle getBBox() const { return { xMin, yMin, xMax, yMax }; }
 
     // Get the head of the linked list of TextWords.
     const TextWord *getWords() const { return words; }
@@ -343,6 +338,8 @@ public:
     bool isHyphenated() const { return hyphenated; }
 
 private:
+    std::pair<int, int> getLineBounds(const PDFRectangle &area) const;
+
     TextBlock *blk; // parent block
     int rot; // text rotation
     double xMin, xMax; // bounding box x coordinates
@@ -422,6 +419,7 @@ public:
         *xMaxA = xMax;
         *yMaxA = yMax;
     }
+    PDFRectangle getBBox() const { return { xMin, yMin, xMax, yMax }; }
 
     int getLineCount() const { return nLines; }
 
@@ -480,11 +478,11 @@ public:
     // Add a block to the end of this flow.
     void addBlock(TextBlock *blk);
 
-    // Returns true if <blk> fits below <prevBlk> in the flow, i.e., (1)
+    // Returns true if <blk> fits in the flow, i.e., (1)
     // it uses a font no larger than the last block added to the flow,
     // and (2) it fits within the flow's [priMin, priMax] along the
     // primary axis.
-    bool blockFits(const TextBlock *blk, const TextBlock *prevBlk) const;
+    bool blockFits(const TextBlock *blk) const;
 
     // Get the head of the linked list of TextBlocks.
     const TextBlock *getBlocks() const { return blocks; }
@@ -505,8 +503,6 @@ private:
     friend class TextPage;
 };
 
-#ifdef TEXTOUT_WORD_LIST
-
 //------------------------------------------------------------------------
 // TextWordList
 //------------------------------------------------------------------------
@@ -525,18 +521,12 @@ public:
     TextWordList(const TextWordList &) = delete;
     TextWordList &operator=(const TextWordList &) = delete;
 
-    // Return the number of words on the list.
-    int getLength() const;
-
-    // Return the <idx>th word from the list.
-    TextWord *get(int idx);
+    const std::vector<TextWord *> &getWords() const { return words; }
 
 private:
     std::vector<TextWord *> words;
 };
 
-#endif // TEXTOUT_WORD_LIST
-
 class TextWordSelection
 {
 public:
@@ -636,11 +626,12 @@ public:
                   double *xMax, double *yMax, PDFRectangle *continueMatch, bool *ignoredHyphen);
 
     // Get the text which is inside the specified rectangle.
-    GooString getText(double xMin, double yMin, double xMax, double yMax, EndOfLineKind textEOL) const;
+    // physical layout false and raw order false does not go well with a rectangle
+    GooString getText(const std::optional<PDFRectangle> &area, EndOfLineKind textEOL, bool physLayout) const;
 
     void visitSelection(TextSelectionVisitor *visitor, const PDFRectangle *selection, SelectionStyle style);
 
-    void drawSelection(OutputDev *out, double scale, int rotation, const PDFRectangle *selection, SelectionStyle style, const GfxColor *glyph_color, const GfxColor *box_color);
+    void drawSelection(OutputDev *out, double scale, int rotation, const PDFRectangle *selection, SelectionStyle style, const GfxColor *glyph_color, const GfxColor *box_color, double box_opacity, bool draw_glyphs);
 
     std::vector<PDFRectangle *> *getSelectionRegion(const PDFRectangle *selection, SelectionStyle style, double scale);
 
@@ -654,7 +645,7 @@ public:
     bool findCharRange(int pos, int length, double *xMin, double *yMin, double *xMax, double *yMax) const;
 
     // Dump contents of page to a file.
-    void dump(void *outputStream, TextOutputFunc outputFunc, bool physLayout, EndOfLineKind textEOL, bool pageBreaks);
+    void dump(void *outputStream, TextOutputFunc outputFunc, bool physLayout, EndOfLineKind textEOL, bool pageBreaks, bool suppressLastEol, std::optional<PDFRectangle> area) const;
 
     // Get the head of the linked list of TextFlows.
     const TextFlow *getFlows() const { return flows; }
@@ -663,13 +654,11 @@ public:
     // character are drawn on eachother.
     void setMergeCombining(bool merge);
 
-#ifdef TEXTOUT_WORD_LIST
     // Build a flat word list, in content stream order (if
     // this->rawOrder is true), physical layout order (if <physLayout>
     // is true and this->rawOrder is false), or reading order (if both
     // flags are false).
     std::unique_ptr<TextWordList> makeWordList(bool physLayout);
-#endif
 
 private:
     // Destructor.
@@ -749,7 +738,7 @@ public:
 private:
     TextPage *text;
 
-    GooString *actualText; // replacement text for the span
+    std::unique_ptr<GooString> actualText; // replacement text for the span
     double actualTextX0;
     double actualTextY0;
     double actualTextX1;
@@ -849,14 +838,15 @@ public:
     bool findText(const Unicode *s, int len, bool startAtTop, bool stopAtBottom, bool startAtLast, bool stopAtLast, bool caseSensitive, bool backward, bool wholeWord, double *xMin, double *yMin, double *xMax, double *yMax) const;
 
     // Get the text which is inside the specified rectangle.
-    GooString getText(double xMin, double yMin, double xMax, double yMax) const;
+    // You can only give an area if either physLayout or rawOrder are true
+    GooString getText(const std::optional<PDFRectangle> &area) const;
 
     // Find a string by character position and length.  If found, sets
     // the text bounding rectangle and returns true; otherwise returns
     // false.
     bool findCharRange(int pos, int length, double *xMin, double *yMin, double *xMax, double *yMax) const;
 
-    void drawSelection(OutputDev *out, double scale, int rotation, const PDFRectangle *selection, SelectionStyle style, const GfxColor *glyph_color, const GfxColor *box_color);
+    void drawSelection(OutputDev *out, double scale, int rotation, const PDFRectangle *selection, SelectionStyle style, const GfxColor *glyph_color, const GfxColor *box_color, double box_opacity, bool draw_glyphs);
 
     std::vector<PDFRectangle *> *getSelectionRegion(const PDFRectangle *selection, SelectionStyle style, double scale);
 
@@ -866,13 +856,11 @@ public:
     // character are drawn on eachother.
     void setMergeCombining(bool merge);
 
-#ifdef TEXTOUT_WORD_LIST
     // Build a flat word list, in content stream order (if
     // this->rawOrder is true), physical layout order (if
     // this->physLayout is true and this->rawOrder is false), or reading
     // order (if both flags are false).
     std::unique_ptr<TextWordList> makeWordList();
-#endif
 
     // Returns the TextPage object for the last rasterized page,
     // transferring ownership to the caller.
@@ -885,14 +873,6 @@ public:
     // last rasterized page.
     const TextFlow *getFlows() const;
 
-    static constexpr EndOfLineKind defaultEndOfLine()
-    {
-#if defined(_WIN32)
-        return eolDOS;
-#else
-        return eolUnix;
-#endif
-    }
     void setTextEOL(EndOfLineKind textEOLA) { textEOL = textEOLA; }
     void setTextPageBreaks(bool textPageBreaksA) { textPageBreaks = textPageBreaksA; }
     double getMinColSpacing1() const { return minColSpacing1; }
