@@ -1,7 +1,7 @@
 /* poppler-page.cc: qt interface to poppler
  * Copyright (C) 2005, Net Integration Technologies, Inc.
  * Copyright (C) 2005, Brad Hards <bradh@frogmouth.net>
- * Copyright (C) 2005-2022, 2024, Albert Astals Cid <aacid@kde.org>
+ * Copyright (C) 2005-2022, 2024-2026, Albert Astals Cid <aacid@kde.org>
  * Copyright (C) 2005, Stefan Kebekus <stefan.kebekus@math.uni-koeln.de>
  * Copyright (C) 2006-2011, Pino Toscano <pino@kde.org>
  * Copyright (C) 2008 Carlos Garcia Campos <carlosgc@gnome.org>
@@ -28,9 +28,9 @@
  * Copyright (C) 2021 Hubert Figuiere <hub@figuiere.net>
  * Copyright (C) 2021 Thomas Huxhorn <thomas.huxhorn@web.de>
  * Copyright (C) 2023 Kevin Ottens <kevin.ottens@enioka.com>. Work sponsored by De Bortoli Wines
- * Copyright (C) 2024 Stefan Brüns <stefan.bruens@rwth-aachen.de>
+ * Copyright (C) 2024, 2025 Stefan Brüns <stefan.bruens@rwth-aachen.de>
  * Copyright (C) 2024 Pratham Gandhi <ppg.1382@gmail.com>
- * Copyright (C) 2024 g10 Code GmbH, Author: Sune Stolborg Vuorela <sune@vuorela.dk>
+ * Copyright (C) 2024, 2026 g10 Code GmbH, Author: Sune Stolborg Vuorela <sune@vuorela.dk>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -69,6 +69,7 @@
 #include <QPainterOutputDev.h>
 #include <Rendition.h>
 #include <SplashOutputDev.h>
+#include <goo/gmem.h>
 #include <splash/SplashBitmap.h>
 
 #include "poppler-private.h"
@@ -230,7 +231,7 @@ Link *PageData::convertLinkActionToLink(::LinkAction *a, DocumentData *parentDoc
     case actionLaunch: {
         LinkLaunch *e = (LinkLaunch *)a;
         const GooString *p = e->getParams();
-        popplerLink = new LinkExecute(linkArea, UnicodeParsedString(e->getFileName()), p ? p->c_str() : nullptr);
+        popplerLink = new LinkExecute(linkArea, UnicodeParsedString(e->getFileName()), p ? QString::fromStdString(p->toStr()) : QString {});
     } break;
 
     case actionNamed: {
@@ -270,7 +271,7 @@ Link *PageData::convertLinkActionToLink(::LinkAction *a, DocumentData *parentDoc
     } break;
 
     case actionURI: {
-        popplerLink = new LinkBrowse(linkArea, ((LinkURI *)a)->getURI().c_str());
+        popplerLink = new LinkBrowse(linkArea, QString::fromStdString(((LinkURI *)a)->getURI()));
     } break;
 
     case actionSound: {
@@ -464,7 +465,7 @@ Page::~Page()
 }
 
 // Callback that filters out everything but form fields
-static auto annotDisplayDecideCbk = [](Annot *annot, void *user_data) {
+static auto annotDisplayDecideCbk = [](Annot *annot, void * /*user_data*/) {
     // Hide everything but forms
     return (annot->getType() == Annot::typeWidget);
 };
@@ -592,7 +593,7 @@ QImage Page::renderToImage(double xres, double yres, int xPos, int yPos, int w,
         splash_output.setVectorAntialias(m_page->parentDoc->m_hints & Document::Antialiasing ? true : false);
         splash_output.setFreeTypeHinting(m_page->parentDoc->m_hints & Document::TextHinting ? true : false, m_page->parentDoc->m_hints & Document::TextSlightHinting ? true : false);
 
-#ifdef USE_CMS
+#if USE_CMS
         splash_output.setDisplayProfile(m_page->parentDoc->m_displayProfile);
 #endif
 
@@ -620,7 +621,7 @@ QImage Page::renderToImage(double xres, double yres, int xPos, int yPos, int w,
 
         qpainter_output.setHintingPreference(QFontHintingFromPopplerHinting(m_page->parentDoc->m_hints));
 
-#ifdef USE_CMS
+#if USE_CMS
         qpainter_output.setDisplayProfile(m_page->parentDoc->m_displayProfile);
 #endif
 
@@ -683,17 +684,22 @@ QString Page::text(const QRectF &r, TextLayout textLayout) const
     QString result;
 
     const bool rawOrder = textLayout == RawOrderLayout;
-    output_dev = new TextOutputDev(nullptr, false, 0, rawOrder, false);
+    const bool physLayout = textLayout == PhysicalLayout;
+    output_dev = new TextOutputDev(nullptr, physLayout, 0, rawOrder, false);
     m_page->parentDoc->doc->displayPageSlice(output_dev, m_page->index + 1, 72, 72, 0, false, true, false, -1, -1, -1, -1, nullptr, nullptr, nullptr, nullptr, true);
     if (r.isNull()) {
         const PDFRectangle *rect = m_page->page->getCropBox();
         if (orientation() == Orientation::Portrait || orientation() == Orientation::UpsideDown) {
-            s = output_dev->getText(rect->x1, rect->y1, rect->x2, rect->y2);
+            s = output_dev->getText(*rect);
         } else {
-            s = output_dev->getText(rect->y1, rect->x1, rect->y2, rect->x2);
+            s = output_dev->getText(PDFRectangle { rect->y1, rect->x1, rect->y2, rect->x2 });
         }
     } else {
-        s = output_dev->getText(r.left(), r.top(), r.right(), r.bottom());
+        if (textLayout == ReadingOrder) {
+            qWarning() << "ReadingOrder is not supported with non null rect";
+            return {};
+        }
+        s = output_dev->getText(PDFRectangle { r.left(), r.top(), r.right(), r.bottom() });
     }
 
     result = QString::fromStdString(s.toStr());
@@ -794,12 +800,11 @@ QList<TextBox *> Page::textList(Rotation rotate, ShouldAbortQueryFunc shouldAbor
 
     QHash<const TextWord *, TextBox *> wordBoxMap;
 
-    output_list.reserve(word_list->getLength());
-    for (int i = 0; i < word_list->getLength(); i++) {
-        TextWord *word = word_list->get(i);
-        GooString *gooWord = word->getText();
-        QString string = QString::fromUtf8(gooWord->c_str());
-        delete gooWord;
+    const std::vector<TextWord *> &words = word_list->getWords();
+    output_list.reserve(words.size());
+    for (const TextWord *word : words) {
+        const std::unique_ptr<std::string> wordText = word->getText();
+        const QString string = QString::fromUtf8(wordText->c_str());
         double xMin, yMin, xMax, yMax;
         word->getBBox(&xMin, &yMin, &xMax, &yMax);
 
@@ -816,8 +821,7 @@ QList<TextBox *> Page::textList(Rotation rotate, ShouldAbortQueryFunc shouldAbor
         output_list.append(text_box);
     }
 
-    for (int i = 0; i < word_list->getLength(); i++) {
-        TextWord *word = word_list->get(i);
+    for (const TextWord *word : words) {
         TextBox *text_box = wordBoxMap.value(word);
         text_box->m_data->nextWord = wordBoxMap.value(word->nextWord());
     }
