@@ -1,6 +1,6 @@
 /* poppler-pdf-converter.cc: qt interface to poppler
  * Copyright (C) 2008, Pino Toscano <pino@kde.org>
- * Copyright (C) 2008, 2009, 2020-2022, 2024, Albert Astals Cid <aacid@kde.org>
+ * Copyright (C) 2008, 2009, 2020-2022, 2024, 2025, Albert Astals Cid <aacid@kde.org>
  * Copyright (C) 2020, Thorsten Behrens <Thorsten.Behrens@CIB.de>
  * Copyright (C) 2020, Klarälvdalens Datakonsult AB, a KDAB Group company, <info@kdab.com>. Work sponsored by Technische Universität Dresden
  * Copyright (C) 2021, Klarälvdalens Datakonsult AB, a KDAB Group company, <info@kdab.com>.
@@ -8,7 +8,7 @@
  * Copyright (C) 2021, Georgiy Sgibnev <georgiy@sgibnev.com>. Work sponsored by lab50.net.
  * Copyright (C) 2022, Martin <martinbts@gmx.net>
  * Copyright (C) 2022, Felix Jung <fxjung@posteo.de>
- * Copyright (C) 2024, g10 Code GmbH, Author: Sune Stolborg Vuorela <sune@vuorela.dk>
+ * Copyright (C) 2024, 2025, g10 Code GmbH, Author: Sune Stolborg Vuorela <sune@vuorela.dk>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -36,7 +36,6 @@
 #include <QFile>
 #include <QUuid>
 
-#include "Array.h"
 #include "Form.h"
 #include <ErrorCodes.h>
 
@@ -141,10 +140,52 @@ bool PDFConverter::sign(const NewSignatureData &data)
     const auto location = std::unique_ptr<GooString>(data.location().isEmpty() ? nullptr : QStringToUnicodeGooString(data.location()));
     const auto ownerPwd = std::optional<GooString>(data.documentOwnerPassword().constData());
     const auto userPwd = std::optional<GooString>(data.documentUserPassword().constData());
-    return !doc->sign(d->outputFileName.toUtf8().constData(), data.certNickname().toUtf8().constData(), data.password().toUtf8().constData(), QStringToGooString(data.fieldPartialName()), data.page() + 1,
-                      boundaryToPdfRectangle(destPage, data.boundingRectangle(), Annotation::FixedRotation), *gSignatureText, *gSignatureLeftText, data.fontSize(), data.leftFontSize(), convertQColor(data.fontColor()), data.borderWidth(),
-                      convertQColor(data.borderColor()), convertQColor(data.backgroundColor()), reason.get(), location.get(), data.imagePath().toStdString(), ownerPwd, userPwd)
-                    .has_value();
+    auto failure = doc->sign(d->outputFileName.toUtf8().constData(), data.certNickname().toUtf8().constData(), data.password().toUtf8().constData(), QStringToGooString(data.fieldPartialName()), data.page() + 1,
+                             boundaryToPdfRectangle(destPage, data.boundingRectangle(), Annotation::FixedRotation), *gSignatureText, *gSignatureLeftText, data.fontSize(), data.leftFontSize(), convertQColor(data.fontColor()),
+                             data.borderWidth(), convertQColor(data.borderColor()), convertQColor(data.backgroundColor()), reason.get(), location.get(), data.imagePath().toStdString(), ownerPwd, userPwd);
+    if (failure) {
+        d->lastSigningErrorDetails = fromPopplerCore(failure.value().message);
+        d->lastSigningResult = GenericSigningError; // catch all
+        switch (failure.value().type) {
+        case CryptoSign::SigningError::GenericError:
+            d->lastSigningResult = GenericSigningError;
+            break;
+        case CryptoSign::SigningError::InternalError:
+            d->lastSigningResult = InternalError;
+            break;
+        case CryptoSign::SigningError::KeyMissing:
+            d->lastSigningResult = KeyMissing;
+            break;
+        case CryptoSign::SigningError::UserCancelled:
+            d->lastSigningResult = UserCancelled;
+
+            break;
+        case CryptoSign::SigningError::WriteFailed:
+            d->lastSigningResult = WriteFailed;
+            break;
+        case CryptoSign::SigningError::BadPassphrase:
+
+            d->lastSigningResult = BadPassphrase;
+            break;
+        }
+        return false;
+    } else {
+        d->lastSigningErrorDetails = {};
+        d->lastSigningResult = SigningSuccess;
+        return true;
+    }
+}
+
+ErrorString PDFConverter::lastSigningErrorDetails() const
+{
+    Q_D(const PDFConverter);
+    return d->lastSigningErrorDetails;
+}
+
+PDFConverter::SigningResult PDFConverter::lastSigningResult() const
+{
+    Q_D(const PDFConverter);
+    return d->lastSigningResult;
 }
 
 struct PDFConverter::NewSignatureData::NewSignatureDataPrivate
