@@ -1,6 +1,6 @@
 /* poppler-private.cc: qt interface to poppler
  * Copyright (C) 2005, Net Integration Technologies, Inc.
- * Copyright (C) 2006, 2011, 2015, 2017-2020, 2024 by Albert Astals Cid <aacid@kde.org>
+ * Copyright (C) 2006, 2011, 2015, 2017-2020, 2024, 2025 by Albert Astals Cid <aacid@kde.org>
  * Copyright (C) 2008, 2010, 2011, 2014 by Pino Toscano <pino@kde.org>
  * Copyright (C) 2013 by Thomas Freitag <Thomas.Freitag@alfa.de>
  * Copyright (C) 2013 Adrian Johnson <ajohnson@redneon.com>
@@ -44,6 +44,7 @@
 #include <PDFDocEncoding.h>
 #include <UnicodeMap.h>
 #include <UTF.h>
+#include <goo/gmem.h>
 
 #ifdef ANDROID
 #    include <QtCore/QString>
@@ -103,7 +104,7 @@ QString unicodeToQString(const Unicode *u, int len)
         convertedStr.append(buf, n);
     }
 
-    return QString::fromUtf8(convertedStr.c_str(), convertedStr.getLength());
+    return QString::fromUtf8(convertedStr.c_str(), convertedStr.size());
 }
 
 QString unicodeToQString(const std::vector<Unicode> &u)
@@ -213,11 +214,11 @@ static void linkActionToTocItem(const ::LinkAction *a, DocumentData *doc, QDomEl
             // get the destination for the page now, but it's VERY time consuming,
             // so better storing the reference and provide the viewport on demand
             const GooString *s = g->getNamedDest();
-            QChar *charArray = new QChar[s->getLength()];
-            for (int i = 0; i < s->getLength(); ++i) {
-                charArray[i] = QChar(s->c_str()[i]);
+            QChar *charArray = new QChar[s->size()];
+            for (size_t i = 0; i < s->size(); ++i) {
+                charArray[i] = QChar::fromLatin1(s->c_str()[i]);
             }
-            QString aux(charArray, s->getLength());
+            QString aux(charArray, s->size());
             e->setAttribute(QStringLiteral("DestinationName"), aux);
             delete[] charArray;
         } else if (destination && destination->isOk()) {
@@ -235,23 +236,23 @@ static void linkActionToTocItem(const ::LinkAction *a, DocumentData *doc, QDomEl
             // get the destination for the page now, but it's VERY time consuming,
             // so better storing the reference and provide the viewport on demand
             const GooString *s = g->getNamedDest();
-            QChar *charArray = new QChar[s->getLength()];
-            for (int i = 0; i < s->getLength(); ++i) {
-                charArray[i] = QChar(s->c_str()[i]);
+            QChar *charArray = new QChar[s->size()];
+            for (size_t i = 0; i < s->size(); ++i) {
+                charArray[i] = QChar::fromLatin1(s->c_str()[i]);
             }
-            QString aux(charArray, s->getLength());
+            QString aux(charArray, s->size());
             e->setAttribute(QStringLiteral("DestinationName"), aux);
             delete[] charArray;
         } else if (destination && destination->isOk()) {
             LinkDestinationData ldd(destination, nullptr, doc, g->getFileName() != nullptr);
             e->setAttribute(QStringLiteral("Destination"), LinkDestination(ldd).toString());
         }
-        e->setAttribute(QStringLiteral("ExternalFileName"), g->getFileName()->c_str());
+        e->setAttribute(QStringLiteral("ExternalFileName"), QString::fromStdString(g->getFileName()->toStr()));
         break;
     }
     case actionURI: {
         const LinkURI *u = static_cast<const LinkURI *>(a);
-        e->setAttribute(QStringLiteral("DestinationURI"), u->getURI().c_str());
+        e->setAttribute(QStringLiteral("DestinationURI"), QString::fromStdString(u->getURI()));
     }
     default:;
     }
