@@ -178,7 +178,7 @@ public:
     QPointer<OptContentModel> m_optContentModel;
     QColor paperColor;
     int m_hints;
-#ifdef USE_CMS
+#if USE_CMS
     GfxLCMSProfilePtr m_sRGBProfile;
     GfxLCMSProfilePtr m_displayProfile;
 #endif
@@ -201,15 +201,15 @@ public:
     {
         const std::optional<std::string> &fiName = fi->getName();
         if (fiName) {
-            fontName = fiName->c_str();
+            fontName = QString::fromStdString(fiName.value());
         }
         const std::optional<std::string> &fiFile = fi->getFile();
         if (fiFile) {
-            fontFile = fiFile->c_str();
+            fontFile = QString::fromStdString(fiFile.value());
         }
         const std::optional<std::string> &fiSubstituteName = fi->getSubstituteName();
         if (fiSubstituteName) {
-            fontSubstituteName = fiSubstituteName->c_str();
+            fontSubstituteName = QString::fromStdString(fiSubstituteName.value());
         }
         isEmbedded = fi->getEmbedded();
         isSubset = fi->getSubset();
@@ -253,6 +253,25 @@ public:
     bool hasSpaceAfter;
 };
 
+inline Poppler::ErrorStringType fromPopplerCore(::ErrorStringType type)
+{
+    switch (type) {
+    case ::ErrorStringType::ErrorCodeString:
+        return Poppler::ErrorStringType::ErrorCodeString;
+    case ::ErrorStringType::UserString:
+        return Poppler::ErrorStringType::UserString;
+    }
+    return Poppler::ErrorStringType::ErrorCodeString;
+}
+
+inline Poppler::ErrorString fromPopplerCore(const ::ErrorString &str)
+{
+    Poppler::ErrorString res;
+    res.type = fromPopplerCore(str.type);
+    res.data = QString::fromStdString(str.text);
+    return res;
+}
+
 class FormFieldData
 {
 public:
@@ -263,6 +282,7 @@ public:
     ::FormWidget *fm;
     QRectF box;
     static POPPLER_QT5_EXPORT ::FormWidget *getFormWidget(const FormField *f);
+    Poppler::ErrorString lastSigningErrorDetails;
 };
 
 class FormFieldIcon;
