@@ -1,6 +1,8 @@
 /* poppler-sound.cc: qt interface to poppler
  * Copyright (C) 2006-2007, Pino Toscano <pino@kde.org>
- * Copyright (C) 2008, 2018, 2020, Albert Astals Cid <aacid@kde.org>
+ * Copyright (C) 2008, 2018, 2020, 2024, Albert Astals Cid <aacid@kde.org>
+ * Copyright (C) 2025, g10 Code GmbH, Author: Sune Stolborg Vuorela <sune@vuorela.dk>
+ * Copyright (C) 2025 Arnav V <arnav0872@gmail.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -67,19 +69,23 @@ SoundObject::SoundType SoundObject::soundType() const
 
 QString SoundObject::url() const
 {
-    if (m_soundData->m_type != SoundObject::External)
+    if (m_soundData->m_type != SoundObject::External) {
         return QString();
+    }
 
-    return QString(m_soundData->m_soundObj->getFileName().c_str());
+    return QString::fromStdString(m_soundData->m_soundObj->getFileName());
 }
 
 QByteArray SoundObject::data() const
 {
-    if (m_soundData->m_type != SoundObject::Embedded)
+    if (m_soundData->m_type != SoundObject::Embedded) {
         return QByteArray();
+    }
 
     Stream *stream = m_soundData->m_soundObj->getStream();
-    stream->reset();
+    if (!stream->rewind()) {
+        return QByteArray {};
+    }
     int dataLen = 0;
     QByteArray fileArray;
     int i;
