@@ -1,7 +1,7 @@
 /*
  * Copyright (C) 2008, Pino Toscano <pino@kde.org>
  * Copyright (C) 2018, Adam Reichold <adam.reichold@t-online.de>
- * Copyright (C) 2019, Albert Astals Cid <aacid@kde.org>
+ * Copyright (C) 2019, 2025, Albert Astals Cid <aacid@kde.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -111,7 +111,7 @@ public:
         return n->m_item.hasChildren();
     }
 
-    int columnCount(const QModelIndex &parent) const override { return 1; }
+    int columnCount(const QModelIndex & /*parent*/) const override { return 1; }
 
 private:
     QVector<Node *> m_topItems;
