@@ -28,6 +28,7 @@
 // Copyright (C) 2018 Klarälvdalens Datakonsult AB, a KDAB Group company, <info@kdab.com>. Work sponsored by the LiMux project of the city of Munich
 // Copyright (C) 2018 Adam Reichold <adam.reichold@t-online.de>
 // Copyright (C) 2025 g10 Code GmbH, Author: Sune Stolborg Vuorela <sune@vuorela.dk>
+// Copyright (C) 2025 Arnav V <arnav0872@gmail.com>
 //
 // To see a description of the changes please see the Changelog file that
 // came with your tarball or type make ChangeLog if you are building from git
@@ -42,14 +43,12 @@
 #include <array>
 
 #include "goo/ft_utils.h"
-#include "goo/gfile.h"
 #include "GlobalParams.h"
 #include "Error.h"
 #include "Object.h"
 #include "GfxState.h"
 #include "GfxFont.h"
 #include "Link.h"
-#include "FontEncodingTables.h"
 #include <fofi/FoFiTrueType.h>
 #include <fofi/FoFiType1C.h>
 #include "QPainterOutputDev.h"
@@ -176,11 +175,11 @@ void QPainterOutputDev::startDoc(PDFDoc *doc)
     m_codeToGID = nullptr;
 }
 
-void QPainterOutputDev::startPage(int pageNum, GfxState *state, XRef *) { }
+void QPainterOutputDev::startPage(int /*pageNum*/, GfxState * /*state*/, XRef *) { }
 
 void QPainterOutputDev::endPage() { }
 
-void QPainterOutputDev::saveState(GfxState *state)
+void QPainterOutputDev::saveState(GfxState * /*state*/)
 {
     m_currentPenStack.push(m_currentPen);
     m_currentBrushStack.push(m_currentBrush);
@@ -191,7 +190,7 @@ void QPainterOutputDev::saveState(GfxState *state)
     m_painter.top()->save();
 }
 
-void QPainterOutputDev::restoreState(GfxState *state)
+void QPainterOutputDev::restoreState(GfxState * /*state*/)
 {
     m_painter.top()->restore();
 
@@ -267,7 +266,7 @@ void QPainterOutputDev::updateLineDash(GfxState *state)
     m_painter.top()->setPen(m_currentPen);
 }
 
-void QPainterOutputDev::updateFlatness(GfxState *state)
+void QPainterOutputDev::updateFlatness(GfxState * /*state*/)
 {
     // qDebug() << "updateFlatness";
 }
@@ -652,7 +651,7 @@ void QPainterOutputDev::updateFont(GfxState *state)
     }
 }
 
-static QPainterPath convertPath(GfxState *state, const GfxPath *path, Qt::FillRule fillRule)
+static QPainterPath convertPath(const GfxPath *path, Qt::FillRule fillRule)
 {
     int i, j;
 
@@ -682,17 +681,17 @@ static QPainterPath convertPath(GfxState *state, const GfxPath *path, Qt::FillRu
 
 void QPainterOutputDev::stroke(GfxState *state)
 {
-    m_painter.top()->strokePath(convertPath(state, state->getPath(), Qt::OddEvenFill), m_currentPen);
+    m_painter.top()->strokePath(convertPath(state->getPath(), Qt::OddEvenFill), m_currentPen);
 }
 
 void QPainterOutputDev::fill(GfxState *state)
 {
-    m_painter.top()->fillPath(convertPath(state, state->getPath(), Qt::WindingFill), m_currentBrush);
+    m_painter.top()->fillPath(convertPath(state->getPath(), Qt::WindingFill), m_currentBrush);
 }
 
 void QPainterOutputDev::eoFill(GfxState *state)
 {
-    m_painter.top()->fillPath(convertPath(state, state->getPath(), Qt::OddEvenFill), m_currentBrush);
+    m_painter.top()->fillPath(convertPath(state->getPath(), Qt::OddEvenFill), m_currentBrush);
 }
 
 bool QPainterOutputDev::axialShadedFill(GfxState *state, GfxAxialShading *shading, double tMin, double tMax)
@@ -815,7 +814,7 @@ bool QPainterOutputDev::axialShadedFill(GfxState *state, GfxAxialShading *shadin
 
     // Actually paint the shaded region
     QBrush newBrush(gradient);
-    m_painter.top()->fillPath(convertPath(state, state->getPath(), Qt::WindingFill), newBrush);
+    m_painter.top()->fillPath(convertPath(state->getPath(), Qt::WindingFill), newBrush);
 
     state->clearPath();
 
@@ -825,17 +824,17 @@ bool QPainterOutputDev::axialShadedFill(GfxState *state, GfxAxialShading *shadin
 
 void QPainterOutputDev::clip(GfxState *state)
 {
-    m_painter.top()->setClipPath(convertPath(state, state->getPath(), Qt::WindingFill), Qt::IntersectClip);
+    m_painter.top()->setClipPath(convertPath(state->getPath(), Qt::WindingFill), Qt::IntersectClip);
 }
 
 void QPainterOutputDev::eoClip(GfxState *state)
 {
-    m_painter.top()->setClipPath(convertPath(state, state->getPath(), Qt::OddEvenFill), Qt::IntersectClip);
+    m_painter.top()->setClipPath(convertPath(state->getPath(), Qt::OddEvenFill), Qt::IntersectClip);
 }
 
 void QPainterOutputDev::clipToStrokePath(GfxState *state)
 {
-    QPainterPath clipPath = convertPath(state, state->getPath(), Qt::WindingFill);
+    QPainterPath clipPath = convertPath(state->getPath(), Qt::WindingFill);
 
     // Get the outline of 'clipPath' as a separate path
     QPainterPathStroker stroker;
@@ -851,7 +850,7 @@ void QPainterOutputDev::clipToStrokePath(GfxState *state)
     m_painter.top()->setClipPath(clipPathOutline, Qt::IntersectClip);
 }
 
-void QPainterOutputDev::drawChar(GfxState *state, double x, double y, double dx, double dy, double originX, double originY, CharCode code, int nBytes, const Unicode *u, int uLen)
+void QPainterOutputDev::drawChar(GfxState *state, double x, double y, double /*dx*/, double /*dy*/, double originX, double originY, CharCode code, int /*nBytes*/, const Unicode * /*u*/, int /*uLen*/)
 {
 
     // First handle type3 fonts
@@ -957,19 +956,19 @@ void QPainterOutputDev::drawChar(GfxState *state, double x, double y, double dx,
     }
 }
 
-void QPainterOutputDev::type3D0(GfxState *state, double wx, double wy) { }
+void QPainterOutputDev::type3D0(GfxState * /*state*/, double /*wx*/, double /*wy*/) { }
 
-void QPainterOutputDev::type3D1(GfxState *state, double wx, double wy, double llx, double lly, double urx, double ury) { }
+void QPainterOutputDev::type3D1(GfxState * /*state*/, double /*wx*/, double /*wy*/, double /*llx*/, double /*lly*/, double /*urx*/, double /*ury*/) { }
 
-void QPainterOutputDev::endTextObject(GfxState *state) { }
+void QPainterOutputDev::endTextObject(GfxState * /*state*/) { }
 
-void QPainterOutputDev::drawImageMask(GfxState *state, Object *ref, Stream *str, int width, int height, bool invert, bool interpolate, bool inlineImg)
+void QPainterOutputDev::drawImageMask(GfxState * /*state*/, Object * /*ref*/, Stream *str, int width, int height, bool invert, bool /*interpolate*/, bool /*inlineImg*/)
 {
     auto imgStr = std::make_unique<ImageStream>(str, width,
                                                 1, // numPixelComps
                                                 1 // getBits
     );
-    if (!imgStr->reset()) {
+    if (!imgStr->rewind()) {
         imgStr->close();
         return;
     }
@@ -1003,7 +1002,7 @@ void QPainterOutputDev::drawImageMask(GfxState *state, Object *ref, Stream *str,
 }
 
 // TODO: lots more work here.
-void QPainterOutputDev::drawImage(GfxState *state, Object *ref, Stream *str, int width, int height, GfxImageColorMap *colorMap, bool interpolate, const int *maskColors, bool inlineImg)
+void QPainterOutputDev::drawImage(GfxState * /*state*/, Object * /*ref*/, Stream *str, int width, int height, GfxImageColorMap *colorMap, bool /*interpolate*/, const int *maskColors, bool /*inlineImg*/)
 {
     unsigned int *data;
     unsigned int *line;
@@ -1015,7 +1014,7 @@ void QPainterOutputDev::drawImage(GfxState *state, Object *ref, Stream *str, int
 
     /* TODO: Do we want to cache these? */
     auto imgStr = std::make_unique<ImageStream>(str, width, colorMap->getNumPixelComps(), colorMap->getBits());
-    if (!imgStr->reset()) {
+    if (!imgStr->rewind()) {
         imgStr->close();
         return;
     }
@@ -1055,7 +1054,7 @@ void QPainterOutputDev::drawImage(GfxState *state, Object *ref, Stream *str, int
 }
 
 void QPainterOutputDev::drawSoftMaskedImage(GfxState *state, Object *ref, Stream *str, int width, int height, GfxImageColorMap *colorMap, bool interpolate, Stream *maskStr, int maskWidth, int maskHeight, GfxImageColorMap *maskColorMap,
-                                            bool maskInterpolate)
+                                            bool /*maskInterpolate*/)
 {
     // Bail out if the image size doesn't match the mask size.  I don't know
     // what to do in this case.
@@ -1075,12 +1074,12 @@ void QPainterOutputDev::drawSoftMaskedImage(GfxState *state, Object *ref, Stream
 
     /* TODO: Do we want to cache these? */
     auto imgStr = std::make_unique<ImageStream>(str, width, colorMap->getNumPixelComps(), colorMap->getBits());
-    if (!imgStr->reset()) {
+    if (!imgStr->rewind()) {
         return;
     }
 
     auto maskImageStr = std::make_unique<ImageStream>(maskStr, maskWidth, maskColorMap->getNumPixelComps(), maskColorMap->getBits());
-    if (!maskImageStr->reset()) {
+    if (!maskImageStr->rewind()) {
         return;
     }
 
