@@ -23,6 +23,7 @@
  * Copyright (C) 2024 Pratham Gandhi <ppg.1382@gmail.com>
  * Copyright (C) 2024 Stefan Brüns <stefan.bruens@rwth-aachen.de>
  * Copyright (C) 2025 g10 Code GmbH, Author: Sune Stolborg Vuorela <sune@vuorela.dk>
+ * Copyright (C) 2025 Arnav V <arnav0872@gmail.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -64,7 +65,7 @@
 #include "poppler-page-private.h"
 #include "poppler-outline-private.h"
 
-#if defined(USE_CMS)
+#if USE_CMS
 #    include <lcms2.h>
 #endif
 
@@ -248,7 +249,7 @@ QByteArray Document::fontData(const FontInfo &fi) const
 
         Object refObj(fi.m_data->embRef);
         Object strObj = refObj.fetch(xref);
-        if (strObj.isStream() && strObj.streamReset()) {
+        if (strObj.isStream() && strObj.streamRewind()) {
             int c;
             while ((c = strObj.streamGetChar()) != EOF) {
                 result.append((char)c);
@@ -611,7 +612,7 @@ void Document::setPaperColor(const QColor &color)
 
 void Document::setColorDisplayProfile(void *outputProfileA)
 {
-#if defined(USE_CMS)
+#if USE_CMS
     if (m_doc->m_sRGBProfile && m_doc->m_sRGBProfile.get() == outputProfileA) {
         // Catch the special case that the user passes the sRGB profile
         m_doc->m_displayProfile = m_doc->m_sRGBProfile;
@@ -629,7 +630,7 @@ void Document::setColorDisplayProfile(void *outputProfileA)
 
 void Document::setColorDisplayProfileName(const QString &name)
 {
-#if defined(USE_CMS)
+#if USE_CMS
     void *rawprofile = cmsOpenProfileFromFile(name.toLocal8Bit().constData(), "r");
     m_doc->m_displayProfile = make_GfxLCMSProfilePtr(rawprofile);
 #else
@@ -639,7 +640,7 @@ void Document::setColorDisplayProfileName(const QString &name)
 
 void *Document::colorRgbProfile() const
 {
-#if defined(USE_CMS)
+#if USE_CMS
     if (!m_doc->m_sRGBProfile) {
         m_doc->m_sRGBProfile = make_GfxLCMSProfilePtr(cmsCreate_sRGBProfile());
     }
@@ -651,7 +652,7 @@ void *Document::colorRgbProfile() const
 
 void *Document::colorDisplayProfile() const
 {
-#if defined(USE_CMS)
+#if USE_CMS
     return m_doc->m_displayProfile.get();
 #else
     return nullptr;
@@ -916,7 +917,7 @@ QDateTime convertDate(const char *dateString)
 
 bool isCmsAvailable()
 {
-#if defined(USE_CMS)
+#if USE_CMS
     return true;
 #else
     return false;
