@@ -1,5 +1,5 @@
 /* poppler-embeddedfile-private.h: Qt interface to poppler
- * Copyright (C) 2005, 2008, 2009, 2012, 2018, 2021, Albert Astals Cid <aacid@kde.org>
+ * Copyright (C) 2005, 2008, 2009, 2012, 2018, 2021, 2022, 2025, Albert Astals Cid <aacid@kde.org>
  * Copyright (C) 2005, Brad Hards <bradh@frogmouth.net>
  * Copyright (C) 2008, 2011, Pino Toscano <pino@kde.org>
  *
@@ -21,6 +21,9 @@
 #ifndef POPPLER_EMBEDDEDFILE_PRIVATE_H
 #define POPPLER_EMBEDDEDFILE_PRIVATE_H
 
+#include <memory>
+
+class EmbFile;
 class FileSpec;
 
 namespace Poppler {
@@ -28,15 +31,11 @@ namespace Poppler {
 class EmbeddedFileData
 {
 public:
-    explicit EmbeddedFileData(FileSpec *fs);
-    ~EmbeddedFileData();
-
-    EmbeddedFileData(const EmbeddedFileData &) = delete;
-    EmbeddedFileData &operator=(const EmbeddedFileData &) = delete;
+    explicit EmbeddedFileData(std::unique_ptr<FileSpec> &&fs);
 
     EmbFile *embFile() const;
 
-    FileSpec *filespec;
+    std::unique_ptr<FileSpec> filespec;
 };
 
 }
