@@ -1,6 +1,6 @@
 /* poppler-form.h: qt interface to poppler
  * Copyright (C) 2007-2008, 2011, Pino Toscano <pino@kde.org>
- * Copyright (C) 2008, 2011, 2012, 2015-2024 Albert Astals Cid <aacid@kde.org>
+ * Copyright (C) 2008, 2011, 2012, 2015-2025 Albert Astals Cid <aacid@kde.org>
  * Copyright (C) 2011 Carlos Garcia Campos <carlosgc@gnome.org>
  * Copyright (C) 2012, Adam Reichold <adamreichold@myopera.com>
  * Copyright (C) 2016, Hanno Meyer-Thurow <h.mth@web.de>
@@ -51,10 +51,10 @@
 #include <SignatureInfo.h>
 #include <CertificateInfo.h>
 #include <CryptoSignBackend.h>
-#ifdef ENABLE_NSS3
+#if ENABLE_NSS3
 #    include <NSSCryptoSignBackend.h>
 #endif
-#ifdef ENABLE_GPGME
+#if ENABLE_GPGME
 #    include <GPGMECryptoSignBackendConfiguration.h>
 #endif
 
@@ -62,9 +62,6 @@
 #include "poppler-private.h"
 #include "poppler-annotation-helper.h"
 
-#include <cmath>
-#include <cctype>
-
 namespace {
 
 Qt::Alignment formTextAlignment(::FormWidget *fm)
@@ -808,7 +805,7 @@ QByteArray CertificateInfo::certificateData() const
 
 bool CertificateInfo::checkPassword(const QString &password) const
 {
-#ifdef ENABLE_SIGNATURES
+#if ENABLE_SIGNATURES
     auto backend = CryptoSign::Factory::createActive();
     if (!backend) {
         return false;
@@ -821,6 +818,7 @@ bool CertificateInfo::checkPassword(const QString &password) const
     std::variant<std::vector<unsigned char>, CryptoSign::SigningErrorMessage> tmpSignature = sigHandler->signDetached(password.toStdString());
     return std::holds_alternative<std::vector<unsigned char>>(tmpSignature);
 #else
+    (void)password;
     return false;
 #endif
 }
@@ -889,7 +887,7 @@ QString SignatureValidationInfo::reason() const
 
 SignatureValidationInfo::HashAlgorithm SignatureValidationInfo::hashAlgorithm() const
 {
-#ifdef ENABLE_SIGNATURES
+#if ENABLE_SIGNATURES
     Q_D(const SignatureValidationInfo);
 
     switch (d->hash_algorithm) {
@@ -1250,7 +1248,7 @@ ErrorString FormFieldSignature::lastSigningErrorDetails() const
 
 bool hasNSSSupport()
 {
-#ifdef ENABLE_NSS3
+#if ENABLE_NSS3
     return true;
 #else
     return false;
@@ -1365,7 +1363,7 @@ bool hasCryptoSignBackendFeature(CryptoSignBackend backend, CryptoSignBackendFea
 
 QString POPPLER_QT6_EXPORT getNSSDir()
 {
-#ifdef ENABLE_NSS3
+#if ENABLE_NSS3
     return QString::fromLocal8Bit(NSSSignatureConfiguration::getNSSDir().c_str());
 #else
     return QString();
@@ -1374,7 +1372,7 @@ QString POPPLER_QT6_EXPORT getNSSDir()
 
 void setNSSDir(const QString &path)
 {
-#ifdef ENABLE_NSS3
+#if ENABLE_NSS3
     if (path.isEmpty()) {
         return;
     }
@@ -1392,7 +1390,7 @@ std::function<QString(const QString &)> nssPasswordCall;
 
 void setNSSPasswordCallback(const std::function<char *(const char *)> &f)
 {
-#ifdef ENABLE_NSS3
+#if ENABLE_NSS3
     NSSSignatureConfiguration::setNSSPasswordCallback(f);
 #else
     qWarning() << "setNSSPasswordCallback called but this poppler is built without NSS support";
@@ -1402,7 +1400,7 @@ void setNSSPasswordCallback(const std::function<char *(const char *)> &f)
 
 void setPgpSignaturesAllowed(bool allowed)
 {
-#ifdef ENABLE_GPGME
+#if ENABLE_GPGME
     GpgSignatureConfiguration::setPgpSignaturesAllowed(allowed);
 #else
     qWarning() << "Trying to enable pgp signatures, but pgp not enabled in this build";
@@ -1412,7 +1410,7 @@ void setPgpSignaturesAllowed(bool allowed)
 
 bool arePgpSignaturesAllowed()
 {
-#ifdef ENABLE_GPGME
+#if ENABLE_GPGME
     return GpgSignatureConfiguration::arePgpSignaturesAllowed();
 #else
     return false;
