@@ -78,6 +78,8 @@ LinkHidePrivate::~LinkHidePrivate() = default;
 
 LinkResetFormPrivate::~LinkResetFormPrivate() = default;
 
+LinkSubmitFormPrivate::~LinkSubmitFormPrivate() = default;
+
 class LinkGotoPrivate : public LinkPrivate
 {
 public:
@@ -300,7 +302,7 @@ LinkDestination::LinkDestination(const LinkDestinationData &data) : d(new LinkDe
 
 LinkDestination::LinkDestination(const QString &description) : d(new LinkDestinationPrivate)
 {
-    const QStringList tokens = description.split(';');
+    const QStringList tokens = description.split(QChar::fromLatin1(';'));
     if (tokens.size() >= 10) {
         d->kind = static_cast<Kind>(tokens.at(0).toInt());
         d->pageNum = tokens.at(1).toInt();
@@ -315,9 +317,9 @@ LinkDestination::LinkDestination(const QString &description) : d(new LinkDestina
     }
 }
 
-LinkDestination::LinkDestination(const LinkDestination &other) : d(other.d) { }
+LinkDestination::LinkDestination(const LinkDestination &other) = default;
 
-LinkDestination::~LinkDestination() { }
+LinkDestination::~LinkDestination() = default;
 
 LinkDestination::Kind LinkDestination::kind() const
 {
@@ -371,16 +373,17 @@ bool LinkDestination::isChangeZoom() const
 
 QString LinkDestination::toString() const
 {
+    const QChar semicolon = QChar::fromLatin1(';');
     QString s = QString::number((qint8)d->kind);
-    s += ";" + QString::number(d->pageNum);
-    s += ";" + QString::number(d->left);
-    s += ";" + QString::number(d->bottom);
-    s += ";" + QString::number(d->right);
-    s += ";" + QString::number(d->top);
-    s += ";" + QString::number(d->zoom);
-    s += ";" + QString::number((qint8)d->changeLeft);
-    s += ";" + QString::number((qint8)d->changeTop);
-    s += ";" + QString::number((qint8)d->changeZoom);
+    s += semicolon + QString::number(d->pageNum);
+    s += semicolon + QString::number(d->left);
+    s += semicolon + QString::number(d->bottom);
+    s += semicolon + QString::number(d->right);
+    s += semicolon + QString::number(d->top);
+    s += semicolon + QString::number(d->zoom);
+    s += semicolon + QString::number((qint8)d->changeLeft);
+    s += semicolon + QString::number((qint8)d->changeTop);
+    s += semicolon + QString::number((qint8)d->changeZoom);
     return s;
 }
 
@@ -437,7 +440,7 @@ LinkGoto::LinkGoto(const QRectF &linkArea, const QString &extFileName, const Lin
     d->extFileName = extFileName;
 }
 
-LinkGoto::~LinkGoto() { }
+LinkGoto::~LinkGoto() = default;
 
 bool LinkGoto::isExternal() const
 {
@@ -470,7 +473,7 @@ LinkExecute::LinkExecute(const QRectF &linkArea, const QString &file, const QStr
     d->parameters = params;
 }
 
-LinkExecute::~LinkExecute() { }
+LinkExecute::~LinkExecute() = default;
 
 QString LinkExecute::fileName() const
 {
@@ -495,7 +498,7 @@ LinkBrowse::LinkBrowse(const QRectF &linkArea, const QString &url) : Link(*new L
     d->url = url;
 }
 
-LinkBrowse::~LinkBrowse() { }
+LinkBrowse::~LinkBrowse() = default;
 
 QString LinkBrowse::url() const
 {
@@ -515,7 +518,7 @@ LinkAction::LinkAction(const QRectF &linkArea, ActionType actionType) : Link(*ne
     d->type = actionType;
 }
 
-LinkAction::~LinkAction() { }
+LinkAction::~LinkAction() = default;
 
 LinkAction::ActionType LinkAction::actionType() const
 {
@@ -539,7 +542,7 @@ LinkSound::LinkSound(const QRectF &linkArea, double volume, bool sync, bool repe
     d->sound = sound;
 }
 
-LinkSound::~LinkSound() { }
+LinkSound::~LinkSound() = default;
 
 Link::LinkType LinkSound::linkType() const
 {
@@ -587,7 +590,7 @@ LinkRendition::LinkRendition(const QRectF &linkArea, std::unique_ptr<::MediaRend
 {
 }
 
-LinkRendition::~LinkRendition() { }
+LinkRendition::~LinkRendition() = default;
 
 Link::LinkType LinkRendition::linkType() const
 {
@@ -629,7 +632,7 @@ LinkJavaScript::LinkJavaScript(const QRectF &linkArea, const QString &js) : Link
     d->js = js;
 }
 
-LinkJavaScript::~LinkJavaScript() { }
+LinkJavaScript::~LinkJavaScript() = default;
 
 Link::LinkType LinkJavaScript::linkType() const
 {
@@ -645,7 +648,7 @@ QString LinkJavaScript::script() const
 // LinkMovie
 LinkMovie::LinkMovie(const QRectF &linkArea, Operation operation, const QString &annotationTitle, const Ref annotationReference) : Link(*new LinkMoviePrivate(linkArea, operation, annotationTitle, annotationReference)) { }
 
-LinkMovie::~LinkMovie() { }
+LinkMovie::~LinkMovie() = default;
 
 Link::LinkType LinkMovie::linkType() const
 {
@@ -672,7 +675,7 @@ bool LinkMovie::isReferencedAnnotation(const MovieAnnotation *annotation) const
 
 LinkOCGState::LinkOCGState(LinkOCGStatePrivate *ocgp) : Link(*ocgp) { }
 
-LinkOCGState::~LinkOCGState() { }
+LinkOCGState::~LinkOCGState() = default;
 
 Link::LinkType LinkOCGState::linkType() const
 {
@@ -682,7 +685,7 @@ Link::LinkType LinkOCGState::linkType() const
 // LinkHide
 LinkHide::LinkHide(LinkHidePrivate *lhidep) : Link(*lhidep) { }
 
-LinkHide::~LinkHide() { }
+LinkHide::~LinkHide() = default;
 
 Link::LinkType LinkHide::linkType() const
 {
@@ -704,10 +707,54 @@ bool LinkHide::isShowAction() const
 // LinkResetForm
 LinkResetForm::LinkResetForm(LinkResetFormPrivate *lrfp) : Link(*lrfp) { }
 
-LinkResetForm::~LinkResetForm() { }
+LinkResetForm::~LinkResetForm() = default;
 
 Link::LinkType LinkResetForm::linkType() const
 {
     return ResetForm;
 }
+
+// LinkSubmitForm
+// static assertions to ensure flags from Link.h match those from poppler-link.h
+static_assert(static_cast<int>(LinkSubmitForm::NoOpFlag) == static_cast<int>(::LinkSubmitForm::NoOpFlag), "NoOpFlag does not match");
+static_assert(static_cast<int>(LinkSubmitForm::ExcludeFlag) == static_cast<int>(::LinkSubmitForm::ExcludeFlag), "ExcludeFlag does not match");
+static_assert(static_cast<int>(LinkSubmitForm::IncludeNoValueFieldsFlag) == static_cast<int>(::LinkSubmitForm::IncludeNoValueFieldsFlag), "IncludeNoValueFieldsFlag does not match");
+static_assert(static_cast<int>(LinkSubmitForm::ExportFormatFlag) == static_cast<int>(::LinkSubmitForm::ExportFormatFlag), "ExportFormatFlag does not match");
+static_assert(static_cast<int>(LinkSubmitForm::GetMethodFlag) == static_cast<int>(::LinkSubmitForm::GetMethodFlag), "GetMethodFlag does not match");
+static_assert(static_cast<int>(LinkSubmitForm::SubmitCoordinatesFlag) == static_cast<int>(::LinkSubmitForm::SubmitCoordinatesFlag), "SubmitCoordinatesFlag does not match");
+static_assert(static_cast<int>(LinkSubmitForm::XFDFFlag) == static_cast<int>(::LinkSubmitForm::XFDFFlag), "XFDFFlag does not match");
+static_assert(static_cast<int>(LinkSubmitForm::IncludeAppendSavesFlag) == static_cast<int>(::LinkSubmitForm::IncludeAppendSavesFlag), "IncludeAppendSavesFlag does not match");
+static_assert(static_cast<int>(LinkSubmitForm::IncludeAnnotationsFlag) == static_cast<int>(::LinkSubmitForm::IncludeAnnotationsFlag), "IncludeAnnotationsFlag does not match");
+static_assert(static_cast<int>(LinkSubmitForm::SubmitPDFFlag) == static_cast<int>(::LinkSubmitForm::SubmitPDFFlag), "SubmitPDFFlag does not match");
+static_assert(static_cast<int>(LinkSubmitForm::CanonicalFormatFlag) == static_cast<int>(::LinkSubmitForm::CanonicalFormatFlag), "CanonicalFormatFlag does not match");
+static_assert(static_cast<int>(LinkSubmitForm::ExclNonUserAnnotsFlag) == static_cast<int>(::LinkSubmitForm::ExclNonUserAnnotsFlag), "ExclNonUserAnnotsFlag does not match");
+static_assert(static_cast<int>(LinkSubmitForm::ExclFKeyFlag) == static_cast<int>(::LinkSubmitForm::ExclFKeyFlag), "ExclFKeyFlag does not match");
+static_assert(static_cast<int>(LinkSubmitForm::EmbedFormFlag) == static_cast<int>(::LinkSubmitForm::EmbedFormFlag), "EmbedFormFlag does not match");
+
+LinkSubmitForm::LinkSubmitForm(LinkSubmitFormPrivate *lsfp) : Link(*lsfp) { }
+
+LinkSubmitForm::~LinkSubmitForm() = default;
+
+Link::LinkType LinkSubmitForm::linkType() const
+{
+    return SubmitForm;
+}
+
+QVector<int> LinkSubmitForm::getFieldIds() const
+{
+    Q_D(const LinkSubmitForm);
+    return d->m_fieldIds;
+}
+
+QString LinkSubmitForm::getUrl() const
+{
+    Q_D(const LinkSubmitForm);
+    return d->m_url;
+}
+
+LinkSubmitForm::SubmitFormFlags LinkSubmitForm::getFlags() const
+{
+    Q_D(const LinkSubmitForm);
+    return d->m_flags;
+}
 }
