@@ -1,4 +1,4 @@
-#include <QtTest/QtTest>
+#include <QtTest/QTest>
 
 #include <poppler-qt6.h>
 
@@ -7,8 +7,9 @@ class TestSearch : public QObject
     Q_OBJECT
 public:
     explicit TestSearch(QObject *parent = nullptr) : QObject(parent) { }
-private slots:
+private Q_SLOTS:
     void testAcrossLinesSearch(); // leave it first
+    void testAcrossLinesSearchDoubleColumn();
     void bug7063();
     void testNextAndPrevious();
     void testWholeWordsOnly();
@@ -19,7 +20,7 @@ private slots:
 
 void TestSearch::bug7063()
 {
-    std::unique_ptr<Poppler::Document> document = Poppler::Document::load(TESTDATADIR "/unittestcases/bug7063.pdf");
+    std::unique_ptr<Poppler::Document> document = Poppler::Document::load(QStringLiteral(TESTDATADIR "/unittestcases/bug7063.pdf"));
     QVERIFY(document);
 
     std::unique_ptr<Poppler::Page> page = document->page(0);
@@ -58,7 +59,7 @@ void TestSearch::bug7063()
 
 void TestSearch::testNextAndPrevious()
 {
-    std::unique_ptr<Poppler::Document> document = Poppler::Document::load(TESTDATADIR "/unittestcases/xr01.pdf");
+    std::unique_ptr<Poppler::Document> document = Poppler::Document::load(QStringLiteral(TESTDATADIR "/unittestcases/xr01.pdf"));
     QVERIFY(document);
 
     std::unique_ptr<Poppler::Page> page = document->page(0);
@@ -147,7 +148,7 @@ void TestSearch::testNextAndPrevious()
 
 void TestSearch::testWholeWordsOnly()
 {
-    std::unique_ptr<Poppler::Document> document = Poppler::Document::load(TESTDATADIR "/unittestcases/WithActualText.pdf");
+    std::unique_ptr<Poppler::Document> document = Poppler::Document::load(QStringLiteral(TESTDATADIR "/unittestcases/WithActualText.pdf"));
     QVERIFY(document);
 
     std::unique_ptr<Poppler::Page> page = document->page(0);
@@ -177,7 +178,7 @@ void TestSearch::testWholeWordsOnly()
 
 void TestSearch::testIgnoreDiacritics()
 {
-    std::unique_ptr<Poppler::Document> document = Poppler::Document::load(TESTDATADIR "/unittestcases/Issue637.pdf");
+    std::unique_ptr<Poppler::Document> document = Poppler::Document::load(QStringLiteral(TESTDATADIR "/unittestcases/Issue637.pdf"));
     QVERIFY(document);
 
     std::unique_ptr<Poppler::Page> page = document->page(0);
@@ -236,7 +237,7 @@ void TestSearch::testIgnoreDiacritics()
 void TestSearch::testRussianSearch()
 {
     // Test for issue #743
-    std::unique_ptr<Poppler::Document> document = Poppler::Document::load(TESTDATADIR "/unittestcases/russian.pdf");
+    std::unique_ptr<Poppler::Document> document = Poppler::Document::load(QStringLiteral(TESTDATADIR "/unittestcases/russian.pdf"));
     QVERIFY(document);
 
     std::unique_ptr<Poppler::Page> page = document->page(0);
@@ -265,7 +266,7 @@ void TestSearch::testRussianSearch()
 
 void TestSearch::testDeseretSearch()
 {
-    std::unique_ptr<Poppler::Document> document = Poppler::Document::load(TESTDATADIR "/unittestcases/deseret.pdf");
+    std::unique_ptr<Poppler::Document> document = Poppler::Document::load(QStringLiteral(TESTDATADIR "/unittestcases/deseret.pdf"));
     QVERIFY(document);
 
     std::unique_ptr<Poppler::Page> page = document->page(0);
@@ -285,7 +286,7 @@ void TestSearch::testAcrossLinesSearch()
     // Test for searching across lines with new flag Poppler::Page::AcrossLines
     // and its automatic features like ignoring hyphen at end of line or allowing
     // whitespace in the search term to match on newline character.
-    std::unique_ptr<Poppler::Document> document = Poppler::Document::load(TESTDATADIR "/unittestcases/searchAcrossLines.pdf");
+    std::unique_ptr<Poppler::Document> document = Poppler::Document::load(QStringLiteral(TESTDATADIR "/unittestcases/searchAcrossLines.pdf"));
     QVERIFY(document);
 
     std::unique_ptr<Poppler::Page> page = document->page(1);
@@ -347,10 +348,17 @@ void TestSearch::testAcrossLinesSearch()
     QCOMPARE(page0->search(str6, l, t, r, b, direction, mode1), true);
     QCOMPARE(page0->search(str6, l, t, r, b, direction, mode2), true);
     QCOMPARE(page0->search(str6, l, t, r, b, direction, mode2W), true);
+    // Check for the case when next line falls in next paragraph. Issue #1475
+    const QString across_block = QString::fromUtf8("emacs jose"); // clazy:exclude=qstring-allocations
+    QCOMPARE(page0->search(across_block, l, t, r, b, direction, empty), false);
+    QCOMPARE(page0->search(across_block, l, t, r, b, direction, mode0), false);
+    QCOMPARE(page0->search(across_block, l, t, r, b, direction, mode1), false);
+    QCOMPARE(page0->search(across_block, l, t, r, b, direction, mode2), true);
+    QCOMPARE(page0->search(across_block, l, t, r, b, direction, mode2W), true);
 
     // Now for completeness, we will match the full text of two lines
-    const QString full2lines = QString::fromUtf8(
-            "Las pruebas se practicarán en vista pública, si bien, excepcionalmente, el Tribunal podrá acordar, mediante providencia, que determinadas pruebas se celebren fuera del acto de juicio"); // clazy:exclude=qstring-allocations
+    const QString full2lines = QString::fromUtf8( // clazy:exclude=qstring-allocations
+            "Las pruebas se practicarán en vista pública, si bien, excepcionalmente, el Tribunal podrá acordar, mediante providencia, que determinadas pruebas se celebren fuera del acto de juicio");
     QCOMPARE(page->search(full2lines, l, t, r, b, direction, mode0), true);
     QCOMPARE(page->search(full2lines, l, t, r, b, direction, mode1), true);
     QCOMPARE(page->search(full2lines, l, t, r, b, direction, mode2), true);
@@ -362,6 +370,32 @@ void TestSearch::testAcrossLinesSearch()
     QCOMPARE(page->search(full2linesHyphenated, l, t, r, b, direction, mode1), true);
     QCOMPARE(page->search(full2linesHyphenated, l, t, r, b, direction, mode2), true);
     QCOMPARE(page->search(full2linesHyphenated, l, t, r, b, direction, mode2W), true);
+
+    // BUG about false positives at start of a line.
+    const QString bug_str = QString::fromUtf8("nes y"); // clazy:exclude=qstring-allocations
+    // there's only 1 match, check for that
+    QCOMPARE(page->search(bug_str, mode2).size(), 1);
+}
+
+void TestSearch::testAcrossLinesSearchDoubleColumn()
+{
+    // Test for searching across lines with new flag Poppler::Page::AcrossLines
+    // in a document with two columns of text.
+    std::unique_ptr<Poppler::Document> document = Poppler::Document::load(QStringLiteral(TESTDATADIR "/unittestcases/searchAcrossLinesDoubleColumn.pdf"));
+    QVERIFY(document);
+
+    std::unique_ptr<Poppler::Page> page = document->page(0);
+    QVERIFY(page);
+
+    const Poppler::Page::SearchFlags mode = Poppler::Page::AcrossLines | Poppler::Page::IgnoreDiacritics | Poppler::Page::IgnoreCase;
+
+    // Test for a bug in double column documents where single line matches are
+    // wrongly returned as being multiline matches.
+    const QString bug_str = QString::fromUtf8("betw"); // clazy:exclude=qstring-allocations
+
+    // there's only 3 matches for 'betw' in document, where only the last
+    // one is a multiline match, so that's a total of 4 rects returned
+    QCOMPARE(page->search(bug_str, mode).size(), 4);
 }
 
 QTEST_GUILESS_MAIN(TestSearch)
