@@ -48,7 +48,7 @@ void PDFDisplay::display()
 
 PDFDisplay::~PDFDisplay() = default;
 
-void PDFDisplay::paintEvent(QPaintEvent *e)
+void PDFDisplay::paintEvent(QPaintEvent * /*e*/)
 {
     QPainter paint(this); // paint widget
     if (!image.isNull()) {
@@ -84,7 +84,7 @@ int main(int argc, char **argv)
         exit(1);
     }
 
-    std::unique_ptr<Poppler::Document> doc = Poppler::Document::load(argv[2], argv[1]);
+    std::unique_ptr<Poppler::Document> doc = Poppler::Document::load(QString::fromLocal8Bit(argv[2]), argv[1]);
     if (!doc) {
         qWarning() << "doc not loaded";
         exit(1);
@@ -110,7 +110,7 @@ int main(int argc, char **argv)
     qDebug() << "OK to add notes: " << doc->okToAddNotes();
     qDebug() << "      Page mode: " << doc->pageMode();
     QStringList fontNameList;
-    foreach (const Poppler::FontInfo &font, doc->fonts())
+    Q_FOREACH (const Poppler::FontInfo &font, doc->fonts())
         fontNameList += font.name();
     qDebug() << "          Fonts: " << fontNameList.join(QStringLiteral(", "));
 
