@@ -11,7 +11,7 @@
 // All changes made under the Poppler project to this file are licensed
 // under GPL version 2 or later
 //
-// Copyright (C) 2009-2011 Albert Astals Cid <aacid@kde.org>
+// Copyright (C) 2009-2011, 2025 Albert Astals Cid <aacid@kde.org>
 // Copyright (C) 2017 Adrian Johnson <ajohnson@redneon.com>
 // Copyright (C) 2020 Jean Ghali <jghali@libertysurf.fr>
 //
@@ -30,7 +30,7 @@
 
 static inline SplashCoord splashAbs(SplashCoord x)
 {
-#if defined(USE_FLOAT)
+#if USE_FLOAT
     return fabsf(x);
 #else
     return fabs(x);
@@ -39,7 +39,7 @@ static inline SplashCoord splashAbs(SplashCoord x)
 
 static inline int splashFloor(SplashCoord x)
 {
-#if defined(USE_FLOAT)
+#if USE_FLOAT
     return (int)floorf(x);
 #elif defined(__GNUC__) && defined(__i386__)
     // floor() and (int)() are implemented separately, which results
@@ -88,7 +88,7 @@ static inline int splashFloor(SplashCoord x)
 
 static inline int splashCeil(SplashCoord x)
 {
-#if defined(USE_FLOAT)
+#if USE_FLOAT
     return (int)ceilf(x);
 #elif defined(__GNUC__) && defined(__i386__)
     // ceil() and (int)() are implemented separately, which results
@@ -183,7 +183,7 @@ static inline SplashCoord splashAvg(SplashCoord x, SplashCoord y)
 
 static inline SplashCoord splashSqrt(SplashCoord x)
 {
-#if defined(USE_FLOAT)
+#if USE_FLOAT
     return sqrtf(x);
 #else
     return sqrt(x);
@@ -192,7 +192,7 @@ static inline SplashCoord splashSqrt(SplashCoord x)
 
 static inline SplashCoord splashPow(SplashCoord x, SplashCoord y)
 {
-#if defined(USE_FLOAT)
+#if USE_FLOAT
     return powf(x, y);
 #else
     return pow(x, y);
