@@ -12,7 +12,7 @@
 // under GPL version 2 or later
 //
 // Copyright (C) 2018 Stefan Brüns <stefan.bruens@rwth-aachen.de>
-// Copyright (C) 2018, 2019 Albert Astals Cid <aacid@kde.org>
+// Copyright (C) 2018-2021, 2025 Albert Astals Cid <aacid@kde.org>
 // Copyright (C) 2018 Adam Reichold <adam.reichold@t-online.de>
 //
 // To see a description of the changes please see the Changelog file that
@@ -22,7 +22,6 @@
 
 #include <config.h>
 
-#include <cstring>
 #include "goo/gmem.h"
 #include "goo/GooLikely.h"
 #include "SplashErrorCodes.h"
@@ -53,24 +52,6 @@ SplashPath::SplashPath()
     hintsLength = hintsSize = 0;
 }
 
-SplashPath::SplashPath(SplashPath *path)
-{
-    length = path->length;
-    size = path->size;
-    pts = (SplashPathPoint *)gmallocn(size, sizeof(SplashPathPoint));
-    flags = (unsigned char *)gmallocn(size, sizeof(unsigned char));
-    memcpy(pts, path->pts, length * sizeof(SplashPathPoint));
-    memcpy(flags, path->flags, length * sizeof(unsigned char));
-    curSubpath = path->curSubpath;
-    if (path->hints) {
-        hintsLength = hintsSize = path->hintsLength;
-        hints = (SplashPathHint *)gmallocn(hintsSize, sizeof(SplashPathHint));
-        memcpy(hints, path->hints, hintsLength * sizeof(SplashPathHint));
-    } else {
-        hints = nullptr;
-    }
-}
-
 SplashPath::SplashPath(SplashPath &&path) noexcept
 {
     length = path.length;
@@ -124,8 +105,9 @@ void SplashPath::append(SplashPath *path)
     int i;
 
     grow(path->length);
-    if (unlikely(size == 0))
+    if (unlikely(size == 0)) {
         return;
+    }
 
     curSubpath = length + path->curSubpath;
     for (i = 0; i < path->length; ++i) {
@@ -141,8 +123,9 @@ SplashError SplashPath::moveTo(SplashCoord x, SplashCoord y)
         return splashErrBogusPath;
     }
     grow(1);
-    if (unlikely(size == 0))
+    if (unlikely(size == 0)) {
         return splashErrBogusPath;
+    }
     pts[length].x = x;
     pts[length].y = y;
     flags[length] = splashPathFirst | splashPathLast;
@@ -157,8 +140,9 @@ SplashError SplashPath::lineTo(SplashCoord x, SplashCoord y)
     }
     flags[length - 1] &= ~splashPathLast;
     grow(1);
-    if (unlikely(size == 0))
+    if (unlikely(size == 0)) {
         return splashErrBogusPath;
+    }
     pts[length].x = x;
     pts[length].y = y;
     flags[length] = splashPathLast;
@@ -173,8 +157,9 @@ SplashError SplashPath::curveTo(SplashCoord x1, SplashCoord y1, SplashCoord x2,
     }
     flags[length - 1] &= ~splashPathLast;
     grow(3);
-    if (unlikely(size == 0))
+    if (unlikely(size == 0)) {
         return splashErrBogusPath;
+    }
     pts[length].x = x1;
     pts[length].y = y1;
     flags[length] = splashPathCurve;
@@ -196,7 +181,10 @@ SplashError SplashPath::close(bool force)
         return splashErrNoCurPt;
     }
     if (force || curSubpath == length - 1 || pts[length - 1].x != pts[curSubpath].x || pts[length - 1].y != pts[curSubpath].y) {
-        lineTo(pts[curSubpath].x, pts[curSubpath].y);
+        const auto lineToStatus = lineTo(pts[curSubpath].x, pts[curSubpath].y);
+        if (lineToStatus != splashOk) {
+            return lineToStatus;
+        }
     }
     flags[curSubpath] |= splashPathClosed;
     flags[length - 1] |= splashPathClosed;
@@ -208,7 +196,10 @@ void SplashPath::addStrokeAdjustHint(int ctrl0, int ctrl1, int firstPt, int last
 {
     if (hintsLength == hintsSize) {
         hintsSize = hintsLength ? 2 * hintsLength : 8;
-        hints = (SplashPathHint *)greallocn(hints, hintsSize, sizeof(SplashPathHint));
+        hints = (SplashPathHint *)greallocn_checkoverflow(hints, hintsSize, sizeof(SplashPathHint));
+    }
+    if (unlikely(!hints)) {
+        return;
     }
     hints[hintsLength].ctrl0 = ctrl0;
     hints[hintsLength].ctrl1 = ctrl1;
