@@ -24,9 +24,6 @@
 
 #include <config.h>
 
-#include <cstdlib>
-#include <cstring>
-#include <algorithm>
 #include "goo/gmem.h"
 #include "goo/GooLikely.h"
 #include "SplashMath.h"
@@ -52,7 +49,7 @@ struct SplashXPathAdjust
 //------------------------------------------------------------------------
 
 // Transform a point from user space to device space.
-inline void SplashXPath::transform(const SplashCoord *matrix, SplashCoord xi, SplashCoord yi, SplashCoord *xo, SplashCoord *yo)
+inline void SplashXPath::transform(const std::array<SplashCoord, 6> &matrix, SplashCoord xi, SplashCoord yi, SplashCoord *xo, SplashCoord *yo)
 {
     //                          [ m[0] m[1] 0 ]
     // [xo yo 1] = [xi yi 1] *  [ m[2] m[3] 0 ]
@@ -65,7 +62,7 @@ inline void SplashXPath::transform(const SplashCoord *matrix, SplashCoord xi, Sp
 // SplashXPath
 //------------------------------------------------------------------------
 
-SplashXPath::SplashXPath(const SplashPath &path, SplashCoord *matrix, SplashCoord flatness, bool closeSubpaths, bool adjustLines, int linePosI)
+SplashXPath::SplashXPath(const SplashPath &path, const std::array<SplashCoord, 6> &matrix, SplashCoord flatness, bool closeSubpaths, bool adjustLines, int linePosI)
 {
     SplashPathHint *hint;
     SplashXPathPoint *pts;
@@ -194,8 +191,7 @@ SplashXPath::SplashXPath(const SplashPath &path, SplashCoord *matrix, SplashCoor
                 y2 = pts[i + 1].y;
                 x3 = pts[i + 2].x;
                 y3 = pts[i + 2].y;
-                addCurve(x0, y0, x1, y1, x2, y2, x3, y3, flatness, (path.flags[i - 1] & splashPathFirst), (path.flags[i + 2] & splashPathLast),
-                         !closeSubpaths && (path.flags[i - 1] & splashPathFirst) && !(path.flags[i - 1] & splashPathClosed), !closeSubpaths && (path.flags[i + 2] & splashPathLast) && !(path.flags[i + 2] & splashPathClosed));
+                addCurve(x0, y0, x1, y1, x2, y2, x3, y3, flatness);
                 x0 = x3;
                 y0 = y3;
                 i += 3;
@@ -269,7 +265,7 @@ void SplashXPath::grow(int nSegs)
     }
 }
 
-void SplashXPath::addCurve(SplashCoord x0, SplashCoord y0, SplashCoord x1, SplashCoord y1, SplashCoord x2, SplashCoord y2, SplashCoord x3, SplashCoord y3, SplashCoord flatness, bool first, bool last, bool end0, bool end1)
+void SplashXPath::addCurve(SplashCoord x0, SplashCoord y0, SplashCoord x1, SplashCoord y1, SplashCoord x2, SplashCoord y2, SplashCoord x3, SplashCoord y3, SplashCoord flatness)
 {
     if (!curveData) {
         // allocate on first use
