@@ -1,8 +1,10 @@
 /* Copyright Krzysztof Kowalczyk 2006-2007
    Copyright Hib Eris <hib@hiberis.nl> 2008, 2013
-   Copyright 2018, 2020, 2022 Albert Astals Cid <aacid@kde.org> 2018
+   Copyright 2018, 2020, 2022, 2025 Albert Astals Cid <aacid@kde.org> 2018
    Copyright 2019 Oliver Sander <oliver.sander@tu-dresden.de>
    Copyright 2020 Adam Reichold <adam.reichold@t-online.de>
+   Copyright 2024 Vincent Lefevre <vincent@vinc17.net>
+   Copyright 2024, 2026 g10 Code GmbH, Author: Sune Stolborg Vuorela <sune@vuorela.dk>
    License: GPLv2 */
 /*
   A tool to stress-test poppler rendering and measure rendering times for
@@ -25,17 +27,11 @@
 
 #include <config.h>
 
-#ifdef _WIN32
-#    include <windows.h>
-#else
-#    include <strings.h>
-#endif
-
 // Define COPY_FILE if you want the file to be copied to a local disk first
 // before it's tested. This is desired if a file is on a slow drive.
 // Currently copying only works on Windows.
 // Not enabled by default.
-//#define COPY_FILE 1
+// #define COPY_FILE 1
 
 #include <cassert>
 #include <cstdio>
@@ -46,10 +42,6 @@
 #include <cerrno>
 #include <ctime>
 
-#ifdef HAVE_DIRENT_H
-#    include <dirent.h>
-#endif
-
 #include "Error.h"
 #include "ErrorCodes.h"
 #include "goo/GooString.h"
@@ -62,22 +54,9 @@
 #include "PDFDoc.h"
 #include "Link.h"
 
-#ifdef _MSC_VER
-#    define strdup _strdup
-#    define strcasecmp _stricmp
-#endif
-
 #define dimof(X) (sizeof(X) / sizeof((X)[0]))
 
-#define INVALID_PAGE_NO -1
-
-/* Those must be implemented in order to provide preview during execution.
-   They can be no-ops. An implementation for windows is in
-   perf-test-preview-win.cc
-*/
-extern void PreviewBitmapInit();
-extern void PreviewBitmapDestroy();
-extern void PreviewBitmapSplash(SplashBitmap *bmpSplash);
+#define INVALID_PAGE_NO (-1)
 
 class PdfEnginePoppler
 {
@@ -130,8 +109,6 @@ static StrList *gArgsListRoot = nullptr;
 #define RESOLUTION_ARG "-resolution"
 #define RECURSIVE_ARG "-recursive"
 #define OUT_ARG "-out"
-#define PREVIEW_ARG "-preview"
-#define SLOW_PREVIEW_ARG "-slowpreview"
 #define LOAD_ONLY_ARG "-loadonly"
 #define PAGE_ARG "-page"
 #define TEXT_ARG "-text"
@@ -161,22 +138,13 @@ static FILE *gErrFile = nullptr;
    Controlled by -recursive command-line argument */
 static bool gfRecursive = false;
 
-/* If true, preview rendered image. To make sure that they're being rendered correctly. */
-static bool gfPreview = false;
-
 /* 1 second (1000 milliseconds) */
 #define SLOW_PREVIEW_TIME 1000
 
-/* If true, preview rendered image in a slow mode i.e. delay displaying for
-   SLOW_PREVIEW_TIME. This is so that a human has enough time to see if the
-   PDF renders ok. In release mode on fast processor pages take only ~100-200 ms
-   to render and they go away too quickly to be inspected by a human. */
-static bool gfSlowPreview = false;
-
 /* If true, we only dump the text, not render */
 static bool gfTextOnly = false;
 
-#define PAGE_NO_NOT_GIVEN -1
+#define PAGE_NO_NOT_GIVEN (-1)
 
 /* If equals PAGE_NO_NOT_GIVEN, we're in default mode where we render all pages.
    If different, will only render this page */
@@ -312,36 +280,6 @@ static bool str_endswith(const char *txt, const char *end)
     return false;
 }
 
-/* TODO: probably should move to some other file and change name to
-   sleep_milliseconds */
-static void sleep_milliseconds(int milliseconds)
-{
-#ifdef _WIN32
-    Sleep((DWORD)milliseconds);
-#else
-    struct timespec tv;
-    int secs, nanosecs;
-    secs = milliseconds / 1000;
-    nanosecs = (milliseconds - (secs * 1000)) * 1000;
-    tv.tv_sec = (time_t)secs;
-    tv.tv_nsec = (long)nanosecs;
-    while (true) {
-        int rval = nanosleep(&tv, &tv);
-        if (rval == 0) {
-            /* Completed the entire sleep time; all done. */
-            return;
-        } else if (errno == EINTR) {
-            /* Interrupted by a signal. Try again. */
-            continue;
-        } else {
-            /* Some other error; bail out. */
-            return;
-        }
-    }
-    return;
-#endif
-}
-
 static SplashColorMode gSplashColorMode = splashModeBGR8;
 
 static SplashColor splashColRed;
@@ -350,15 +288,15 @@ static SplashColor splashColBlue;
 static SplashColor splashColWhite;
 static SplashColor splashColBlack;
 
-#define SPLASH_COL_RED_PTR (SplashColorPtr) & (splashColRed[0])
-#define SPLASH_COL_GREEN_PTR (SplashColorPtr) & (splashColGreen[0])
-#define SPLASH_COL_BLUE_PTR (SplashColorPtr) & (splashColBlue[0])
-#define SPLASH_COL_WHITE_PTR (SplashColorPtr) & (splashColWhite[0])
-#define SPLASH_COL_BLACK_PTR (SplashColorPtr) & (splashColBlack[0])
+#define SPLASH_COL_RED_PTR ((SplashColorPtr) & (splashColRed[0]))
+#define SPLASH_COL_GREEN_PTR ((SplashColorPtr) & (splashColGreen[0]))
+#define SPLASH_COL_BLUE_PTR ((SplashColorPtr) & (splashColBlue[0]))
+#define SPLASH_COL_WHITE_PTR ((SplashColorPtr) & (splashColWhite[0]))
+#define SPLASH_COL_BLACK_PTR ((SplashColorPtr) & (splashColBlack[0]))
 
 static SplashColorPtr gBgColor = SPLASH_COL_WHITE_PTR;
 
-static void splashColorSet(SplashColorPtr col, unsigned char red, unsigned char green, unsigned char blue, unsigned char alpha)
+static void splashColorSet(SplashColorPtr col, unsigned char red, unsigned char green, unsigned char blue)
 {
     switch (gSplashColorMode) {
     case splashModeBGR8:
@@ -379,11 +317,11 @@ static void splashColorSet(SplashColorPtr col, unsigned char red, unsigned char
 
 static void SplashColorsInit()
 {
-    splashColorSet(SPLASH_COL_RED_PTR, 0xff, 0, 0, 0);
-    splashColorSet(SPLASH_COL_GREEN_PTR, 0, 0xff, 0, 0);
-    splashColorSet(SPLASH_COL_BLUE_PTR, 0, 0, 0xff, 0);
-    splashColorSet(SPLASH_COL_BLACK_PTR, 0, 0, 0, 0);
-    splashColorSet(SPLASH_COL_WHITE_PTR, 0xff, 0xff, 0xff, 0);
+    splashColorSet(SPLASH_COL_RED_PTR, 0xff, 0, 0);
+    splashColorSet(SPLASH_COL_GREEN_PTR, 0, 0xff, 0);
+    splashColorSet(SPLASH_COL_BLUE_PTR, 0, 0, 0xff);
+    splashColorSet(SPLASH_COL_BLACK_PTR, 0, 0, 0);
+    splashColorSet(SPLASH_COL_WHITE_PTR, 0xff, 0xff, 0xff);
 }
 
 PdfEnginePoppler::PdfEnginePoppler() : _fileName(nullptr), _pageCount(INVALID_PAGE_NO), _pdfDoc(nullptr), _outputDev(nullptr) { }
@@ -517,7 +455,7 @@ static void StrList_Destroy(StrList **root)
     *root = nullptr;
 }
 
-static void my_error(ErrorCategory, Goffset pos, const char *msg)
+static void my_error(ErrorCategory, Goffset /*pos*/, const char * /*msg*/)
 {
 #if 0
     char        buf[4096], *p = buf;
@@ -597,18 +535,9 @@ static void PrintUsageAndExit(int argc, char **argv)
     exit(0);
 }
 
-static bool ShowPreview()
-{
-    if (gfPreview || gfSlowPreview) {
-        return true;
-    }
-    return false;
-}
-
 static void RenderPdfAsText(const char *fileName)
 {
     PDFDoc *pdfDoc = nullptr;
-    GooString *txt = nullptr;
     int pageCount;
     double timeInMs;
 
@@ -628,7 +557,7 @@ static void RenderPdfAsText(const char *fileName)
     GooTimer msTimer;
     pdfDoc = new PDFDoc(std::make_unique<GooString>(fileName));
     if (!pdfDoc->isOk()) {
-        error(errIO, -1, "RenderPdfFile(): failed to open PDF file {0:s}\n", fileName);
+        error(errIO, -1, "RenderPdfFile(): failed to open PDF file {0:s}", fileName);
         goto Exit;
     }
 
@@ -650,15 +579,13 @@ static void RenderPdfAsText(const char *fileName)
         bool crop = true;
         bool doLinks = false;
         pdfDoc->displayPage(textOut, curPage, 72, 72, rotate, useMediaBox, crop, doLinks);
-        txt = textOut->getText(0.0, 0.0, 10000.0, 10000.0);
+        GooString txt = textOut->getText(PDFRectangle { 0.0, 0.0, 10000.0, 10000.0 });
         msTimer.stop();
         timeInMs = msTimer.getElapsed();
         if (gfTimings) {
             LogInfo("page %d: %.2f ms\n", curPage, timeInMs);
         }
-        printf("%s\n", txt->c_str());
-        delete txt;
-        txt = nullptr;
+        printf("%s\n", txt.c_str());
     }
 
 Exit:
@@ -725,12 +652,6 @@ static void RenderPdf(const char *fileName)
             }
         }
 
-        if (ShowPreview()) {
-            PreviewBitmapSplash(bmpSplash);
-            if (gfSlowPreview) {
-                sleep_milliseconds(SLOW_PREVIEW_TIME);
-            }
-        }
         delete bmpSplash;
     }
 Error:
@@ -849,12 +770,8 @@ static void ParseCommandLine(int argc, char **argv)
                     PrintUsageAndExit(argc, argv);
                 }
                 gOutFileName = str_dup(argv[i]);
-            } else if (str_ieq(arg, PREVIEW_ARG)) {
-                gfPreview = true;
             } else if (str_ieq(arg, TEXT_ARG)) {
                 gfTextOnly = true;
-            } else if (str_ieq(arg, SLOW_PREVIEW_ARG)) {
-                gfSlowPreview = true;
             } else if (str_ieq(arg, LOAD_ONLY_ARG)) {
                 gfLoadOnly = true;
             } else if (str_ieq(arg, PAGE_ARG)) {
@@ -937,8 +854,6 @@ int main(int argc, char **argv)
         gErrFile = stderr;
     }
 
-    PreviewBitmapInit();
-
     StrList *curr = gArgsListRoot;
     while (curr) {
         RenderCmdLineArg(curr->str);
@@ -947,7 +862,6 @@ int main(int argc, char **argv)
     if (outFile) {
         fclose(outFile);
     }
-    PreviewBitmapDestroy();
     StrList_Destroy(&gArgsListRoot);
     free(gOutFileName);
     return 0;
