@@ -17,7 +17,7 @@
 // All changes made under the Poppler project to this file are licensed
 // under GPL version 2 or later
 //
-// Copyright (C) 2007, 2010, 2012, 2018, 2020 Albert Astals Cid <aacid@kde.org>
+// Copyright (C) 2007, 2010, 2012, 2018, 2020, 2025 Albert Astals Cid <aacid@kde.org>
 // Copyright (C) 2008 Boris Toloknov <tlknv@yandex.ru>
 // Copyright (C) 2008 Tomas Are Haavet <tomasare@gmail.com>
 // Copyright (C) 2010 OSSD CDAC Mumbai by Leena Chourey (leenac@cdacmumbai.in) and Onkar Potdar (onkar@cdacmumbai.in)
@@ -140,14 +140,14 @@ HtmlFont::HtmlFont(const GfxFont &font, int _size, GfxRGB rgb, double opacity)
     if (const std::optional<std::string> &fontname = font.getName()) {
         FontName = *fontname;
 
-        GooString fontnameLower(*fontname);
-        fontnameLower.lowerCase();
+        std::string fontnameLower = *fontname;
+        GooString::lowerCase(fontnameLower);
 
-        if (!bold && strstr(fontnameLower.c_str(), "bold")) {
+        if (!bold && fontnameLower.contains("bold")) {
             bold = true;
         }
 
-        if (!italic && (strstr(fontnameLower.c_str(), "italic") || strstr(fontnameLower.c_str(), "oblique"))) {
+        if (!italic && (fontnameLower.contains("italic") || fontnameLower.contains("oblique"))) {
             italic = true;
         }
 
