@@ -17,7 +17,7 @@
 // All changes made under the Poppler project to this file are licensed
 // under GPL version 2 or later
 //
-// Copyright (C) 2005-2013, 2016-2022, 2024 Albert Astals Cid <aacid@kde.org>
+// Copyright (C) 2005-2013, 2016-2022, 2024, 2025 Albert Astals Cid <aacid@kde.org>
 // Copyright (C) 2008 Kjartan Maraas <kmaraas@gnome.org>
 // Copyright (C) 2008 Boris Toloknov <tlknv@yandex.ru>
 // Copyright (C) 2008 Haruyuki Kawabe <Haruyuki.Kawabe@unisys.co.jp>
@@ -48,6 +48,7 @@
 // Copyright (C) 2021 Christopher Hasse <hasse.christopher@gmail.com>
 // Copyright (C) 2022 Brian Rosenfield <brosenfi@yahoo.com>
 // Copyright (C) 2024, 2025 g10 Code GmbH, Author: Sune Stolborg Vuorela <sune@vuorela.dk>
+// Copyright (C) 2025 Arnav V <arnav0872@gmail.com>
 //
 // To see a description of the changes please see the Changelog file that
 // came with your tarball or type make ChangeLog if you are building from git
@@ -57,17 +58,15 @@
 #include "config.h"
 #include <cstdio>
 #include <cstdlib>
-#include <cstdarg>
 #include <cstddef>
-#include <cctype>
 #include <cmath>
 #include <iostream>
 #include "goo/GooString.h"
 #include "goo/gbasename.h"
 #include "goo/gbase64.h"
-#include "UnicodeMap.h"
 #include "goo/gmem.h"
 #include "Error.h"
+#include "GfxFont.h"
 #include "GfxState.h"
 #include "Page.h"
 #include "Annot.h"
@@ -229,7 +228,7 @@ HtmlString::~HtmlString()
     gfree(xRight);
 }
 
-void HtmlString::addChar(GfxState *state, double x, double y, double dx, double dy, Unicode u)
+void HtmlString::addChar(GfxState * /*state*/, double x, double /*y*/, double dx, double /*dy*/, Unicode u)
 {
     if (dir == textDirUnknown) {
         // dir = UnicodeMap::getDirection(u);
@@ -330,7 +329,7 @@ void HtmlPage::updateFont(GfxState *state)
     }
 }
 
-void HtmlPage::beginString(GfxState *state, const GooString *s)
+void HtmlPage::beginString(GfxState *state, const GooString * /*s*/)
 {
     curStr = new HtmlString(state, fontSize, fonts.get());
 }
@@ -347,7 +346,7 @@ void HtmlPage::conv()
     }
 }
 
-void HtmlPage::addChar(GfxState *state, double x, double y, double dx, double dy, double ox, double oy, const Unicode *u, int uLen)
+void HtmlPage::addChar(GfxState *state, double x, double y, double dx, double dy, double /*ox*/, double /*oy*/, const Unicode *u, int uLen)
 {
     double x1, y1, w1, h1, dx2, dy2;
     int n, i;
@@ -544,7 +543,7 @@ void HtmlPage::coalesce()
     }
     if (str1->getLink() != nullptr) {
         const std::unique_ptr<GooString> ls = str1->getLink()->getLinkStart();
-        str1->htext->insert(0, ls.get());
+        str1->htext->insert(0, ls->toStr());
     }
     curX = str1->xMin;
     curY = str1->yMin;
@@ -676,7 +675,7 @@ void HtmlPage::coalesce()
             }
             if (str1->getLink() != nullptr) {
                 const std::unique_ptr<GooString> ls = str1->getLink()->getLinkStart();
-                str1->htext->insert(0, ls.get());
+                str1->htext->insert(0, ls->toStr());
             }
         }
     }
@@ -1171,7 +1170,7 @@ HtmlOutputDev::~HtmlOutputDev()
     }
 }
 
-void HtmlOutputDev::startPage(int pageNumA, GfxState *state, XRef *xref)
+void HtmlOutputDev::startPage(int pageNumA, GfxState *state, XRef * /*xref*/)
 {
 #if 0
   if (mode&&!xml){
@@ -1248,12 +1247,12 @@ void HtmlOutputDev::beginString(GfxState *state, const GooString *s)
     pages->beginString(state, s);
 }
 
-void HtmlOutputDev::endString(GfxState *state)
+void HtmlOutputDev::endString(GfxState * /*state*/)
 {
     pages->endString();
 }
 
-void HtmlOutputDev::drawChar(GfxState *state, double x, double y, double dx, double dy, double originX, double originY, CharCode code, int /*nBytes*/, const Unicode *u, int uLen)
+void HtmlOutputDev::drawChar(GfxState *state, double x, double y, double dx, double dy, double originX, double originY, CharCode /*code*/, int /*nBytes*/, const Unicode *u, int uLen)
 {
     if (!showHidden && (state->getRender() & 3) == 3) {
         return;
@@ -1277,9 +1276,9 @@ void HtmlOutputDev::drawJpegImage(GfxState *state, Stream *str)
 
     // initialize stream
     str = str->getNextStream();
-    if (!str->reset()) {
+    if (!str->rewind()) {
         fclose(f1);
-        error(errIO, -1, "Couldn't reset stream");
+        error(errIO, -1, "Couldn't rewind stream");
         return;
     }
 
@@ -1296,10 +1295,16 @@ void HtmlOutputDev::drawJpegImage(GfxState *state, Stream *str)
     pages->addImage(std::move(fName), state);
 }
 
+// We need this because fclose returns int and the custom deleter of unique_ptr expects void
+static void custom_fclose(FILE *ptr)
+{
+    fclose(ptr);
+}
+
 void HtmlOutputDev::drawPngImage(GfxState *state, Stream *str, int width, int height, GfxImageColorMap *colorMap, bool isMask)
 {
-#ifdef ENABLE_LIBPNG
-    std::unique_ptr<FILE, decltype(&fclose)> f1 { nullptr, &fclose };
+#if ENABLE_LIBPNG
+    std::unique_ptr<FILE, decltype(&custom_fclose)> f1 { nullptr, &custom_fclose };
     InMemoryFile ims;
 
     if (!colorMap && !isMask) {
@@ -1326,8 +1331,8 @@ void HtmlOutputDev::drawPngImage(GfxState *state, Stream *str, int width, int he
         unsigned char *p;
         GfxRGB rgb;
         ImageStream imgStr { str, width, colorMap->getNumPixelComps(), colorMap->getBits() };
-        if (!imgStr.reset()) {
-            error(errInternal, -1, "Can't reset image stream");
+        if (!imgStr.rewind()) {
+            error(errInternal, -1, "Can't rewind image stream");
             return;
         }
         unsigned char *row = (unsigned char *)gmalloc(3 * width); // 3 bytes/pixel: RGB
@@ -1380,8 +1385,8 @@ void HtmlOutputDev::drawPngImage(GfxState *state, Stream *str, int width, int he
             }
         }
 
-        if (!str->reset()) {
-            error(errInternal, -1, "failed to reset stream");
+        if (!str->rewind()) {
+            error(errInternal, -1, "failed to rewind stream");
             return;
         }
         unsigned char *png_row = (unsigned char *)gmalloc(size);
@@ -1431,7 +1436,7 @@ void HtmlOutputDev::drawImageMask(GfxState *state, Object *ref, Stream *str, int
     if (dumpJPEG && str->getKind() == strDCT) {
         drawJpegImage(state, str);
     } else {
-#ifdef ENABLE_LIBPNG
+#if ENABLE_LIBPNG
         drawPngImage(state, str, width, height, nullptr, true);
 #else
         OutputDev::drawImageMask(state, ref, str, width, height, invert, interpolate, inlineImg);
@@ -1453,7 +1458,7 @@ void HtmlOutputDev::drawImage(GfxState *state, Object *ref, Stream *str, int wid
     if (dumpJPEG && str->getKind() == strDCT && (colorMap->getNumPixelComps() == 1 || colorMap->getNumPixelComps() == 3) && !inlineImg) {
         drawJpegImage(state, str);
     } else {
-#ifdef ENABLE_LIBPNG
+#if ENABLE_LIBPNG
         drawPngImage(state, str, width, height, colorMap);
 #else
         OutputDev::drawImage(state, ref, str, width, height, colorMap, interpolate, maskColors, inlineImg);
