@@ -14,7 +14,7 @@
 // All changes made under the Poppler project to this file are licensed
 // under GPL version 2 or later
 //
-// Copyright (C) 2006, 2007, 2009, 2012, 2018-2022. 2024 Albert Astals Cid <aacid@kde.org>
+// Copyright (C) 2006, 2007, 2009, 2012, 2018-2022, 2024, 2025 Albert Astals Cid <aacid@kde.org>
 // Copyright (C) 2008, 2009 Warren Toomey <wkt@tuhs.org>
 // Copyright (C) 2009, 2011 Carlos Garcia Campos <carlosgc@gnome.org>
 // Copyright (C) 2009 Kovid Goyal <kovid@kovidgoyal.net>
@@ -26,7 +26,7 @@
 // Copyright (C) 2013 Thomas Freitag <Thomas.Freitag@alfa.de>
 // Copyright (C) 2018 Klarälvdalens Datakonsult AB, a KDAB Group company, <info@kdab.com>. Work sponsored by the LiMux project of the city of Munich
 // Copyright (C) 2019, 2024 Oliver Sander <oliver.sander@tu-dresden.de>
-// Copyright (C) 2024 g10 Code GmbH, Author: Sune Stolborg Vuorela <sune@vuorela.dk>
+// Copyright (C) 2024, 2025 g10 Code GmbH, Author: Sune Stolborg Vuorela <sune@vuorela.dk>
 //
 // To see a description of the changes please see the Changelog file that
 // came with your tarball or type make ChangeLog if you are building from git
@@ -37,14 +37,11 @@
 #define HTMLOUTPUTDEV_H
 
 #include <cstdio>
-#include "goo/gbasename.h"
-#include "GfxFont.h"
 #include "OutputDev.h"
 #include "HtmlLinks.h"
 #include "HtmlFonts.h"
 #include "Link.h"
 #include "Catalog.h"
-#include "UnicodeMap.h"
 
 #define xoutRound(x) ((int)((x) + 0.5))
 
@@ -176,11 +173,11 @@ private:
 
     // marks the position of the fonts that belong to current page (for noframes)
     int fontsPageMarker;
-    HtmlFontAccu *fonts;
-    HtmlLinks *links;
-    std::vector<HtmlImage *> imgList;
+    std::unique_ptr<HtmlFontAccu> fonts;
+    std::unique_ptr<HtmlLinks> links;
+    std::vector<std::unique_ptr<HtmlImage>> imgList;
 
-    GooString *DocName;
+    std::unique_ptr<GooString> DocName;
     int pageWidth;
     int pageHeight;
     int firstPage; // used to begin the numeration of pages
@@ -200,11 +197,11 @@ public:
     HtmlMetaVar(const HtmlMetaVar &) = delete;
     HtmlMetaVar &operator=(const HtmlMetaVar &) = delete;
 
-    GooString *toString() const;
+    std::unique_ptr<GooString> toString() const;
 
 private:
-    GooString *name;
-    GooString *content;
+    std::unique_ptr<GooString> name;
+    std::unique_ptr<GooString> content;
 };
 
 //------------------------------------------------------------------------
@@ -246,8 +243,9 @@ public:
 
     //----- initialization and control
 
-    bool checkPageSlice(Page *p, double hDPI, double vDPI, int rotate, bool useMediaBox, bool crop, int sliceX, int sliceY, int sliceW, int sliceH, bool printing, bool (*abortCheckCbk)(void *data) = nullptr,
-                        void *abortCheckCbkData = nullptr, bool (*annotDisplayDecideCbk)(Annot *annot, void *user_data) = nullptr, void *annotDisplayDecideCbkData = nullptr) override
+    bool checkPageSlice(Page *p, double /*hDPI*/, double /*vDPI*/, int /*rotate*/, bool /*useMediaBox*/, bool /*crop*/, int /*sliceX*/, int /*sliceY*/, int /*sliceW*/, int /*sliceH*/, bool /*printing*/,
+                        bool (* /*abortCheckCbk*/)(void *data) = nullptr, void * /*abortCheckCbkData*/ = nullptr, bool (* /*annotDisplayDecideCbk*/)(Annot *annot, void *user_data) = nullptr,
+                        void * /*annotDisplayDecideCbkData*/ = nullptr) override
     {
         docPage = p;
         return true;
@@ -302,7 +300,7 @@ private:
     // FILE *tin;                    // image log file
     // bool write;
     bool needClose; // need to close the file?
-    HtmlPage *pages; // text for the current page
+    std::unique_ptr<HtmlPage> pages; // text for the current page
     bool rawOrder; // keep text in content stream order
     bool doOutline; // output document outline
     bool ok; // set up ok?
@@ -310,9 +308,9 @@ private:
     int pageNum;
     int maxPageWidth;
     int maxPageHeight;
-    GooString *Docname;
-    GooString *docTitle;
-    std::vector<HtmlMetaVar *> glMetaVars;
+    std::unique_ptr<GooString> Docname;
+    std::unique_ptr<GooString> docTitle;
+    std::vector<std::unique_ptr<HtmlMetaVar>> glMetaVars;
     Catalog *catalog;
     Page *docPage;
     std::vector<std::string> backgroundImages;
