@@ -18,7 +18,7 @@
 // Copyright (C) 2009 Michael K. Johnson <a1237@danlj.org>
 // Copyright (C) 2009 Shen Liang <shenzhuxi@gmail.com>
 // Copyright (C) 2009 Stefan Thomas <thomas@eload24.com>
-// Copyright (C) 2009-2011, 2015, 2018-2022 Albert Astals Cid <aacid@kde.org>
+// Copyright (C) 2009-2011, 2015, 2018-2022, 2025 Albert Astals Cid <aacid@kde.org>
 // Copyright (C) 2010, 2012, 2017 Adrian Johnson <ajohnson@redneon.com>
 // Copyright (C) 2010 Hib Eris <hib@hiberis.nl>
 // Copyright (C) 2010 Jonathan Liu <net147@gmail.com>
@@ -37,6 +37,8 @@
 // Copyright (C) 2020 Philipp Knechtges <philipp-dev@knechtges.com>
 // Copyright (C) 2021 Diogo Kollross <diogoko@gmail.com>
 // Copyright (C) 2021 Peter Williams <peter@newton.cx>
+// Copyright (C) 2022 James Cloos <cloos@jhcloos.com>
+// Copyright (C) 2025 g10 Code GmbH, Author: Sune Stolborg Vuorela <sune@vuorela.dk>
 //
 // To see a description of the changes please see the Changelog file that
 // came with your tarball or type make ChangeLog if you are building from git
@@ -52,10 +54,8 @@
 #include <cstdio>
 #include <cmath>
 #include "parseargs.h"
-#include "goo/gmem.h"
 #include "goo/GooString.h"
 #include "GlobalParams.h"
-#include "Object.h"
 #include "PDFDoc.h"
 #include "PDFDocFactory.h"
 #include "splash/SplashBitmap.h"
@@ -78,7 +78,7 @@
 #    include <deque>
 #endif // UTILS_USE_PTHREADS
 
-#ifdef USE_CMS
+#if USE_CMS
 #    include <lcms2.h>
 #endif
 
@@ -103,7 +103,7 @@ static bool hideAnnotations = false;
 static bool useCropBox = false;
 static bool mono = false;
 static bool gray = false;
-#ifdef USE_CMS
+#if USE_CMS
 static GooString displayprofilename;
 static GfxLCMSProfilePtr displayprofile;
 static GooString defaultgrayprofilename;
@@ -168,7 +168,7 @@ static const ArgDesc argDesc[] = { { "-f", argInt, &firstPage, 0, "first page to
 
                                    { "-mono", argFlag, &mono, 0, "generate a monochrome PBM file" },
                                    { "-gray", argFlag, &gray, 0, "generate a grayscale PGM file" },
-#ifdef USE_CMS
+#if USE_CMS
                                    { "-displayprofile", argGooString, &displayprofilename, 0, "ICC color profile to use as the display profile" },
                                    { "-defaultgrayprofile", argGooString, &defaultgrayprofilename, 0, "ICC color profile to use as the DefaultGray color space" },
                                    { "-defaultrgbprofile", argGooString, &defaultrgbprofilename, 0, "ICC color profile to use as the DefaultRGB color space" },
@@ -176,16 +176,16 @@ static const ArgDesc argDesc[] = { { "-f", argInt, &firstPage, 0, "first page to
 #endif
                                    { "-sep", argString, sep, sizeof(sep), "single character separator between name and page number, default - " },
                                    { "-forcenum", argFlag, &forceNum, 0, "force page number even if there is only one page " },
-#ifdef ENABLE_LIBPNG
+#if ENABLE_LIBPNG
                                    { "-png", argFlag, &png, 0, "generate a PNG file" },
 #endif
-#ifdef ENABLE_LIBJPEG
+#if ENABLE_LIBJPEG
                                    { "-jpeg", argFlag, &jpeg, 0, "generate a JPEG file" },
                                    { "-jpegcmyk", argFlag, &jpegcmyk, 0, "generate a CMYK JPEG file" },
                                    { "-jpegopt", argGooString, &jpegOpt, 0, "jpeg options, with format <opt1>=<val1>[,<optN>=<valN>]*" },
 #endif
                                    { "-overprint", argFlag, &overprint, 0, "enable overprint" },
-#ifdef ENABLE_LIBTIFF
+#if ENABLE_LIBTIFF
                                    { "-tiff", argFlag, &tiff, 0, "generate a TIFF file" },
                                    { "-tiffcompression", argString, TiffCompressionStr, sizeof(TiffCompressionStr), "set TIFF compression: none, packbits, jpeg, lzw, deflate" },
 #endif
@@ -226,7 +226,7 @@ static bool parseJpegOptions()
         const char *comma = strchr(nextOpt, ',');
         GooString opt;
         if (comma) {
-            opt.Set(nextOpt, comma - nextOpt);
+            opt.Set(nextOpt, static_cast<int>(comma - nextOpt));
             nextOpt = comma + 1;
         } else {
             opt.Set(nextOpt);
@@ -238,9 +238,9 @@ static bool parseJpegOptions()
             fprintf(stderr, "Unknown jpeg option \"%s\"\n", opt.c_str());
             return false;
         }
-        int iequal = equal - opt.c_str();
-        GooString value(&opt, iequal + 1, opt.getLength() - iequal - 1);
-        opt.del(iequal, opt.getLength() - iequal);
+        const int iequal = static_cast<int>(equal - opt.c_str());
+        GooString value(&opt, iequal + 1, opt.size() - iequal - 1);
+        opt.erase(iequal, opt.size() - iequal);
         // here opt is "<optN>" and value is "<valN>"
 
         if (opt.cmp("quality") == 0) {
@@ -277,7 +277,7 @@ static bool parseJpegOptions()
     return true;
 }
 
-static auto annotDisplayDecideCbk = [](Annot *annot, void *user_data) { return !hideAnnotations; };
+static auto annotDisplayDecideCbk = [](Annot * /*annot*/, void * /*user_data*/) { return !hideAnnotations; };
 
 static void savePageSlice(PDFDoc *doc, SplashOutputDev *splashOut, int pg, int x, int y, int w, int h, double pg_w, double pg_h, char *ppmFile)
 {
@@ -297,7 +297,7 @@ static void savePageSlice(PDFDoc *doc, SplashOutputDev *splashOut, int pg, int x
     params.jpegQuality = jpegQuality;
     params.jpegProgressive = jpegProgressive;
     params.jpegOptimize = jpegOptimize;
-    params.tiffCompression.Set(TiffCompressionStr);
+    params.tiffCompression = TiffCompressionStr;
 
     if (ppmFile != nullptr) {
         SplashError e;
@@ -379,7 +379,7 @@ static void processPageJobs()
         splashOut->setFontAntialias(fontAntialias);
         splashOut->setVectorAntialias(vectorAntialias);
         splashOut->setEnableFreeType(enableFreeType);
-#    ifdef USE_CMS
+#    if USE_CMS
         splashOut->setDisplayProfile(displayprofile);
         splashOut->setDefaultGrayProfile(defaultgrayprofile);
         splashOut->setDefaultRGBProfile(defaultrgbprofile);
@@ -411,7 +411,7 @@ int main(int argc, char *argv[])
     bool ok;
     int pg, pg_num_len;
     double pg_w, pg_h;
-#ifdef USE_CMS
+#if USE_CMS
     cmsColorSpaceSignature profilecolorspace;
 #endif
 
@@ -457,7 +457,7 @@ int main(int argc, char *argv[])
         }
     }
 
-    if (jpegOpt.getLength() > 0) {
+    if (!jpegOpt.empty()) {
         if (!jpeg) {
             fprintf(stderr, "Warning: -jpegopt only valid with jpeg output.\n");
         }
@@ -545,7 +545,7 @@ int main(int argc, char *argv[])
         paperColor[2] = 255;
     }
 
-#ifdef USE_CMS
+#if USE_CMS
     if (!displayprofilename.toStr().empty()) {
         displayprofile = make_GfxLCMSProfilePtr(cmsOpenProfileFromFile(displayprofilename.c_str(), "r"));
         if (!displayprofile) {
@@ -602,7 +602,7 @@ int main(int argc, char *argv[])
     splashOut->setFontAntialias(fontAntialias);
     splashOut->setVectorAntialias(vectorAntialias);
     splashOut->setEnableFreeType(enableFreeType);
-#    ifdef USE_CMS
+#    if USE_CMS
     splashOut->setDisplayProfile(displayprofile);
     splashOut->setDefaultGrayProfile(defaultgrayprofile);
     splashOut->setDefaultRGBProfile(defaultrgbprofile);
@@ -666,10 +666,10 @@ int main(int argc, char *argv[])
 
             // No specific image size requested---compute the size from the resolution
             if (x_scaleTo <= 0) {
-                pg_w = pg_w * (x_resolution / 72.0);
+                pg_w = pg_w * x_resolution / 72.0;
             }
             if (y_scaleTo <= 0) {
-                pg_h = pg_h * (y_resolution / 72.0);
+                pg_h = pg_h * y_resolution / 72.0;
             }
         }
 
